/**************************************************************************
 |                                                                         
 |                    STATA SETUP FILE FOR ICPSR 06887
 |             NATIONAL HOUSEHOLD SURVEY ON DRUG ABUSE, 1992
 |
 |
 |  Please edit this file as instructed below.
 |  To execute, start Stata, change to the directory containing:
 |       - this do file
 |       - the ASCII data file
 |       - the dictionary file
 |
 |  Then execute the do file (e.g., do 06887-0001-statasetup.do)
 |
 **************************************************************************/

set mem 80m  /* Allocating 80 megabyte(s) of RAM for Stata SE to read the
                 data file into memory. */


set more off  /* This prevents the Stata output viewer from pausing the
                 process */

/****************************************************

Section 1: File Specifications
   This section assigns local macros to the necessary files.
   Please edit:
        "data-filename" ==> The name of data file downloaded from ICPSR
        "dictionary-filename" ==> The name of the dictionary file downloaded.
        "stata-datafile" ==> The name you wish to call your Stata data file.

   Note:  We assume that the raw data, dictionary, and setup (this do file) all
          reside in the same directory (or folder).  If that is not the case
          you will need to include paths as well as filenames in the macros.

********************************************************/

local raw_data "data-filename"
local dict "dictionary-filename"
local outfile "stata-datafile"

/********************************************************

Section 2: Infile Command

This section reads the raw data into Stata format.  If Section 1 was defined
properly, there should be no reason to modify this section.  These macros
should inflate automatically.

**********************************************************/

infile using `dict', using (`raw_data') clear


/*********************************************************

Section 3: Value Label Definitions
This section defines labels for the individual values of each variable.
We suggest that users do not modify this section.\n
**********************************************************/


label data "National Household Survey on Drug Abuse, 1992, Dataset 0001"

#delimit ;
label define CIG5PK    1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       81 "NEVER USED CIGARETTES Logically assigned"
                       91 "NEVER USED CIGARETTES" 98 "BLANK (NO ANSWER)" ;
label define CIGAGE    981 "NEVER USED CIGARETTES Logically assigned"
                       985 "BAD DATA Logically assigned"
                       989 "LEGITIMATE SKIP Logically assigned"
                       991 "NEVER USED CIGARETTES" 993 "NEVER SMOKED DAILY"
                       994 "DONT KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define CIGYRS    985 "BAD DATA Logically assigned"
                       989 "LEGITIMATE SKIP Logically assigned"
                       991 "NEVER USED CIGARETTES" 994 "DONT KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define PACKS     1 "One to five cigarettes a day"
                       2 "About 1/2 pack a day (6-15 cigarettes)"
                       3 "About a pack a day (16-25 cigarettes)"
                       4 "About 1 1/2 packs a day (26-35 cigarette"
                       5 "About 2 packs or more a day (over 35 cig"
                       89 "LEGITIMATE SKIP Logically assigned"
                       91 "NEVER USED CIGARETTES" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define CIGTIME   9981 "NEVER USED CIGARETTES Logically assigned"
                       9985 "BAD DATA Logically assigned"
                       9989 "LEGITIMATE SKIP Logically assigned"
                       9991 "NEVER USED CIGARETTES" 9994 "DONT KNOW"
                       9998 "BLANK (NO ANSWER)" 9999 "LEGITIMATE SKIP" ;
label define NOBOOKYR  0 "Was not arrested and booked in past 12 m"
                       85 "BAD DATA Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define BKLARCNY  1 "Response circled" 2 "Response not circled"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       98 "BOOKED IN PAST YEAR BUT SP-12 NOT ANSWER" ;
label define BKBURGL   1 "Response circled" 2 "Response not circled"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       98 "BOOKED IN PAST YEAR BUT SP-12 NOT ANSWER" ;
label define BKAGASLT  1 "Response circled" 2 "Response not circled"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       98 "BOOKED IN PAST YEAR BUT SP-12 NOT ANSWER" ;
label define BKSMASLT  1 "Response circled" 2 "Response not circled"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       98 "BOOKED IN PAST YEAR BUT SP-12 NOT ANSWER" ;
label define BKMVTHFT  1 "Response circled" 2 "Response not circled"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       98 "BOOKED IN PAST YEAR BUT SP-12 NOT ANSWER" ;
label define BKROB     1 "Response circled" 2 "Response not circled"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       98 "BOOKED IN PAST YEAR BUT SP-12 NOT ANSWER" ;
label define BKRAPE    1 "Response circled" 2 "Response not circled"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       98 "BOOKED IN PAST YEAR BUT SP-12 NOT ANSWER" ;
label define BKMURDER  2 "Response not circled"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       98 "BOOKED IN PAST YEAR BUT SP-12 NOT ANSWER" ;
label define BKARSON   1 "Response circled" 2 "Response not circled"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       98 "BOOKED IN PAST YEAR BUT SP-12 NOT ANSWER" ;
label define BKDRVINF  1 "Response circled" 2 "Response not circled"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       98 "BOOKED IN PAST YEAR BUT SP-12 NOT ANSWER" ;
label define BKDRUNK   1 "Response circled" 2 "Response not circled"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       98 "BOOKED IN PAST YEAR BUT SP-12 NOT ANSWER" ;
label define BKDRUG    1 "Response circled" 2 "Response not circled"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       98 "BOOKED IN PAST YEAR BUT SP-12 NOT ANSWER" ;
label define BKPROS    1 "Response circled" 2 "Response not circled"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       98 "BOOKED IN PAST YEAR BUT SP-12 NOT ANSWER" ;
label define BKVANDAL  1 "Response circled" 2 "Response not circled"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       98 "BOOKED IN PAST YEAR BUT SP-12 NOT ANSWER" ;
label define BKOTHOFF  1 "Larceny or theft"
                       2 "Burglary or breaking and entering"
                       3 "Aggravated assault"
                       4 "Other assault, such as simple assault or"
                       8 "Murder, homicide, or nonnegligent mansla"
                       10 "Driving under the influence"
                       11 "Drunkenness or other liquor law violatio"
                       12 "Possession or sale of drugs"
                       14 "Oth proprty offns:- fraud, poss stln goo"
                       15 "Other offenses (NOT SPECIFIED)"
                       16 "Weapons offenses"
                       18 "Violation of court order, parole, probat"
                       19 "Public order offenses"
                       20 "Juvenile status offenses" 22 "Traffic violations"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define NOTBKED   1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       98 "BOOKED IN PAST YEAR BUT SP-12 NOT ANSWER" ;
label define DRUNKDRV  1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define OTHDOING  1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define OTHDOSP1  1 "Shoplifting" 2 "Other larceny or theft"
                       3 "Property damage/destruction (incl.vandal"
                       4 "Motor vehicle theft" 5 "Robbery"
                       6 "Breaking and entering, burglary"
                       7 "Hitting someone or physically fighting"
                       9 "Other assault, battery"
                       10 "Driving under the influence of alcohol o"
                       11 "Selling illegal drugs"
                       12 "Drug offense (except sales) involving ma"
                       13 "Other drug-related offense"
                       14 "Drunkenness or other liquor law violatio"
                       15 "Forcible rape"
                       16 "Murder, homicide, or nonnegligent mansla"
                       17 "Other offenses against persons" 18 "Arson"
                       19 "Nondestructive prop offenses, fraud, stl"
                       20 "Prostitution or commercialized sex"
                       21 "Weapons offenses"
                       22 "Violation of court order, parole, probat"
                       23 "Public order offenses"
                       24 "Juvenile status offenses" 26 "Traffic violations"
                       27 "Other offenses, NOT SPECIFIED"
                       85 "BAD DATA Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define OTHDOSP2  1 "Shoplifting" 2 "Other larceny or theft"
                       3 "Property damage/destruction (incl.vandal"
                       4 "Motor vehicle theft"
                       6 "Breaking and entering, burglary"
                       7 "Hitting someone or physically fighting"
                       9 "Other assault, battery"
                       10 "Driving under the influence of alcohol o"
                       11 "Selling illegal drugs"
                       12 "Drug offense (except sales) involving ma"
                       13 "Other drug-related offense"
                       14 "Drunkenness or other liquor law violatio"
                       19 "Nondestructive prop offenses, fraud, stl"
                       21 "Weapons offenses" 23 "Public order offenses"
                       24 "Juvenile status offenses" 26 "Traffic violations"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define ALCSED    1 "Response circled" 2 "Response not circled"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       99 "LEGITIMATE SKIP" ;
label define ALCTRAN   1 "Response circled" 2 "Response not circled"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       99 "LEGITIMATE SKIP" ;
label define ALCSTM    1 "Response circled" 2 "Response not circled"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       99 "LEGITIMATE SKIP" ;
label define ALCANAL   1 "Response circled" 2 "Response not circled"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       99 "LEGITIMATE SKIP" ;
label define ALCMJ     1 "Response circled" 2 "Response not circled"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       99 "LEGITIMATE SKIP" ;
label define ALCINH    1 "Response circled" 2 "Response not circled"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       99 "LEGITIMATE SKIP" ;
label define ALCCOC    1 "Response circled" 2 "Response not circled"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       99 "LEGITIMATE SKIP" ;
label define ALCHAL    1 "Response circled" 2 "Response not circled"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       99 "LEGITIMATE SKIP" ;
label define ALCOPT    1 "Response circled" 2 "Response not circled"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       99 "LEGITIMATE SKIP" ;
label define ALCNONE   1 "Response circled" 2 "Response not circled"
                       12 "months from your use of any of the"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       99 "LEGITIMATE SKIP" ;
label define CIGHELP   1 "Yes" 2 "No"
                       81 "NEVER USED CIGARETTES Logically assigned"
                       91 "NEVER USED CIGARETTES" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define DRNKHELP  1 "Yes" 2 "No"
                       81 "NEVER USED ALCOHOL Logically assigned"
                       91 "NEVER USED ALCOHOL" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define TRMTHELP  1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       4 "NO LOGICALLY IMPUTED"
                       81 "NEVER USED DRUGS Logically assigned"
                       83 "NEVER RECEIVED TREATMENT BUT MAY USE DRU"
                       91 "NEVER USED DRUGS"
                       93 "NEVER RECEIVED TREATMENT BUT MAY USE DRU"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TRMTEMRG  1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       4 "NO LOGICALLY IMPUTED"
                       81 "NEVER USED DRUGS Logically assigned"
                       83 "NEVER RECEIVED TREATMENT BUT MAY USE DRU"
                       91 "NEVER USED DRUGS"
                       93 "NEVER RECEIVED TREATMENT BUT MAY USE DRU"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TRMTHOSP  1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       4 "NO LOGICALLY IMPUTED"
                       81 "NEVER USED DRUGS Logically assigned"
                       83 "NEVER RECEIVED TREATMENT BUT MAY USE DRU"
                       91 "NEVER USED DRUGS"
                       93 "NEVER RECEIVED TREATMENT BUT MAY USE DRU"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TRMTDOC   1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       4 "NO LOGICALLY IMPUTED"
                       81 "NEVER USED DRUGS Logically assigned"
                       83 "NEVER RECEIVED TREATMENT BUT MAT USE DRU"
                       91 "NEVER USED DRUGS"
                       93 "NEVER RECEIVED TREATMENT BUT MAT USE DRU"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TRMTTRMT  1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       4 "NO LOGICALLY ASSIGNED"
                       81 "NEVER USED DRUGS Logically assigned"
                       83 "NEVER RECEIVED TREATMENT BUT MAY USE DRU"
                       91 "NEVER USED DRUGS"
                       93 "NEVER RECEIVED TREATMENT BUT MAY USE DRU"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TRMTMHC   1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       4 "NO LOGICALLY IMPUTED"
                       81 "NEVER USED DRUGS Logically assigned"
                       83 "NEVER RECEIVED TREATMENT BUT MAY USE DRU"
                       91 "NEVER USED DRUGS"
                       93 "NEVER RECEIVED TREATMENT BUT MAY USE DRU"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TRMTSHG   1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       4 "NO LOGICALLY IMPUTED"
                       81 "NEVER USED DRUGS Logically assigned"
                       83 "NEVER RECEIVED TREATMENT BUT MAY USE DRU"
                       91 "NEVER USED DRUGS"
                       93 "NEVER RECEIVED TREATMENT BUT MAY USE DRU"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TRMTSOP   1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       4 "NO LOGICALLY IMPUTED"
                       81 "NEVER USED DRUGS Logically assigned"
                       83 "NEVER RECEIVED TREATMENT BUT MAY USE DRU"
                       91 "NEVER USED DRUGS"
                       93 "NEVER RECEIVED TREATMENT BUT MAY USE DRU"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TRMTSP    4 "AA or NA or CA" 5 "Residential placement"
                       9 "Within myself (self-treatment)" 10 "Church"
                       12 "Friends" 13 "Court or correctional facilities"
                       14 "Counselor, therapist, psychologist" 15 "School"
                       21 "ER, Ambulance" 22 "Hospital"
                       24 "Drug treatment or Rehab. Center"
                       25 "Mental health center" 26 "Self-help group"
                       27 "All types mentioned"
                       81 "NEVER USED DRUGS Logically assigned"
                       85 "BAD DATA Logically assigned" 91 "NEVER USED DRUGS"
                       93 "NEVER RECEIVED TREATMENT BUT MAY USE DRU"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define TRMTREC   1 "Within the past month"
                       2 "More than one month ago but less than 6"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago"
                       8 "Received treatment in past year LOGICALL"
                       9 "Received treatment in lifetime LOGICALLY"
                       81 "NEVER USED DRUGS Logically assigned"
                       83 "NEVER RECEIVED TREATMENT Logically assig"
                       91 "NEVER USED DRUGS" 93 "NEVER RECEIVED TREATMENT"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define NOTRMT    1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define TXEMRG    1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TXHOSP    1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TXDOC     1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TXTRMT    1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TXMHC     1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TXSHG     1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TXSOP     1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TXSP      4 "AA or NA or CA" 5 "Residential placement"
                       9 "Within myself (self-treatment)"
                       10 "Church or religious influence" 12 "Friends"
                       13 "Court or Correctional Facilities"
                       14 "Counselor, therapist, psychologist" 15 "School"
                       16 "Home, Family" 21 "ER, Ambulance" 22 "Hospital"
                       23 "Doctors Office" 24 "Drug treatment or Rehab"
                       25 "Mental Health Center" 26 "Self-help Group"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TRMTLIFE  1 "Very important" 2 "Somewhat important"
                       3 "Not at all important"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TRMTRESP  1 "Very important" 2 "Somewhat important"
                       3 "Not at all important"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TRMTFEAR  1 "Very important" 2 "Somewhat important"
                       3 "Not at all important"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TRMTCOST  1 "Very important" 2 "Somewhat important"
                       3 "Not at all important"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TRMTEVNT  1 "Very important" 2 "Somewhat important"
                       3 "Not at all important"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TRMTPR    1 "Very important" 2 "Somewhat important"
                       3 "Not at all important"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TRMTHLTH  1 "Very important" 2 "Somewhat important"
                       3 "Not at all important"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TRMTJOB   1 "Very important" 2 "Somewhat important"
                       3 "Not at all important"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TRMTJAIL  1 "Very important" 2 "Somewhat important"
                       3 "Not at all important"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TRMTSERV  1 "Very important" 2 "Somewhat important"
                       3 "Not at all important"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TRMTBQD   1 "Very important" 2 "Somewhat important"
                       3 "Not at all important"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TRMTDNA   1 "Very important" 2 "Somewhat important"
                       3 "Not at all important"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TRMTSOR   1 "Very important" 2 "Somewhat important"
                       3 "Not at all important" 4 "Response circled only"
                       5 "Reason specified but no ranking"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TRMTRSP   1 "Wanted to change lifestyle"
                       2 "Had family responsibilities"
                       3 "Fear of being jailed" 4 "Drugs were too costly"
                       5 "Occurrence of a sig. personal or special"
                       6 "Pressure from family (or close friends)"
                       7 "Had concerns about health" 9 "Sent to jail"
                       10 "Availability of services" 12 "Drugs not available"
                       14 "Depression"
                       15 "Fear of dying/suicide(fear of, or attemp"
                       16 "Church or other religious influence"
                       17 "Forced/Compelled (but by whom is unknown"
                       18 "Wanted to quit drugs"
                       19 "Reason connected to the military" 20 "Overdose"
                       21 "Loss of control/Dependency"
                       22 "Felt bad about self/Wanted to do/be bett"
                       23 "Reason connected to Drivers License"
                       24 "Physical victimization" 25 "Committing violence"
                       26 "Pressure from counselor/soc. srvcs/etc"
                       27 "Psychological disorders"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TRMTOUTC  1 "Still in treatment"
                       2 "Successfully completed treatment"
                       3 "Had a problem with program"
                       4 "Couldnt afford to continue treatment"
                       5 "Family needed me" 6 "Began using drug(s) again"
                       7 "Other outcome, not specified"
                       8 "Didnt need treatment" 9 "Treatment is for lifetime"
                       10 "Successful because of own efforts, not t"
                       11 "Use to a lesser extent" 12 "Kicked out of program"
                       13 "Moved"
                       14 "Successful because of religious reasons"
                       15 "Discontinued treatment, success unknown"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TMTPHI    1 "Response circled" 2 "Response not circled"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TMTPSAVE  1 "Response circled" 2 "Response not circled"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TMTPFMLY  1 "Response circled" 2 "Response not circled"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TMTPEMPR  1 "Response circled" 2 "Response not circled"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TMTPMEDI  1 "Response circled" 2 "Response not circled"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TMTPFREE  1 "Response circled" 2 "Response not circled"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TMTPOTH   1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TMTPASP   2 "Own savings or earnings" 3 "Family member"
                       4 "Employer" 5 "Medicare or Medicaid" 6 "Free"
                       8 "Friend/Sponsor" 9 "State/City" 10 "Court"
                       11 "Church" 12 "School" 13 "Hospital"
                       14 "Veterans Administration/Military Service"
                       15 "Treatment program"
                       85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define HIGHBP    1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define BPMED     1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DONT KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define NOMARR    85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define WORKSTAT  1 "Working full-time, 35 hours or more a we"
                       2 "Working part-time, less than 35 hours a"
                       3 "Have job but out: illness/leave/furlough"
                       4 "Unemployed or laid off and looking for w"
                       5 "Unemployed and not looking for work"
                       6 "Full-time homemaker only" 7 "In school only"
                       8 "Retired" 9 "Disabled, not able to work"
                       21 "Working full time, 35 hours or more a we"
                       22 "Working part time, less than 35 hours a"
                       23 "Have a job but out: illness/leave/furlou"
                       24 "Unemployed or laid off and looking for w"
                       25 "Unemployed and not looking for work"
                       26 "Full-time homemaker" 27 "In school only"
                       28 "Retired" 29 "Disabled, not able to work"
                       30 "Other, in labor force"
                       31 "Other, not in the labor force"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define BHOUR     98 "BLANK (NO ANSWER)" ;
label define BMIN      98 "BLANK (NO ANSWER)" ;
label define EHOUR     98 "BLANK (NO ANSWER)" ;
label define EMIN      98 "BLANK (NO ANSWER)" ;
label define CENCTY    1 "Yes" 2 "No"
                       3 "Not in any of the 6 metropolitan areas" ;
label define UCLASS9   0 "Above underclass level" 1 "Below underclass level" ;
label define CENTRALC  1 "Sample segm. within a central city of me"
                       2 "Sam. segm. not within a central city of"
                       3 "Sample segment not within in a central c" ;
label define IRWORKST  1 "Working full-time, 35 hours or more a we"
                       2 "Working part-time, less than 35 hours a"
                       3 "Have job but out: illness/leave/furlough"
                       4 "Unemployed or laid off and looking for w"
                       5 "Unemployed and not looking for work"
                       6 "Full-time homemaker only" 7 "In school only"
                       8 "Retired" 9 "Disabled, not able to work"
                       10 "Other, in labor force"
                       11 "Other, not in labor force" ;
label define IIWORKST  1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define ICEYR     0 "Did not use in the past year (IRICERC ="
                       1 "Used within the past year (IRICERC = 1-4" ;
label define ICEMON    0 "Did not use in the past month (IRICERC ="
                       1 "Used within the past month (IRICERC = 1-" ;
label define QC06      1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago" 98 "BLANK (NO ANSWER)" ;
label define QC09      1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago"
                       91 "NEVER USED SMOKELESS TOBACCO"
                       98 "BLANK (NO ANSWER)" ;
label define CIGTRY    985 "BAD DATA Logically assigned"
                       991 "NEVER USED CIGARETTES" 994 "DONT KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define CIGREC    1 "Within the past month(30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago"
                       7 "Use in past 30 days LOGICALLY IMPUTED"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       91 "NEVER USED CIGARETTES" 98 "BLANK (NO ANSWER)" ;
label define AVCIG     1 "Less than one cigarette a day"
                       2 "One to five cigarettes a day"
                       3 "About 1/2 pack a day (6-15 cigarettes)"
                       4 "About a pack a day (16-25 cigarettes)"
                       5 "About 1 1/2 packs a day (26-35 cigarette"
                       6 "About 2 packs or more a day (over 35 cig"
                       89 "LEGITIMATE SKIP Logically assigned"
                       91 "NEVER USED CIGARETTES" 94 "DONT KNOW"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define SNUFREC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago"
                       8 "Use in past year LOGICALLY IMPUTED"
                       91 "NEVER USED SMOKELESS TOBACCO"
                       98 "BLANK (NO ANSWER)" ;
label define OTHTOB    1 "Daily in the past 12 Months"
                       2 "Almost daily (3-6 days a week)"
                       3 "1 or 2 days a week"
                       4 "Several times a month (25-51 days a year"
                       5 "1 or 2 times a month (12-24 days a year)"
                       6 "Every other month or so (6-11 days a yea"
                       7 "3-5 days this past year"
                       8 "1 or 2 days this past year"
                       81 "NEVER USED SMOKELESS TOBACCO Logically a"
                       83 "DID NOT USE SMOKELESS TOBACCO PST YR Log"
                       91 "NEVER USED SMOKELESS TOBACCO"
                       98 "BLANK (NO ANSWER)" ;
label define ALCTRY    981 "NEVER USED ALCOHOL Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED ALCOHOL" 994 "DONT KNOW"
                       998 "BLANK (NO ANSWER)" ;
label define ALCREC    1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago"
                       7 "Use in past 30 days LOGICALLY IMPUTED"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       81 "NEVER USED ALCOHOL Logically assigned"
                       91 "NEVER USED ALCOHOL" ;
label define ALCAGE    981 "NEVER USED ALCOHOL Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED ALCOHOL"
                       993 "NEVER USED ALCOHOL MONTHLY OR MORE OFTEN"
                       994 "DONT KNOW" 998 "BLANK (NO ANSWER)" ;
label define ALCDAYS   81 "NEVER USED ALCOHOL Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN THE PAST 30 DAYS"
                       94 "DONT KNOW" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define NODR30A   81 "NEVER USED ALCOHOL Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN THE PAST 30 DAYS"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DR5DAY    81 "NEVER USED ALCOHOL Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN THE PAST 30 DAYS"
                       94 "DONT KNOW" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define MODR30A   81 "NEVER USED ALCOHOL Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN THE PAST 30 DAYS"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define MODR30DY  81 "NEVER USED ALCOHOL Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN THE PAST 30 DAYS"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ALCPAT    1 "Daily in the past 12 months"
                       2 "Almost daily or 3 to 6 days a week"
                       3 "About 1 or 2 days a week"
                       4 "Several times a month (about 25 to 51 da"
                       5 "1 to 2 times a month (12 to 24 days a ye"
                       6 "Every other month or so (6 to 11 days a"
                       7 "3 to 5 days in the past 12 months"
                       8 "1 or 2 days in the past 12 months"
                       81 "NEVER USED ALCOHOL Logically assigned"
                       83 "DID NOT USE ALCOHOL PAST 12 MOS. Logic.a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN THE PAST 12 MONTH"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DRUNKYR   1 "Daily in the past 12 months"
                       2 "Almost daily or 3 to 6 days a week"
                       3 "About 1 or 2 days a week"
                       4 "Several times a month (about 25 to 51 da"
                       5 "1 to 2 times a month (12 to 24 days a ye"
                       6 "Every other month or so (6 to 11 days a"
                       7 "3 to 5 days in the past 12 months"
                       8 "1 or 2 days in the past 12 months"
                       9 "Never got very high or drunk in past 12"
                       81 "NEVER USED ALCOHOL Logically assigned"
                       83 "DID NOT USE ALCOHOL PAST 12 MOS. Logic.a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL"
                       93 "DID NOT USE ALCOHOL IN THE PAST 12 MONTH"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ALCBEER   1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED ALCOHOL Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL" 94 "DONT KNOW" 97 "REFUSED" ;
label define ALCWINE   1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED ALCOHOL Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL" ;
label define ALCLIQR   1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED ALCOHOL Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL" ;
label define ALCVARY   1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED ALCOHOL Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ALCOHOL" ;
label define NOSEDAT   1 "Response circled" 2 "Response not circled"
                       4 "Response not circled LOGICALLY IMPUTED"
                       98 "BLANK (NO ANSWER)" ;
label define BUTISOL   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define BUTICAPS  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define AMYTAL    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define MEBARAL   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define PLACIDYL  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define DORIDEN   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define NOLUDAR   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define NEMBUTAL  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define SECONAL   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define TUINAL    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define DALMANE   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define RESTORIL  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define HALCION   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define AMOBARB   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define PHENOBAR  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define METHAQ    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define CHHYD     1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define PENTOB    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define SECOB     1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define SEDNEWA   116 "Methaqualone, Quaalude, Sopor"
                       120 "Downers; OTHER Sedative, NOT SPECIFIED"
                       123 "Unisom" 124 "Yellow jackets" 126 "sic" 138 "sic"
                       140 "Seldane" 145 "Red devil(s)" 149 "sic" 150 "sic"
                       151 "sic" 201 "Valium" 202 "Librium" 209 "Xanax"
                       234 "Cyclobenzaprine, Flexeril" 239 "see also 228"
                       241 "Prozac" 318 "Ritalin, Methylphenidate"
                       324 "Uppers; OTHER Stimulant, NOT SPECIFIED"
                       327 "Black beauties, Black Beauty" 353 "No-Doz"
                       362 "Benadryl" 401 "Darvon"
                       406 "Oxycodone, Percodan, Roxicet" 407 "Demerol"
                       408 "Dilaudid" 420 "OTHER Analgesic, NOT SPECIFIED"
                       422 "Motrin" 423 "Percocet" 425 "Advil"
                       435 "Tylenol, Tylenol Extrastrength" 440 "Soma"
                       458 "Mepergan, Mepergan Fortis" 515 "Vicks"
                       811 "Muscle relaxers"
                       813 "Cigarettes, smoking (subst spec), tobacc"
                       981 "NEVER USED SEDATIVES Logically assigned"
                       991 "NEVER USED SEDATIVES" 998 "BLANK (NO ANSWER)" ;
label define SEDNEWB   201 "Valium" 221 "OTHER Tranquilizer, NOT SPECIFIED"
                       336 "Diet pills" 415 "Codeine"
                       605 "PCP (angel dust, phencyclidine)"
                       991 "NEVER USED SEDATIVES" 998 "BLANK (NO ANSWER)" ;
label define SEDNEWC   805 "Cocaine, coke" 991 "NEVER USED SEDATIVES"
                       998 "BLANK (NO ANSWER)" ;
label define SEDNEWD   803 "sic" 991 "NEVER USED SEDATIVES"
                       998 "BLANK (NO ANSWER)" ;
label define SEDNEWE   991 "NEVER USED SEDATIVES" 998 "BLANK (NO ANSWER)" ;
label define SEDNOSP   1 "Response circled" 2 "Response not circled"
                       3 "Sedative use LOGICALLY IMPUTED"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define SEDDKNAM  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define SEDAGE    981 "NEVER USED SEDATIVES Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED SEDATIVES" 994 "DONT KNOW"
                       998 "BLANK (NO ANSWER)" ;
label define SEDTOT    1 "1 or 2 times" 2 "3 to 5 times" 3 "6 to 10 times"
                       4 "11 to 49 times" 5 "50 to 99 times"
                       6 "100 to 199 times" 7 "200 or more times"
                       91 "NEVER USED SEDATIVES" 96 "MULTIPLE RESPONSE"
                       98 "BLANK (NO ANSWER)" ;
label define SEDREC    1 "Within the past month(30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       91 "NEVER USED SEDATIVES" 98 "BLANK (NO ANSWER)" ;
label define SEDYRFRQ  1 "Daily in the past 12 months"
                       2 "Almost daily or 3 to 6 days a week"
                       3 "About 1 or 2 days a week"
                       4 "Several times a month (25 to 51 days a y"
                       5 "1 to 2 times a month (12 to 24 days a ye"
                       6 "Every other month or so (6 to 11 days a"
                       7 "3 to 5 days in the past 12 months"
                       8 "1 or 2 days in the past 12 months"
                       81 "NEVER USED SEDATIVES Logically assigned"
                       83 "DID NOT USE SEDATIVE PAST 12 MOS. Logic."
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED SEDATIVES"
                       93 "DID NOT USE ANY SEDATIVE IN THE PAST 12"
                       98 "BLANK (NO ANSWER)" ;
label define TRNREAD   1 "Wants interviewer to continue reading"
                       2 "Wants to do it himself/herself"
                       3 "Wants interviewer to continue LOGICALLY"
                       98 "BLANK (NO ANSWER)" ;
label define NOTRANQ   1 "Response circled" 2 "Response not circled"
                       4 "Response not circled LOGICALLY IMPUTED"
                       98 "BLANK (NO ANSWER)" ;
label define VALIUM    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define LIBRIUM   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define LIMBTROL  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define MENRIUM   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define SERAX     1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define TRANXENE  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define ATIVAN    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define CENTRAX   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define XANAX     1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define PAXIPAM   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define BUSPAR    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define MILTOWN   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define EQUANIL   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define DEPROL    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define VISTAR    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define ATARAX    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define DURRAX    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define DIAZEPAM  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define SKLY      2 "Response not circled" 91 "NEVER USED TRANQUILIZERS"
                       98 "BLANK (NO ANSWER)" ;
label define MEPROB    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define TRNEWA    105 "Placidyl" 113 "Halcion"
                       116 "Methaqualone, Quaalude, Sopor"
                       131 "Haldol, Haloperidol" 201 "Valium" 209 "Xanax"
                       221 "OTHER Tranquilizer, NOT SPECIFIED" 229 "Librax"
                       234 "Cyclobenzaprine, Flexeril" 241 "Prozac"
                       252 "Strawberry whip cream" 254 "sic" 255 "sic"
                       257 "Zestril" 258 "sic" 260 "PCB" 261 "sic"
                       339 "Amphetamines (speed generically)"
                       811 "Muscle relaxers" 991 "NEVER USED TRANQUILIZERS"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define TRNEWB    225 "Desyrel, Trazodone"
                       991 "NEVER USED TRANQUILIZERS" 998 "BLANK (NO ANSWER)" ;
label define TRNEWC    991 "NEVER USED TRANQUILIZERS" 998 "BLANK (NO ANSWER)" ;
label define TRNEWD    991 "NEVER USED TRANQUILIZERS" 998 "BLANK (NO ANSWER)" ;
label define TRNEWE    991 "NEVER USED TRANQUILIZERS" 998 "BLANK (NO ANSWER)" ;
label define TRNOSP    1 "Response circled" 2 "Response not circled"
                       3 "Tranquilizer use LOGICALLY IMPUTED"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define TRDKNAM   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED TRANQUILIZERS" 98 "BLANK (NO ANSWER)" ;
label define TRANAGE   981 "NEVER USED TRANQUILIZERS Logically assig"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED TRANQUILIZERS" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" ;
label define TRANTOT   1 "1 or 2 times" 2 "3 to 5 times" 3 "6 to 10 times"
                       4 "11 to 49 times" 5 "50 to 99 times"
                       6 "100 to 199 times" 7 "200 or more times"
                       91 "NEVER USED TRANQUILIZERS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define TRANREC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       91 "NEVER USED TRANQUILIZERS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define TRNYRFRQ  1 "Daily in the past 12 months"
                       2 "Almost daily or 3 to 6 days a week"
                       3 "About 1 or 2 days a week"
                       4 "Several times a month (about 25 to 51 da"
                       5 "1 to 2 times a month (12 to 24 days a ye"
                       6 "Every other month or so (6 to 11 days a"
                       7 "3 to 5 days in the past 12 months"
                       8 "1 or 2 days in the past 12 months"
                       81 "NEVER USED TRANQUILIZERS Logically assig"
                       83 "DID NOT USE TRANQUILIZER PAST 12 MOS. Lo"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED TRANQUILIZERS"
                       93 "DID NOT USE ANY TRANQUILIZER IN THE PAST"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define STMREAD   1 "Wants interviewer to continue reading"
                       2 "Wants to do it himself/herself"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define NOSTIMS   1 "Response circled" 2 "Response not circled"
                       4 "Response not circled LOGICALLY IMPUTED"
                       98 "BLANK (NO ANSWER)" ;
label define DEXED     1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define DEXAMYL   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define ESKAT     1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define BENZ      1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define BIPHET    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define DESOXYN   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define TENUATE   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define TEPANIL   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define DIDREX    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define PLEGINE   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define PRELUDIN  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define IONAMIN   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define FASTIN    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define PONDIMIN  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define VORANIL   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define SANOREX   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define MAZANOR   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define RITALIN   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define CYLERT    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define DETAMP    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define METHI     1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define METHAMP   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define OBLA      1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define STIMNEWA  301 "Dexedrine" 312 "Ionamin"
                       313 "Fastin, Phentermine"
                       322 "Methamphetamine (speed or ice or cr"
                       324 "Uppers; OTHER Stimulant, NOT SPECIFIED"
                       326 "White cross" 327 "Black beauties, Black Beauty"
                       328 "Pink hearts" 329 "Robins eggs, speckled eggs"
                       330 "Blue birds, blue jays, blue robins" 331 "Whites"
                       332 "see also 346" 333 "357 Magnum, Magnum 44"
                       334 "Crossroads, cross tops" 335 "Dexatrim"
                       336 "Diet pills"
                       339 "Amphetamines (speed generically)" 344 "Bennies"
                       345 "Black Molly" 346 "see also 332" 348 "Crystal"
                       353 "No-Doz" 354 "Vivarin" 355 "Crystal meth"
                       359 "Criss cross" 375 "sic" 376 "sic" 378 "sic"
                       423 "Percocet" 442 "Ibuprofen" 468 "Excedrin"
                       526 "Nail polish"
                       530 "Asthma inhaler, asthma med., bronchial d"
                       601 "LSD (acid, white lightning) [see als"
                       605 "PCP (angel dust, phencyclidine)" 606 "sic"
                       622 "Microdot(s), purple microdot"
                       802 "THC, cannabinol" 805 "Cocaine, coke" 809 "Pills"
                       814 "Caffeine" 815 "Coffee" 848 "Liquid vitamin"
                       851 "sic"
                       981 "NEVER USED STIMULANTS Logically assigned"
                       991 "NEVER USED STIMULANTS" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" ;
label define STIMNEWB  326 "White cross" 327 "Black beauties, Black Beauty"
                       328 "Pink hearts" 333 "357 Magnum, Magnum 44"
                       334 "Crossroads, cross tops" 348 "Crystal"
                       354 "Vivarin" 377 "Ventolin" 379 "Hearts"
                       380 "Pink ladies" 415 "Codeine" 805 "Cocaine, coke"
                       814 "Caffeine"
                       981 "NEVER USED STIMULANTS Logically assigned"
                       991 "NEVER USED STIMULANTS" 998 "BLANK (NO ANSWER)" ;
label define STIMNEWC  326 "White cross" 327 "Black beauties, Black Beauty"
                       328 "Pink hearts" 329 "Robins eggs, speckled eggs"
                       345 "Black Molly" 417 "Morphine"
                       991 "NEVER USED STIMULANTS" 998 "BLANK (NO ANSWER)" ;
label define STIMNEWD  124 "Yellow jackets" 418 "Methadone"
                       991 "NEVER USED STIMULANTS" 998 "BLANK (NO ANSWER)" ;
label define STIMNEWE  991 "NEVER USED STIMULANTS" 998 "BLANK (NO ANSWER)" ;
label define STIMNOSP  1 "Response circled" 2 "Response not circled"
                       3 "Stimulant use LOGICALLY IMPUTED"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define STMDKNAM  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define STIMAGE   981 "NEVER USED STIMULANTS Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED STIMULANTS" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" ;
label define STIMTOT   1 "1 or 2 times" 2 "3 to 5 times" 3 "6 to 10 times"
                       4 "11 to 49 times" 5 "50 to 99 times"
                       6 "100 to 199 times" 7 "200 or more times"
                       91 "NEVER USED STIMULANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define STIMREC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define STMYRFRQ  1 "Daily in the past 12 months"
                       2 "Almost daily or 3 to 6 days a week"
                       3 "About 1 or 2 days a week"
                       4 "Several times a month (about 25 to 51 da"
                       5 "1 to 2 times a month (12 to 24 days a ye"
                       6 "Every other month or so (6 to 11 days a"
                       7 "3 to 5 days in the past 12 months"
                       8 "1 or 2 days in the past 12 months"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       83 "DID NOT USE STIMULANT PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED STIMULANTS"
                       93 "DID NOT USE STIMULANT IN THE PAST 12 MON"
                       98 "BLANK (NO ANSWER)" ;
label define STNEEDLE  1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       91 "NEVER USED STIMULANTS" 98 "BLANK (NO ANSWER)" ;
label define STNDLREC  1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago but less than 10 yea"
                       6 "10 or more years ago"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       81 "NEVER USED STIMULANTS Logically assigned"
                       83 "NEVER USED AMPHETAMINES W/A NEEDLE Logic"
                       91 "NEVER USED STIMULANTS"
                       93 "NEVER USED AMPHETAMINES WITH A NEEDLE"
                       98 "BLANK (NO ANSWER)" ;
label define ANLREAD   1 "Wants interviewer to read questions"
                       2 "Wants to do it himself/herself"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define ANALNONE  1 "Response circled" 2 "Response not circled"
                       4 "Response not circled LOGICALLY IMPUTED"
                       98 "BLANK (NO ANSWER)" ;
label define DARVON    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define DOLENE    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define SK65A     1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define WYGESIC   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define LEVODRO   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define PERCODAN  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define DEMEROL   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define DILAUD    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define TYLCOD    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define PHENCOD   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define TALWIN    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define TALWINNX  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define TALACEN   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define PROPOXY   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define CODEINE   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define ANILERID  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define MORPHINE  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define METHDON   1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define STADOL    1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define ANALNEWA  140 "Seldane" 222 "USED TRANQUILIZER, DONT KNOW NAME"
                       352 "Lemons" 406 "Oxycodone, Percodan, Roxicet"
                       409 "Tylenol with Codeine, Tylenol 3, Tylenol"
                       415 "Codeine" 422 "Motrin" 423 "Percocet"
                       424 "Fioricet" 425 "Advil"
                       426 "Butalbital, Fiorinal, Phrenilin Forte"
                       427 "Darvocet" 430 "Aspirin, Ecotrin, Empirin"
                       431 "Tylox"
                       434 "Co-Gesic, Hydrocodone, Tussionex, Vicodi"
                       435 "Tylenol, Tylenol Extrastrength"
                       438 "Anaprox, Naprosyn" 439 "222, Canadian 222"
                       440 "Soma" 442 "Ibuprofen"
                       444 "Aspirin with Codeine, Empirin 3" 447 "Synalgos"
                       450 "Acetaminophen" 455 "Fiorinal with Codeine"
                       456 "see also 434" 459 "Ketamine" 462 "Norflex"
                       465 "Fentanyl" 466 "Midol" 467 "Tolectin" 702 "Heroin"
                       991 "NEVER USED ANALGESICS" 995 "BAD DATA"
                       998 "BLANK (NO ANSWER)" ;
label define ANALNEWB  222 "USED TRANQUILIZER, DONT KNOW NAME" 422 "Motrin"
                       434 "Co-Gesic, Hydrocodone, Tussionex, Vicodi"
                       435 "Tylenol, Tylenol Extrastrength"
                       991 "NEVER USED ANALGESICS" 998 "BLANK (NO ANSWER)" ;
label define ANALNEWC  991 "NEVER USED ANALGESICS" 998 "BLANK (NO ANSWER)" ;
label define ANALNEWD  991 "NEVER USED ANALGESICS" 998 "BLANK (NO ANSWER)" ;
label define ANALNEWE  991 "NEVER USED ANALGESICS" 998 "BLANK (NO ANSWER)" ;
label define ANLNOSP   1 "Response circled" 2 "Response not circled"
                       3 "Analgesic use LOGICALLY IMPUTED"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define ANLDKNAM  1 "Response circled" 2 "Response not circled"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define ANALAGE   981 "NEVER USED ANALGESICS Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED ANALGESICS" 994 "DONT KNOW"
                       998 "BLANK (NO ANSWER)" ;
label define ANALTOT   1 "1 or 2 times" 2 "3 to 5 times" 3 "6 to 10 times"
                       4 "11 to 49 times" 5 "50 to 99 times"
                       6 "100 to 199 times" 7 "200 or more times"
                       91 "NEVER USED ANALGESICS" 94 "DONT KNOW"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define ANALREC   1 "Within past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       91 "NEVER USED ANALGESICS" 98 "BLANK (NO ANSWER)" ;
label define ANLYRFRQ  1 "Daily in the past 12 months"
                       2 "Almost daily or 3 to 6 days a week"
                       3 "About 1 or 2 days a week"
                       4 "Several times a month (about 25 to 51 da"
                       5 "1 to 2 times a month (12 to 24 days a ye"
                       6 "Every other month or so (6 to 11 days a"
                       7 "3 to 5 days in the past 12 months"
                       8 "1 or 2 days in the past 12 months"
                       81 "NEVER USED ANALGESICS Logically assigned"
                       83 "DID NOT USE ANALGESICS PAST 12 MO. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANALGESICS"
                       93 "DID NOT USE ANALGESICS IN THE PAST 12 MO"
                       98 "BLANK (NO ANSWER)" ;
label define MJOPP     981 "NEVER HAD CHANCE TO TRY MARIJUANA Logic."
                       985 "BAD DATA Logically assigned"
                       991 "NEVER HAD CHANCE TO TRY MARIJUANA"
                       994 "DONT KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define MJAGE     981 "NEVER USED MARIJUANA Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED MARIJUANA" 994 "DONT KNOW"
                       998 "BLANK (NO ANSWER)" ;
label define MJTOT     1 "1 or 2 times" 2 "3 to 5 times" 3 "6 to 10 times"
                       4 "11 to 49 times" 5 "50 to 99 times"
                       6 "100 to 199 times" 7 "200 or more times"
                       81 "NEVER USED MARIJUANA Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define MJREC     1 "Within the past week (7 days)"
                       2 "More than 1 week ago but less than 1 mon"
                       3 "1 or more months ago but less than 6 mon"
                       4 "6 or more months ago but less than 1 yea"
                       5 "1 or more years ago but less than 3 year"
                       6 "3 or more years ago"
                       7 "Use in past 30 days LOGICALLY IMPUTED"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       81 "NEVER USED MARIJUANA Logically assigned"
                       91 "NEVER USED MARIJUANA" ;
label define MJDAY30A  81 "NEVER USED MARIJUANA Logically assigned"
                       83 "DID NOT USE MARIJUANA PAST 30 DAYS Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN PAST 30 DAYS"
                       94 "DONT KNOW" 95 "BAD DATA" 98 "BLANK (NO ANSWER)" ;
label define MJAV30A   81 "NEVER USED MARIJUANA Logically assigned"
                       83 "DID NOT USE MARIJUANA PAST 30 DAYS Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN PAST 30 DAYS"
                       98 "BLANK (NO ANSWER)" ;
label define MJAV30B   81 "NEVER USED MARIJUANA Logically assigned"
                       83 "DID NOT USE MARIJUANA PAST 30 DAYS Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN PAST 30 DAYS"
                       98 "BLANK (NO ANSWER)" ;
label define MJAMT30A  1 "1 to 10 joints in the past 30 days"
                       2 "11 to 20 joints in the past 30 days"
                       3 "About 1 ounce in the past 30 days"
                       4 "About 2 ounces in the past 30 days"
                       5 "3 to 4 ounces in the past 30 days"
                       6 "5 to 6 ounces in the past 30 days"
                       8 "8 ounces in the past 30 days"
                       77 "More than 6 oz. exact amt not spec. in p"
                       81 "NEVER USED MARIJUANA Logically assigned"
                       83 "DID NOT USE MARIJUANA PAST 30 DAYS Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN PAST 30 DAYS"
                       94 "DONT KNOW" 98 "BLANK (NO ANSWER)" ;
label define MJFRIEND  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED MARIJUANA Logically assigned"
                       83 "DID NOT USE MARIJUANA PST 30 DAYS Logic."
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN PAST 30 DAYS"
                       97 "REFUSED" ;
label define MJDEALER  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED MARIJUANA Logically assigned"
                       83 "DID NOT USE MARIJUANA PST 30 DAYS Logic."
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN PAST 30 DAYS"
                       97 "REFUSED" ;
label define MJOTHSHR  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED MARIJUANA Logically assigned"
                       83 "DID NOT USE MARIJUANA PST 30 DAYS Logic."
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN PAST 30 DAYS"
                       97 "REFUSED" ;
label define MJGIVEN   1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED MARIJUANA Logically assigned"
                       83 "DID NOT USE MARIJUANA PST 30 DAYS Logic."
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN PAST 30 DAYS"
                       97 "REFUSED" ;
label define MJTRGOOD  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED MARIJUANA Logically assigned"
                       83 "DID NOT USE MARIJUANA PST 30 DAYS Logic."
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN PAST 30 DAYS"
                       97 "REFUSED" ;
label define MJTRSERV  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED MARIJUANA Logically assigned"
                       83 "DID NOT USE MARIJUANA PST 30 DAYS Logic."
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN PAST 30 DAYS"
                       97 "REFUSED" ;
label define MJSTOLE   1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED MARIJUANA Logically assigned"
                       83 "DID NOT USE MARIJUANA PST 30 DAYS Logic."
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN PAST 30 DAYS"
                       97 "REFUSED" ;
label define MJTRICK   1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED MARIJUANA Logically assigned"
                       83 "DID NOT USE MARIJUANA PST 30 DAYS Logic."
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN PAST 30 DAYS"
                       97 "REFUSED" ;
label define MJOBTNON  2 "Response not circled"
                       81 "NEVER USED MARIJUANA Logically assigned"
                       83 "DID NOT USE MARIJUANA PST 30 DAYS Logic."
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN PAST 30 DAYS"
                       97 "REFUSED" ;
label define MJBUCK    .0000 "Did not spend any money on marijuana pst"
                       9981.0000 "NEVER USED MARIJUANA Logically assigned"
                       9983.0000 "DID NOT USE MARIJUANA PST 30 DAYS Logic."
                       9985.0000 "BAD DATA Logically assigned"
                       9991.0000 "NEVER USED MARIJUANA"
                       9993.0000 "DID NOT USE MARIJUANA IN THE PAST 30 DAY"
                       9994.0000 "DONT KNOW" 9997.0000 "REFUSED"
                       9998.0000 "BLANK (NO ANSWER)" ;
label define MJYRFREQ  1 "Several times a day in the past 12 month"
                       2 "Daily in the past 12 months"
                       3 "Almost daily or 3 to 6 days a week"
                       4 "1 or 2 days a week"
                       5 "Several times a month (about 25 to 51 da"
                       6 "1 to 2 times a month (12 to 24 days a ye"
                       7 "Every other month or so (6 to 11 days a"
                       8 "3 to 5 days in the past 12 months"
                       9 "1 or 2 days in the past 12 months"
                       81 "NEVER USED MARIJUANA Logically assigned"
                       83 "DID NOT USE MARIJUANA PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN PAST 12 MONTHS"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define MJJOINT   1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED MARIJUANA Logically assigned"
                       83 "DID NOT USE MARIJUANA PAST 12 MOS. Logic"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MON" ;
label define MJPIPE    1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED MARIJUANA Logically assigned"
                       83 "DID NOT USE MARIJUANA PAST 12 MOS. Logic"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MON" ;
label define MJBAKE    1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED MARIJUANA Logically assigned"
                       83 "DID NOT USE MARIJUANA PAST 12 MOS. Logic"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MON" ;
label define MJCHEW    1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED MARIJUANA Logically assigned"
                       83 "DID NOT USE MARIJUANA PAST 12 MOS. Logic"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MON" ;
label define MJWAY     1 "Response circled, method not specified"
                       2 "Response not circled"
                       4 "PST 30 DAY OR PST 12 MTH MJ USER W/NO Q."
                       6 "Can with holes/in a bowl" 7 "One hitter"
                       8 "Boiled with tea"
                       9 "Smoky small room(burn in small room like"
                       10 "Knifa hits" 11 "Shot gun"
                       12 "Chewing/eating/suck on stems" 17 "Blunts"
                       19 "With cocaine" 24 "Drank it"
                       25 "Hash under glass/can, glass bottle"
                       27 "Smoked in Phillies" 28 "In tobacco paper"
                       29 "Eat roaches" 30 "Hash" 31 "Joint" 32 "Pipe"
                       81 "NEVER USED MARIJUANA Logically assigned"
                       83 "DID NOT USE MARIJUANA PAST 12 MOS. Logic"
                       91 "NEVER USED MARIJUANA"
                       93 "DID NOT USE MARIJUANA IN THE PAST 12 MON" ;
label define MJLFDALY  1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED (from UDAYMJ)"
                       81 "NEVER USED MARIJUANA Logically assigned"
                       91 "NEVER USED MARIJUANA" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define INHREAD   1 "Wants interviewer to read questions"
                       2 "Wants to do it himself/herself"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define GAS       1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED (from"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define LGAS      1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED (from"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define SPPAINT   1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED (frm"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define AEROS     1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED (frm"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define GLUE      1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define SOLVENT   1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED (frm"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define AMYLNIT   1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED (frm"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define ETHER     1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED (frm"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define NITOXID   1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED (frm"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define CLEFLU    1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED (frm"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define INHNEWA   304 "Benzedrine"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       503 "Other aerosol sprays"
                       504 "Shoeshine liq, glue,toluene,Super Glue,r"
                       506 "Amyl nitrite, poppers, locker rm odori"
                       507 "Halothane, ether, or other anesthetics;"
                       508 "Nitrous oxide, whippets, dentist gas"
                       509 "Corr flds, degreasers, cleaning flds, Li"
                       511 "Markers, felt-tip pens, ink pens" 512 "Incense"
                       514 "sic" 515 "Vicks" 516 "Freon"
                       518 "Acetone, nail polish remover" 519 "Helium"
                       524 "see also 509" 525 "see also 521,544"
                       526 "Nail polish" 528 "Whipped-cream can"
                       539 "ScotchGard" 540 "PAM" 542 "Spirits of ammonia"
                       545 "Car tailpipe exhaust fumes, CO2" 547 "sic"
                       548 "Cologne, rubbing alcohol" 549 "sic"
                       550 "Methyl chloride" 551 "sic" 552 "sic"
                       553 "Pixie sticks" 554 "Raid" 702 "Heroin" 803 "sic"
                       805 "Cocaine, coke"
                       807 "Alcohol, beer, ethanol, EtOH, pink champ"
                       816 "Smokeless tobacco, snuff, chewing tobacc"
                       852 "sic"
                       981 "NEVER USED INHALANTS Logically assigned"
                       991 "NEVER USED INHALANTS" 995 "BAD DATA"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define INHNEWB   322 "Methamphetamine (speed or ice or cr"
                       339 "Amphetamines (speed generically)"
                       503 "Other aerosol sprays"
                       504 "Shoeshine liq, glue,toluene,Super Glue,r"
                       505 "Lacquer thinner or other paint solvents"
                       508 "Nitrous oxide, whippets, dentist gas"
                       509 "Corr flds, degreasers, cleaning flds, Li"
                       518 "Acetone, nail polish remover" 524 "see also 509"
                       526 "Nail polish" 531 "Candy, powdered candy"
                       542 "Spirits of ammonia" 546 "Leather protector"
                       553 "Pixie sticks" 804 "Hashish"
                       981 "NEVER USED INHALANTS Logically assigned"
                       991 "NEVER USED INHALANTS" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" ;
label define INHNEWC   322 "Methamphetamine (speed or ice or cr"
                       518 "Acetone, nail polish remover" 806 "Crack, rock"
                       981 "NEVER USED INHALANTS Logically assigned"
                       991 "NEVER USED INHALANTS" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" ;
label define INHNEWD   981 "NEVER USED INHALANTS Logically assigned"
                       991 "NEVER USED INHALANTS" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" ;
label define INHNEWE   981 "NEVER USED INHALANTS Logically assigned"
                       991 "NEVER USED INHALANTS" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" ;
label define INHNOSP   1 "Response circled" 2 "Response not circled"
                       3 "Inhalant use LOGICALLY IMPUTED"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define INHDKNAM  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define INHAGE    981 "NEVER USED INHALANTS Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED INHALANTS" 994 "DONT KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define INHTOT    1 "1 or 2 times" 2 "3 to 5 times" 3 "6 to 10 times"
                       4 "11 to 49 times" 5 "50 to 99 times"
                       6 "100 to 199 times" 7 "200 or more times"
                       81 "NEVER USED INHALANTS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define INHREC    1 "Within the past week (7 days)"
                       2 "More than 1 week ago but less than 1 mon"
                       3 "1 or more months ago but less than 6 mon"
                       4 "6 or more months ago but less than 1 yea"
                       5 "1 or more years ago but less than 3 year"
                       6 "3 or more years ago"
                       7 "Use in past 30 days LOGICALLY IMPUTED"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define GAS30A    1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED INHALANTS Logically assigned"
                       83 "DID NOT USE INHALANT PAST 30 DAYS Logic."
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANT IN PAST 30 DAYS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define LGAS30A   1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED INHALANTS Logically assigned"
                       83 "DID NOT USE INHALANT PAST 30 DAYS Logic."
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANT IN PAST 30 DAYS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define SPPAN30A  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED INHALANTS Logically assigned"
                       83 "DID NOT USE INHALANT PAST 30 DAYS Logic."
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANT IN PAST 30 DAYS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define AEROS30A  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED INHALANTS Logically assigned"
                       83 "DID NOT USE INHALANT PAST 30 DAYS Logic."
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANT IN PAST 30 DAYS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define GLUE30A   1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED INHALANTS Logically assigned"
                       83 "DID NOT USED INHALANT PAST 30 DAYS Logic"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANT IN PAST 30 DAYS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define SOLVN30A  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED INHALANTS Logically assigned"
                       83 "DID NOT USE INHALANT PAST 30 DAYS Logic."
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANT IN PAST 30 DAYS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define AMLNT30A  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED INHALANTS Logically assigned"
                       83 "DID NOT USE INHALANT PAST 30 DAYS Logic."
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANT IN PAST 30 DAYS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define ETHER30A  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED INHALANTS Logically assigned"
                       83 "DID NOT USED INHALANT PAST 30 DAYS Logic"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANT IN PAST 30 DAYS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define NOX30A    1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED INHALANTS Logically assigned"
                       83 "DID NOT USE INHALANT PAST 30 DAYS Logic."
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANT IN PAST 30 DAYS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define CLFL30A   1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED INHALANTS Logically assigned"
                       83 "DID NOT USE INHALANT PAST 30 DAYS Logic."
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANT IN PAST 30 DAYS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define INNEW30A  504 "Shoeshine liq, glue,toluene,Super Glue,r"
                       511 "Markers, felt-tip pens, ink pens" 516 "Freon"
                       524 "see also 509" 528 "Whipped-cream can"
                       539 "ScotchGard" 548 "Cologne, rubbing alcohol"
                       805 "Cocaine, coke"
                       807 "Alcohol, beer, ethanol, EtOH, pink champ"
                       981 "NEVER USED INHALANTS Logically assigned"
                       983 "DID NOT USE INHALANTS PAST 30 DAYS Logic"
                       991 "NEVER USED INHALANTS"
                       993 "DID NOT USE INHALANTS IN PAST 30 DAYS"
                       995 "BAD DATA" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define INNEW30B  509 "Corr flds, degreasers, cleaning flds, Li"
                       981 "NEVER USED INHALANTS Logically assigned"
                       983 "DID NOT USE INHALANTS PAST 30 DAYS Logic"
                       991 "NEVER USED INHALANTS"
                       993 "DID NOT USE INHALANTS PAST 30 DAYS" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" ;
label define INNEW30C  981 "NEVER USED INHALANTS Logically assigned"
                       983 "DID NOT USE INHALANTS PAST 30 DAYS Logic"
                       991 "NEVER USED INHALANTS"
                       993 "DID NOT USE INHALANTS IN PAST 30 DAYS"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define INNEW30D  981 "NEVER USED INHALANTS Logically assigned"
                       983 "DID NOT USE INHALANTS PAST 30 DAYS Logic"
                       991 "NEVER USED INHALANTS"
                       993 "DID NOT USE INHALANTS PAST 30 DAYS" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" ;
label define INNEW30E  981 "NEVER USED INHALANTS Logically assigned"
                       983 "DID NOT USE INHALANTS PAST 30 DAYS Logic"
                       991 "NEVER USED INHALANTS"
                       993 "DID NOT USE INHALANTS IN PAST 30 DAYS"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define IN30NOSP  1 "Response circled" 2 "Response not circled"
                       3 "Inhalant use LOGICALLY IMPUTED"
                       81 "NEVER USED INHALANTS Logically assigned"
                       83 "DID NOT USE INHALANT PAST 30 DAYS Logic."
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANT IN PAST 30 DAYS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define INH30NO   1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED"
                       4 "Response not circled LOGICALLY IMPUTED"
                       81 "NEVER USED INHALANTS Logically assigned"
                       91 "NEVER USED INHALANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define INHDY30A  81 "NEVER USED INHALANTS Logically assigned"
                       83 "DID NOT USE INHALANTS PAST 30 DAYS Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANT IN PAST 30 DAYS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define INHYRFRQ  1 "Daily in the past 12 months"
                       2 "Almost daily or 3 to 6 days a week"
                       3 "About 1 or 2 days a week"
                       4 "Several times a month (about 25 to 51 da"
                       5 "1 to 2 times a month (12 to 24 days a ye"
                       6 "Every other month or so (6 to 11 days a"
                       7 "3 to 5 days in the past 12 months"
                       8 "1 or 2 days in the past 12 months"
                       81 "NEVER USED INHALANTS Logically assigned"
                       83 "DID NOT USE INHALANT PAST 12 MOS. Logic."
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS"
                       93 "DID NOT USE INHALANT IN THE PAST 12 MONT"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define INHPO     1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       81 "NEVER USED INHALANTS Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED INHALANTS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define INHQNC1   1 "QUESTION 1 NOT CLEAR" 98 "BLANK (NO ANSWER)" ;
label define INHQNC2   2 "QUESTION 2 NOT CLEAR" 98 "BLANK (NO ANSWER)" ;
label define INHQNC3   3 "QUESTION 3 NOT CLEAR" 98 "BLANK (NO ANSWER)" ;
label define INHQNC4   4 "QUESTION 4 NOT CLEAR" 98 "BLANK (NO ANSWER)" ;
label define INHQNC5   5 "QUESTION 5 NOT CLEAR" 98 "BLANK (NO ANSWER)" ;
label define INHQNC6   6 "QUESTION 6 NOT CLEAR" 98 "BLANK (NO ANSWER)" ;
label define INHQNC7   7 "QUESTION 7 NOT CLEAR" 98 "BLANK (NO ANSWER)" ;
label define INHQNC8   8 "QUESTION 8 NOT CLEAR" 98 "BLANK (NO ANSWER)" ;
label define INHQNC10  10 "ALL QUESTIONS WERE CLEAR" 98 "BLANK (NO ANSWER)" ;
label define INHANSY   1 "Yes" 2 "No" 96 "MULTIPLE RESPONSE"
                       98 "BLANK (NO ANSWER)" ;
label define COCOPP    981 "NEVER HAD A CHANCE TO TRY COCAINE Logic."
                       985 "BAD DATA Logically assigned"
                       991 "NEVER HAD A CHANCE TO TRY COCAINE IN ANY"
                       994 "DONT KNOW" 998 "BLANK (NO ANSWER)" ;
label define COCAGE    981 "NEVER USED COCAINE Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED COCAINE" 994 "DONT KNOW"
                       998 "BLANK (NO ANSWER)" ;
label define COCTOT    1 "1 or 2 times" 2 "3 to 5 times" 3 "6 to 10 times"
                       4 "11 to 49 times" 5 "50 to 99 times"
                       6 "100 to 199 times" 7 "200 or more times"
                       81 "NEVER USED COCAINE Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE" 94 "DONT KNOW"
                       98 "BLANK (NO ANSWER)" ;
label define COCREC    1 "Within the past week (7 days)"
                       2 "More than 1 week ago but less than 1 mon"
                       3 "1 or more months ago but less than 6 mon"
                       4 "6 or more months ago but less than 1 yea"
                       5 "1 or more years ago but less than 3 year"
                       6 "3 or more years ago"
                       7 "Use in past 30 days LOGICALLY IMPUTED"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       81 "NEVER USED COCAINE Logically assigned"
                       91 "NEVER USED COCAINE" ;
label define COCUS30A  81 "NEVER USED COCAINE Logically assigned"
                       83 "DID NOT USE COCAINE IN PAST 30 DAYS Logi"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 30 DAYS"
                       94 "DONT KNOW" 98 "BLANK (NO ANSWER)" ;
label define COCAM30A  1 "Used some but less than 1/4 gram in past"
                       2 "About 1/4 gram in the past 30 days"
                       3 "About 1/2 gram in the past 30 days"
                       4 "About 1 gram in the past 30 days"
                       5 "About 2 grams in the past 30 days"
                       6 "About 3 grams in the past 30 days"
                       9 "About 6 grams in the past 30 days"
                       11 "About 8 grams in the past 30 days"
                       13 "About 10 grams in the past 30 days"
                       16 "About 13 grams in the past 30 days"
                       18 "About 15 grams in the past 30 days"
                       77 "More than 3 grams exact amt not spec. ps"
                       81 "NEVER USED COCAINE Logically assigned"
                       83 "DID NOT USE COCAINE IN PAST 30 DAYS Logi"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 30 DAYS"
                       94 "DONT KNOW" 98 "BLANK (NO ANSWER)" ;
label define CCFRIEND  1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED (frm"
                       81 "NEVER USED COCAINE Logically assigned"
                       83 "DID NOT USE COCAINE PST 30 DAYS Logicall"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 30 DAYS" 97 "REFUSED" ;
label define CCDEALER  1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED (frm"
                       81 "NEVER USED COCAINE Logically Assigned"
                       83 "DID NOT USE COCAINE PST 30 DAYS Logicall"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 30 DAYS" 97 "REFUSED" ;
label define CCOTHSHR  1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED (frm"
                       81 "NEVER USED COCAINE Logically assigned"
                       83 "DID NOT USE COCAINE PST 30 DAYS Logicall"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 30 DAYS" 97 "REFUSED" ;
label define CCGIVEN   1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED (frm"
                       81 "NEVER USED COCAINE Logically Assigned"
                       83 "DID NOT USE COCAINE PST 30 DAYS Logicall"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 30 DAYS" 97 "REFUSED" ;
label define CCTRGOOD  1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED (frm"
                       81 "NEVER USED COCAINE Logically assigned"
                       83 "DID NOT USE COCAINE PST 30 DAYS Logicall"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PST 30 DAYS Logic"
                       97 "REFUSED" ;
label define CCTRSERV  1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED (frm"
                       81 "NEVER USED COCAINE Logically assigned"
                       83 "DID NOT USE COCAINE PST 30 DAYS Logicall"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PST 30 DAYS Logic"
                       97 "REFUSED" ;
label define CCSTOLE   1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED (from"
                       81 "NEVER USED COCAINE Logically assigned"
                       83 "DID NOT USE COCAINE PST 30 DAYS Logicall"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 30 DAYS" 97 "REFUSED" ;
label define CCTRICK   1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED (frm"
                       81 "NEVER USED COCAINE Logically assigned"
                       83 "DID NOT USE COCAINE PST 30 DAYS Logicall"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PST 30 DAYS" 97 "REFUSED" ;
label define CCOBTNON  2 "Response not circled"
                       81 "NEVER USED COCAINE Logically assigned"
                       83 "DID NOT USE COCAINE PST 30 DAYS Logicall"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 30 DAYS" 97 "REFUSED" ;
label define COCBUCK   0 "Did not spend any money on cocaine pst 3"
                       9981 "NEVER USED COCAINE Logically assigned"
                       9983 "DID NOT USE COCAINE PAST 30 DAYS Logic.a"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED COCAINE"
                       9993 "DID NOT USE COCAINE IN PAST 30 DAYS"
                       9994 "DONT KNOW" 9997 "REFUSED"
                       9998 "BLANK (NO ANSWER)" ;
label define COCYRFRQ  1 "Daily in the past 12 months"
                       2 "Almost daily or 3 to 6 days a week"
                       3 "About 1 or 2 days a week"
                       4 "Several times a month (about 25 to 51 da"
                       5 "1 to 2 times a month (12 to 24 days a ye"
                       6 "Every other month or so (6 to 11 days a"
                       7 "3 to 5 days in the past 12 months"
                       8 "1 or 2 days in the past 12 months"
                       81 "NEVER USED COCAINE Logically assigned"
                       83 "DID NOT USE COCAINE IN PAST 12 MONTHS Lo"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 12 MONTHS"
                       98 "BLANK (NO ANSWER)" ;
label define COCSNIFF  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED COCAINE Logically assigned"
                       83 "DID NOT USE COCAINE PAST 12 MOS Logicall"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 12 MONTHS" ;
label define COCSWAL   1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED COCAINE Logically assigned"
                       83 "DID NOT USE COCAINE PAST 12 MOS Logicall"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 12 MONTHS" ;
label define COCIV     1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED (frm"
                       81 "NEVER USED COCAINE Logically assigned"
                       83 "DID NOT USE COCAINE PAST 12 MOS Logicall"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 12 MONTHS" ;
label define FREEBASE  1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED (frm"
                       81 "NEVER USED COCAINE Logically assigned"
                       83 "DID NOT USE COCAINE PAST 12 MOS Logicall"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 12 MONTHS" ;
label define COCWAY    1 "Response circled, method not specified"
                       2 "Response not circled"
                       4 "PST 3O DAYS OR PST 12 MTH COC USR W/NO Q"
                       7 "On my gums/mouth" 8 "Freeze, put on tongue"
                       9 "Smoked in a cigarette/Snowcap"
                       10 "Laced with marijuana"
                       11 "Smoked using aluminum foil"
                       81 "NEVER USED COCAINE Logically assigned"
                       83 "DID NOT USE COCAINE PAST 12 MOS Logicall"
                       91 "NEVER USED COCAINE"
                       93 "DID NOT USE COCAINE IN PAST 12 MONTHS"
                       95 "BAD DATA" ;
label define CONDLREC  1 "Within past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago but less than 10 yea"
                       6 "10 or more years ago"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       81 "NEVER USED COCAINE Logically assigned"
                       83 "USED COCAINE BUT NEVER W/A NEEDLE Logic."
                       91 "NEVER USED COCAINE"
                       93 "USED COCAINE BUT NEVER W/A NEEDLE"
                       98 "BLANK (NO ANSWER)" ;
label define CCLFDALY  1 "Yes" 2 "No"
                       3 "Yes LOGICALLY IMPUTED (from UDAYCOC)"
                       81 "NEVER USED COCAINE Logically assigned"
                       91 "NEVER USED COCAINE" 95 "BAD DATA"
                       98 "BLANK (NO ANSWER)" ;
label define CRAKREC   1 "Within the past week (7 days)"
                       2 "More than 1 week ago but less than 1 mon"
                       3 "1 or more months ago but less than 6 mon"
                       4 "6 or more months ago but less than 1 yea"
                       5 "1 or more years ago but less than 3 year"
                       6 "3 or more years ago"
                       7 "Use in past 30 days LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       81 "NEVER USED CRACK Logically assigned"
                       91 "NEVER USED CRACK" 97 "REFUSED" ;
label define CRKAM30A  981 "NEVER USED CRACK Logically assigned"
                       983 "DID NOT USE CRACK IN PAST 30 DAYS Logi"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED CRACK"
                       993 "DID NOT USE CRACK IN PAST 30 DAYS"
                       994 "DONT KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define CKFRIEND  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED CRACK Logically assigned"
                       83 "DID NOT USE CRACK PST 30 DAYS Logicall"
                       85 "BAD DATA Logically assigned" 91 "NEVER USED CRACK"
                       93 "DID NOT USE CRACK IN PAST 30 DAYS" 97 "REFUSED" ;
label define CKDEALER  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED CRACK Logically assigned"
                       83 "DID NOT USE CRACK PST 30 DAYS Logicall"
                       85 "BAD DATA Logically assigned" 91 "NEVER USED CRACK"
                       93 "DID NOT USE CRACK IN PAST 30 DAYS" 97 "REFUSED" ;
label define CKOTHSHR  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED CRACK Logically assigned"
                       83 "DID NOT USE CRACK PST 30 DAYS Logicall"
                       85 "BAD DATA Logically assigned" 91 "NEVER USED CRACK"
                       93 "DID NOT USE CRACK IN PAST 30 DAYS" 97 "REFUSED" ;
label define CKGIVEN   1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED CRACK Logically assigned"
                       83 "DID NOT USE CRACK PST 30 DAYS Logicall"
                       85 "BAD DATA Logically assigned" 91 "NEVER USED CRACK"
                       93 "DID NOT USE CRACK IN PST 30 DAYS" 97 "REFUSED" ;
label define CKTRGOOD  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED CRACK Logically assigned"
                       83 "DID NOT USE CRACK PST 30 DAYS Logicall"
                       85 "BAD DATA Logically assigned" 91 "NEVER USED CRACK"
                       93 "DID NOT USE CRACK IN PAST 30 DAYS" 97 "REFUSED" ;
label define CKTRSERV  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED CRACK Logically assigned"
                       83 "DID NOT USE CRACK PST 30 DAYS Logicall"
                       85 "BAD DATA Logically assigned" 91 "NEVER USED CRACK"
                       93 "DID NOT USE CRACK IN PAST 30 DAYS" 97 "REFUSED" ;
label define CKSTOLE   1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED CRACK Logically assigned"
                       83 "DID NOT USE CRACK PST 30 DAYS Logicall"
                       85 "BAD DATA Logically assigned" 91 "NEVER USED CRACK"
                       93 "DID NOT USE CRACK IN PAST 30 DAYS" 97 "REFUSED" ;
label define CKTRICK   1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED CRACK Logically assigned"
                       83 "DID NOT USE CRACK PST 30 DAYS Logicall"
                       85 "BAD DATA Logically assigned" 91 "NEVER USED CRACK"
                       93 "DID NOT USE CRACK IN PAST 30 DAYS" 97 "REFUSED" ;
label define CKOBTNON  2 "Response not circled"
                       81 "NEVER USED CRACK Logically assigned"
                       83 "DID NOT USE CRACK PST 30 DAYS Logicall"
                       85 "BAD DATA Logically assigned" 91 "NEVER USED CRACK"
                       93 "DID NOT USE CRACK IN PAST 30 DAYS" 97 "REFUSED" ;
label define CRAKBUCK  0 "Did not spend any money on crack pst 3"
                       9981 "NEVER USED CRACK Logically assigned"
                       9983 "DID NOT USE CRACK PAST 30 DAYS Logic.a"
                       9985 "BAD DATA Logically assigned"
                       9991 "NEVER USED CRACK"
                       9993 "DID NOT USE CRACK IN PAST 30 DAYS"
                       9997 "REFUSED" 9998 "BLANK (NO ANSWER)" ;
label define CKLFDALY  1 "Yes" 2 "No"
                       81 "NEVER USED CRACK Logically assigned"
                       91 "NEVER USED CRACK" 95 "BAD DATA" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define HALREAD   1 "Wants interviewer to continue reading"
                       2 "Wants to do it himself/herself"
                       3 "Wants interviewer to continue LOGICALLY"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define LSD       1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED HALLUCINOGENS Logically assig"
                       91 "NEVER USED HALLUCINOGENS" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define PEYOTE    1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED HALLUCINOGENS Logically assig"
                       91 "NEVER USED HALLUCINOGENS" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define MESC      1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED HALLUCINOGENS Logically assig"
                       91 "NEVER USED HALLUCINOGENS" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define PSILCY    1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED HALLUCINOGENS Logically assig"
                       91 "NEVER USED HALLUCINOGENS" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define PCP       1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED (frm"
                       81 "NEVER USED HALLUCINOGENS Logically assig"
                       91 "NEVER USED HALLUCINOGENS" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ECSTASY   1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED HALLUCINOGENS Logically assig"
                       91 "NEVER USED HALLUCINOGENS" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HALNEWA   245 "Tryptophan"
                       322 "Methamphetamine (speed or ice or cr"
                       326 "White cross" 336 "Diet pills"
                       339 "Amphetamines (speed generically)"
                       342 "Purple hearts" 522 "Liquid TV (MTV), TV tuner"
                       537 "Boat horn"
                       601 "LSD (acid, white lightning) [see als"
                       604 "Psilocybin (mushrooms)"
                       605 "PCP (angel dust, phencyclidine)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 609 "sic"
                       612 "Happy stick, sherm, shermstick" 614 "MDA"
                       616 "DMT" 617 "Morning glory seeds"
                       622 "Microdot(s), purple microdot"
                       623 "Mickey Mouse club, Mickey Mousers" 624 "O"
                       625 "Window pane" 636 "STP" 638 "sic" 639 "Nutmeg"
                       640 "Purple pyramid" 641 "sic" 644 "Spanish"
                       645 "Thai stick" 647 "sic"
                       701 "OTHER Opiates, NOT SPECIFIED" 703 "Opium"
                       802 "THC, cannabinol"
                       981 "NEVER USED HALLUCINOGENS Logically assig"
                       991 "NEVER USED HALLUCINOGENS" 994 "DONT KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define HALNEWB   601 "LSD (acid, white lightning) [see als" 609 "sic"
                       616 "DMT" 621 "Red dragon"
                       622 "Microdot(s), purple microdot" 624 "O" 636 "STP"
                       643 "Queen" 803 "sic" 804 "Hashish"
                       981 "NEVER USED HALLUCINOGENS Logically assig"
                       991 "NEVER USED HALLUCINOGENS" 994 "DONT KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define HALNEWC   618 "Acid paper, blotter (acid) [see also 601"
                       622 "Microdot(s), purple microdot" 642 "Pink Floyd"
                       646 "sic"
                       981 "NEVER USED HALLUCINOGENS Logically assig"
                       991 "NEVER USED HALLUCINOGENS" 994 "DONT KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define HALNEWD   981 "NEVER USED HALLUCINOGENS Logically assig"
                       991 "NEVER USED HALLUCINOGENS" 994 "DONT KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define HALNEWE   981 "NEVER USED HALLUCINOGENS Logically assig"
                       991 "NEVER USED HALLUCINOGENS" 994 "DONT KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define HALNOSP   1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED"
                       81 "NEVER USED HALLUCINOGENS Logically assig"
                       91 "NEVER USED HALLUCINOGENS" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HALDKNAM  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED HALLUCINOGENS Logically assig"
                       91 "NEVER USED HALLUCINOGENS" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HALLOPP   981 "NEVER HAD A CHANCE TO TRY HALLUCINOGENS"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER HAD A CHANCE TO TRY HALLUCINOGENS"
                       994 "DONT KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define HALLAGE   981 "NEVER USED HALLUCINOGENS Logically assig"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED HALLUCINOGENS" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" ;
label define HALLTOT   1 "1 or 2 times" 2 "3 to 5 times" 3 "6 to 10 times"
                       4 "11 to 49 times" 5 "50 to 99 times"
                       6 "100 to 199 times" 7 "200 or more times"
                       81 "NEVER USED HALLUCINOGENS Logically assig"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HALLUCINOGENS" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HALLREC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago"
                       7 "Use in past 30 days LOGICALLY IMPUTED"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       81 "NEVER USED HALLUCINOGENS Logically assig"
                       91 "NEVER USED HALLUCINOGENS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define HAL30USE  81 "NEVER USED HALLUCINOGENS Logically assig"
                       83 "DID NOT USE HALLUCINOGENS PST 30 DAYS Lo"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HALLUCINOGENS"
                       93 "DID NOT USE HALLUCINOGENS IN THE PAST 30"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HALYRFRQ  1 "Daily in the past 12 months"
                       2 "Almost daily or 3 to 6 days a week"
                       3 "About 1 or 2 days a week"
                       4 "Several times a month (about 25 to 51 da"
                       5 "1 to 2 times a month (12 to 24 days a ye"
                       6 "Every other month or so (6 to 11 days a"
                       7 "3 to 5 days in the past 12 months"
                       8 "1 or 2 days in the past 12 months"
                       81 "NEVER USED HALLUCINOGENS Logically assig"
                       83 "DID NOT USE HALLUCINOGENS PST 12 MOS. Lo"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HALLUCINOGENS"
                       93 "DID NOT USE HALLUCINOGENS IN THE PST 12"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define PCPREC    1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       81 "NEVER USED PCP Logically assigned"
                       91 "NEVER USED PCP" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define HERREAD   1 "Wants interviewer to continue reading"
                       2 "Wants to do it himself/herself"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define HEROPP    981 "NEVER HAD A CHANCE TO TRY HEROIN Logic.a"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER HAD A CHANCE TO TRY HEROIN" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" ;
label define HERAGE    981 "NEVER USED HEROIN Logically assigned"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED HEROIN" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" ;
label define HERTOT    1 "1 or 2 times" 2 "3 to 5 times" 3 "6 to 10 times"
                       4 "11 to 49 times" 5 "50 to 99 times"
                       6 "100 to 199 times" 7 "200 or more times"
                       81 "NEVER USED HEROIN Logically assigned"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED HEROIN" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define HERREC    1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago"
                       7 "Use in past 30 days LOGICALLY IMPUTED"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       81 "NEVER USED HEROIN Logically assigned"
                       91 "NEVER USED HEROIN" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define HER30USE  81 "NEVER USED HEROIN Logically assigned"
                       83 "DID NOT USE HEROIN PAST 30 DAYS Logic.as"
                       91 "NEVER USED HEROIN"
                       93 "DID NOT USE HEROIN IN THE PAST 30 DAYS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HERNEEDL  1 "Yes, have used heroin with a needle"
                       2 "No, have used heroin, but not with a nee"
                       3 "Yes, used heroin w/a needle LOGICALLY IM"
                       4 "No, used heroin, but w/o a needle LOGIC."
                       81 "NEVER USED HEROIN Logically assigned"
                       91 "NEVER USED HEROIN" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define HRNDLREC  1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago but less than 10 yea"
                       6 "10 or more years ago"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       81 "NEVER USED HEROIN Logically assigned"
                       83 "NEVER USED HEROIN WITH A NEEDLE Logicall"
                       91 "NEVER USED HEROIN"
                       93 "NEVER USED HEROIN WITH A NEEDLE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define DRGREAD   1 "Wants interviewer to continue reading"
                       2 "Wants to do it himself/herself"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define CDCIG     1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED (from"
                       13 "Did not try to cut down on any drug in p"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CDALC     1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED (frm"
                       13 "Did not try to cut down on any drug in p"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CDSED     1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED (frm"
                       13 "Did not try to cut down on any drug in p"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CDTRAN    1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED (Frm"
                       13 "Did not try to cut down on any drug in p"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CDSTM     1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in p"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CDANAL    1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED (frm"
                       13 "Did not try to cut down on any drug in p"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CDMJ      1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in p"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CDINH     1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED (frm"
                       13 "Did not try to cut down on any drug in p"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CDCOC     1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in p"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CDHALL    1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED (frm"
                       13 "Did not try to cut down on any drug in p"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CDHER     1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in p"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CDOTHOP   1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED (frm"
                       13 "Did not try to cut down on any drug in p"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CDNONE    1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UCDCIG    1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in p"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUG PAST 12 MOS. Logic."
                       85 "BAD DATA Logically assigned (CDCIG > 1)"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUG IN THE PAST 12 MONT"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UCDALC    1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in p"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUG PAST 12 MOS. Logic."
                       85 "BAD DATA Logically assigned (CDALC > 1)"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUG IN THE PAST 12 MONT"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UCDSED    1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in p"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUG PAST 12 MOS. Logic."
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUG IN THE PAST 12 MONT"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UCDTRAN   1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in p"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUG PAST 12 MOS. Logic."
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUG IN THE PAST 12 MONT"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UCDSTM    1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in p"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUG PAST 12 MOS. Logic."
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUG IN THE PAST 12 MONT"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UCDANAL   1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in p"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUG PAST 12 MOS. Logic."
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUG IN THE PAST 12 MONT"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UCDMJ     1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in p"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUG PAST 12 MOS. Logic."
                       85 "BAD DATA Logically assigned (CDMJ > 1)"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUG IN THE PAST 12 MONT"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UCDINH    1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in p"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUG PAST 12 MOS. Logic."
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUG IN THE PAST 12 MONT"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UCDCOC    1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in p"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUG PAST 12 MOS. Logic."
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUG IN THE PAST 12 MONT"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UCDHALL   1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in p"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUG PAST 12 MOS. Logic."
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUG IN THE PAST 12 MONT"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UCDHER    1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in p"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUG PAST 12 MOS. Logic."
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUG IN THE PAST 12 MONT"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UCDOTHOP  1 "Response circled" 2 "Response not circled"
                       13 "Did not try to cut down on any drug in p"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUG PAST 12 MOS. Logic."
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUG IN THE PAST 12 MONT"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UCDNONE   1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUG PAST 12 MOS. Logic."
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUG IN THE PAST 12 MONT"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define EFFCIG    1 "Response circled" 2 "Response not circled"
                       13 "Did not need more of any drug used for s"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define EFFALC    1 "Response circled" 2 "Response not circled"
                       13 "Did not need more of any drug used for s"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define EFFSED    1 "Response circled" 2 "Response not circled"
                       13 "Did not need more of any drug used for s"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define EFFTRAN   1 "Response circled" 2 "Response not circled"
                       13 "Did not need more of any drug used for s"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define EFFSTM    1 "Response circled" 2 "Response not circled"
                       13 "Did not need more of any drug used for s"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define EFFANAL   1 "Response circled" 2 "Response not circled"
                       13 "Did not need more of any drug used for s"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define EFFMJ     1 "Response circled" 2 "Response not circled"
                       13 "Did not need more of any drug used for s"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define EFFINH    1 "Response circled" 2 "Response not circled"
                       13 "Did not need more of any drug used for s"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define EFFCOC    1 "Response circled" 2 "Response not circled"
                       13 "Did not need more of any drug used for s"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define EFFHALL   1 "Response circled" 2 "Response not circled"
                       13 "Did not need more of any drug used for s"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define EFFHER    1 "Response circled" 2 "Response not circled"
                       13 "Did not need more of any drug used for s"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define EFFOTHOP  1 "Response circled" 2 "Response not circled"
                       13 "Did not need more of any drug used for s"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define EFFNONE   1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UDAYCIG   1 "Response circled" 2 "Response not circled"
                       13 "Did not use any drug daily in past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UDAYALC   1 "Response circled" 2 "Response not circled"
                       13 "Did not use any drug daily in past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UDAYSED   1 "Response circled" 2 "Response not circled"
                       13 "Did not use any drug daily in past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UDAYTRAN  1 "Response circled" 2 "Response not circled"
                       13 "Did not use any drug daily in past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UDAYSTM   1 "Response circled" 2 "Response not circled"
                       13 "Did not use any drug daily in past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UDAYANAL  1 "Response circled" 2 "Response not circled"
                       13 "Did not use any drug daily in past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UDAYMJ    1 "Response circled" 2 "Response not circled"
                       13 "Did not use any drug daily in past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UDAYINH   1 "Response circled" 2 "Response not circled"
                       13 "Did not use any drug daily in past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UDAYCOC   1 "Response circled" 2 "Response not circled"
                       13 "Did not use any drug daily in past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UDAYHALL  1 "Response circled" 2 "Response not circled"
                       13 "Did not use any drug daily in past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UDAYHER   1 "Response circled" 2 "Response not circled"
                       13 "Did not use any drug daily in past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UDAYOTH   1 "Response circled" 2 "Response not circled"
                       13 "Did not use any drug daily in past year"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UDAYNONE  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DEPCIG    1 "Response circled" 2 "Response not circled"
                       13 "Did not feel like had to have any drug u"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DEPALC    1 "Response circled" 2 "Response not circled"
                       13 "Did not feel like had to have any drug u"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DEPSED    1 "Response circled" 2 "Response not circled"
                       13 "Did not feel like had to have any drug u"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DEPTRAN   1 "Response circled" 2 "Response not circled"
                       13 "Did not feel like had to have any drug u"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DEPSTM    1 "Response circled" 2 "Response not circled"
                       13 "Did not feel like had to have any drug u"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DEPANAL   1 "Response circled" 2 "Response not circled"
                       13 "Did not feel like had to have any drug u"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DEPMJ     1 "Response circled" 2 "Response not circled"
                       13 "Did not feel like had to have any drug u"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DEPINH    1 "Response circled" 2 "Response not circled"
                       13 "Did not feel like had to have any drug u"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DEPCOC    1 "Response circled" 2 "Response not circled"
                       13 "Did not feel like had to have any drug u"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DEPHALL   1 "Response circled" 2 "Response not circled"
                       13 "Did not feel like had to have any drug u"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DEPHER    1 "Response circled" 2 "Response not circled"
                       13 "Did not feel like had to have any drug u"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DEPOTHOP  1 "Response circled" 2 "Response not circled"
                       13 "Did not feel like had to have any drug u"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DEPNONE   1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define WSCIG     1 "Response circled" 2 "Response not circled"
                       13 "Did not have withdrawal symptoms in past"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define WSALC     1 "Response circled" 2 "Response not circled"
                       13 "Did not have withdrawal symptoms in past"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define WSSED     1 "Response circled" 2 "Response not circled"
                       13 "Did not have withdrawal symptoms in past"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define WSTRAN    1 "Response circled" 2 "Response not circled"
                       13 "Did not have withdrawal symptoms in past"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define WSSTM     1 "Response circled" 2 "Response not circled"
                       13 "Did not have withdrawal symptoms in past"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define WSANAL    1 "Response circled" 2 "Response not circled"
                       13 "Did not have withdrawal symptoms in past"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define WSMJ      1 "Response circled" 2 "Response not circled"
                       13 "Did not have withdrawal symptoms in past"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define WSINH     1 "Response circled" 2 "Response not circled"
                       13 "Did not have withdrawal symptoms in past"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define WSCOC     1 "Response circled" 2 "Response not circled"
                       13 "Did not have withdrawal symptoms in past"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define WSHALL    1 "Response circled" 2 "Response not circled"
                       13 "Did not have withdrawal symptoms in past"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define WSHER     1 "Response circled" 2 "Response not circled"
                       13 "Did not have withdrawal symptoms in past"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define WSOTHOP   1 "Response circled" 2 "Response not circled"
                       13 "Did not have withdrawal symptoms in past"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define WSNONE    1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       83 "DID NOT USE ANY DRUGS PAST 12 MOS. Logic"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUGS"
                       93 "DID NOT USE ANY DRUGS IN THE PAST 12 MON"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define NDLREAD   1 "Wants interviewer to continue reading"
                       2 "Wants to do it himself/herself"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define GNNDLLIF  1 "Yes, have used a needle to take a drug"
                       2 "No, have never used a needle to take a d"
                       3 "Yes, have used a ndle to take a drug LOG"
                       81 "NEVER USED A NEEDLE TO TAKE A DRUG Logic"
                       91 "NEVER USED A NEEDLE TO TAKE A DRUG" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define GNNDLREC  1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago but less than 10 yea"
                       6 "10 or more years ago"
                       7 "Use in past 30 days LOGICALLY IMPUTED"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       81 "NEVER USED ANY DRUG FOR NONMDCL RSN Logi"
                       83 "NEVER USED A NDL TO TAKE ANY DRUG Logic."
                       91 "NEVER USED ANY DRUG FOR NONMEDICAL REASO"
                       93 "NEVER USED A NEEDLE TO TAKE ANY DRUG"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define GNNDLSED  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED ANY DRUGS LISTED ABOVE Logic."
                       83 "NEVER USED A NEEDLE TO TAKE DRUG Logic.a"
                       91 "NEVER USED ANY OF THE DRUGS LISTED ABOVE"
                       93 "NEVER USED A NEEDLE TO TAKE ANY DRUG"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define GNNDLTRA  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED ANY DRUGS LISTED ABOVE Logic."
                       83 "NEVER USED A NEEDLE TO TAKE DRUG Logic.a"
                       91 "NEVER USED ANY OF THE DRUGS LISTED ABOVE"
                       93 "NEVER USED A NEEDLE TO TAKE ANY DRUG"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define GNNDLSTM  1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED (frm"
                       81 "NEVER USED ANY DRUGS LISTED ABOVE Logic."
                       83 "NEVER USED A NEEDLE TO TAKE DRUG Logic.a"
                       91 "NEVER USED ANY OF THE DRUGS LISTED ABOVE"
                       93 "NEVER USED A NEEDLE TO TAKE ANY DRUG"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define GNNDLANL  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED ANY DRUGS LISTED ABOVE Logic."
                       83 "NEVER USED A NEEDLE TO TAKE DRUG Logic.a"
                       91 "NEVER USED ANY OF THE DRUGS LISTED ABOVE"
                       93 "NEVER USED A NEEDLE TO TAKE ANY DRUG"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define GNNDLINH  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED ANY DRUGS LISTED ABOVE Logic."
                       83 "NEVER USED A NEEDLE TO TAKE DRUG Logic.a"
                       91 "NEVER USED ANY OF THE DRUGS LISTED ABOVE"
                       93 "NEVER USED A NEEDLE TO TAKE ANY DRUG"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define GNNDLCOC  1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED (frm"
                       81 "NEVER USED ANY DRUGS LISTED ABOVE Logic."
                       83 "NEVER USED A NEEDLE TO TAKE DRUG Logic.a"
                       91 "NEVER USED ANY OF THE DRUGS LISTED ABOVE"
                       93 "NEVER USED A NEEDLE TO TAKE ANY DRUG"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define GNNDLHAL  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED ANY DRUGS LISTED ABOVE Logic."
                       83 "NEVER USED A NEEDLE TO TAKE DRUG Logic.a"
                       91 "NEVER USED ANY OF THE DRUGS LISTED ABOVE"
                       93 "NEVER USED A NEEDLE TO TAKE ANY DRUG"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define GNNDLHER  1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED (frm"
                       81 "NEVER USED ANY DRUGS LISTED ABOVE Logic."
                       83 "NEVER USED A NEEDLE TO TAKE DRUG Logic.a"
                       91 "NEVER USED ANY OF THE DRUGS LISTED ABOVE"
                       93 "NEVER USED A NEEDLE TO TAKE ANY DRUG" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define GNNDLOPT  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED ANY DRUGS LISTED ABOVE Logic."
                       83 "NEVER USED A NEEDLE TO TAKE DRUG Logic.a"
                       91 "NEVER USED ANY OF THE DRUGS LISTED ABOVE"
                       93 "NEVER USED A NEEDLE TO TAKE ANY DRUG"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define GNNDLSTR  1 "Response circled" 2 "Response not circled"
                       81 "NEVER USED ANY DRUGS LSTD ABOVE Logicall"
                       83 "NEVER USED A NEEDLE TO TAKE DRUG Logic.a"
                       91 "NEVER USED ANY OF THE DRUGS LISTED ABOVE"
                       93 "NEVER USED A NEEDLE TO TAKE ANY DRUG"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define GNNDLNON  2 "Response not circled"
                       81 "NEVER USED ANY DRUGS LISTED ABOVE Logic."
                       83 "NEVER USED A NEEDLE TO TAKE DRUG Logic.a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY OF THE DRUGS LISTED ABOVE"
                       93 "NEVER USED A NEEDLE TO TAKE ANY DRUG" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define GNNDLSH1  1 "Yes, have used a needle after someone el"
                       2 "No, have not used a needle after someone"
                       81 "NEVER USED ANY DRUG Logically assigned"
                       83 "NEVER USED A NEEDLE TO TAKE DRUG Logic.a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUG"
                       93 "NEVER USED A NEEDLE TO TAKE ANY DRUG"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define GNNDLSH2  1 "Yes, someone used a needle after I used"
                       2 "No, no one has used a needle after I use"
                       81 "NEVER USED ANY DRUG Logically assigned"
                       83 "NEVER USED A NEEDLE TO TAKE DRUG Logic."
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANY DRUG"
                       93 "NEVER USED A NEEDLE TO TAKE ANY DRUG"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define SPTREAD   1 "Wants interviewer to continue reading"
                       2 "Wants to do it himself/herself"
                       3 "Wants interviewer to continue LOGICALLY"
                       98 "BLANK (NO ANSWER)" ;
label define DRUGTEST  1 "Yes" 2 "No"
                       3 "Did not have a job during past 12 months"
                       85 "BAD DATA Logically assigned" 94 "DONT KNOW"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define TESTPOS   1 "Yes" 2 "No"
                       3 "Did not receive test in past 12 months"
                       4 "Did not have a job during past 12 months"
                       85 "BAD DATA Logically assigned" 94 "DONT KNOW"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define ICELIFE   1 "Yes" 3 "Yes LOGICALLY IMPUTED"
                       81 "NEVER USED ICE Logically assigned"
                       91 "NEVER USED ICE" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define ICEREC    1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago but less than 10 yea"
                       6 "10 or more years ago"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       81 "NEVER USED ICR Logically assigned"
                       91 "NEVER USED ICR" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define STEROPP   981 "NEVER HAD CHANCE TO TRY ANABOLIC STEROID"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER HAD A CHANCE TO TRY ANABOLIC STERO"
                       994 "DONT KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define STERAGE   981 "NEVER USED ANABOLIC STEROIDS Logically a"
                       985 "BAD DATA Logically assigned"
                       991 "NEVER USED ANABOLIC STEROIDS" 994 "DONT KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define STERTOT   1 "1 or 2 times" 2 "3 to 5 times" 3 "6 to 10 times"
                       4 "11 to 49 times" 5 "50 to 99 times"
                       6 "100 to 199 times" 7 "200 or more times"
                       81 "NEVER USED ANABOLIC STEROIDS Logically a"
                       85 "BAD DATA Logically assigned"
                       91 "NEVER USED ANABOLIC STEROIDS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define STERREC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       81 "NEVER USED ANABOLIC STEROIDS Logically a"
                       91 "NEVER USED ANABOLIC STEROIDS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define SPNEWA    0 "None (code used only for question SP-9)"
                       116 "Methaqualone, Quaalude, Sopor" 244 "sic"
                       322 "Methamphetamine (speed or ice or cr"
                       326 "White cross" 327 "Black beauties, Black Beauty"
                       331 "Whites" 333 "357 Magnum, Magnum 44"
                       334 "Crossroads, cross tops" 336 "Diet pills"
                       339 "Amphetamines (speed generically)"
                       343 "Nitroglycerine" 348 "Crystal" 355 "Crystal meth"
                       422 "Motrin" 427 "Darvocet"
                       601 "LSD (acid, white lightning) [see als"
                       604 "Psilocybin (mushrooms)" 606 "sic" 609 "sic"
                       703 "Opium" 801 "OTHER Drugs, NOT SPECIFIED"
                       802 "THC, cannabinol" 803 "sic" 804 "Hashish"
                       805 "Cocaine, coke"
                       807 "Alcohol, beer, ethanol, EtOH, pink champ"
                       813 "Cigarettes, smoking (subst spec), tobacc"
                       814 "Caffeine" 846 "Erythromycin" 847 "sic"
                       850 "Slack" 852 "sic" 853 "sic" 854 "Juice" 856 "sic"
                       859 "sic" 861 "sic" 862 "sic" 863 "Beetlenut"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define SPNEWB    0 "None (code used only for question SP-9)"
                       326 "White cross" 352 "Lemons" 355 "Crystal meth"
                       427 "Darvocet"
                       601 "LSD (acid, white lightning) [see als"
                       604 "Psilocybin (mushrooms)" 606 "sic" 803 "sic"
                       805 "Cocaine, coke"
                       813 "Cigarettes, smoking (subst spec), tobacc"
                       852 "sic" 997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define SPNEWC    0 "None (code used only for question SP-9)"
                       601 "LSD (acid, white lightning) [see als" 803 "sic"
                       807 "Alcohol, beer, ethanol, EtOH, pink champ"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define SPNEWD    0 "None (code used only for question SP-9)"
                       807 "Alcohol, beer, ethanol, EtOH, pink champ"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define SPNEWE    0 "None (code used only for question SP-9)"
                       813 "Cigarettes, smoking (subst spec), tobacc"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)" ;
label define BOOKED    1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       12 "months have you been arrested and" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define PROBATON  1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       85 "BAD DATA Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define PAROLE    1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define STRSTEAL  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define OTHSTEAL  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define DAMAGE    1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CARSTEAL  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define FORCEMON  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define BREAKIN   1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define PHYFIGHT  1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define HURTBAD   1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define GUNMONEY  1 "Yes" 2 "No" 85 "BAD DATA Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define SOLDDRUG  1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       85 "BAD DATA Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define DEXREAD   1 "Wants interviewer to continue reading"
                       2 "Wants to do it himself/herself"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define NOBOOZYR  1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED"
                       85 "BAD DATA Logically assigned" ;
label define ALCAGGR   1 "Yes" 2 "No" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define ALCARGUM  1 "Yes" 2 "No" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define ALCABSNT  1 "Yes" 2 "No" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCHIGH   1 "Yes" 2 "No" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define ALCJOB    1 "Yes" 2 "No" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define ALCMATCD  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCRELCD  1 "Yes" 2 "No" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCFRDCD  1 "Yes" 2 "No" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCTOSS   1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define ALCHOLIC  1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define ALCDRUNK  1 "Yes" 2 "No" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCINTOX  1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define ALCREM    1 "Yes" 2 "No" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCQUICK  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCMORN   1 "Yes" 2 "No" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCSHOOK  1 "Yes" 2 "No" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCALONE  1 "Yes" 2 "No" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ALCBRKPM  1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define AS13NONE  1 "Response circled" 2 "Response not circled"
                       3 "Response circled LOGICALLY IMPUTED"
                       85 "BAD DATA Logically assigned" 97 "REFUSED" ;
label define DRDEPRSS  1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define DEPDRG1A  120 "Downers; OTHER Sedative, NOT SPECIFIED"
                       201 "Valium" 209 "Xanax"
                       221 "OTHER Tranquilizer, NOT SPECIFIED"
                       301 "Dexedrine" 318 "Ritalin, Methylphenidate"
                       322 "Methamphetamine (speed or ice or cr"
                       324 "Uppers; OTHER Stimulant, NOT SPECIFIED"
                       333 "357 Magnum, Magnum 44"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       355 "Crystal meth" 407 "Demerol"
                       409 "Tylenol with Codeine, Tylenol 3, Tylenol"
                       420 "OTHER Analgesic, NOT SPECIFIED" 423 "Percocet"
                       440 "Soma" 502 "Spray paints"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       601 "LSD (acid, white lightning) [see als"
                       605 "PCP (angel dust, phencyclidine)" 606 "sic"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 702 "Heroin"
                       801 "OTHER Drugs, NOT SPECIFIED" 802 "THC, cannabinol"
                       803 "sic" 804 "Hashish" 805 "Cocaine, coke"
                       806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champ"
                       808 "All of the ones Ive tried" 812 "Cigars"
                       813 "Cigarettes, smoking (subst spec), tobacc"
                       814 "Caffeine"
                       816 "Smokeless tobacco, snuff, chewing tobacc"
                       900 "Non-drug reason given for drug problem"
                       989 "LEGITIMATE SKIP Logically assigned"
                       994 "DONT KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define DEPDRG2A  201 "Valium" 221 "OTHER Tranquilizer, NOT SPECIFIED"
                       322 "Methamphetamine (speed or ice or cr"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       501 "Gasoline or lighter fluids"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       601 "LSD (acid, white lightning) [see als"
                       605 "PCP (angel dust, phencyclidine)"
                       701 "OTHER Opiates, NOT SPECIFIED" 702 "Heroin"
                       803 "sic" 804 "Hashish" 805 "Cocaine, coke"
                       806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champ"
                       813 "Cigarettes, smoking (subst spec), tobacc"
                       815 "Coffee"
                       816 "Smokeless tobacco, snuff, chewing tobacc"
                       818 "Nicotine"
                       900 "Non-drug reason given for drug problem"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define DEPDRG3A  221 "OTHER Tranquilizer, NOT SPECIFIED"
                       322 "Methamphetamine (speed or ice or cr"
                       601 "LSD (acid, white lightning) [see als"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 803 "sic"
                       805 "Cocaine, coke"
                       807 "Alcohol, beer, ethanol, EtOH, pink champ"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define DEPDRG4A  510 "OTHER Inhalant, NOT SPECIFIED"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 803 "sic"
                       807 "Alcohol, beer, ethanol, EtOH, pink champ"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define DEPDRG5A  703 "Opium" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define DRARGUM   1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define ARGDRG1A  120 "Downers; OTHER Sedative, NOT SPECIFIED"
                       201 "Valium" 221 "OTHER Tranquilizer, NOT SPECIFIED"
                       241 "Prozac" 318 "Ritalin, Methylphenidate"
                       322 "Methamphetamine (speed or ice or cr"
                       324 "Uppers; OTHER Stimulant, NOT SPECIFIED"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       401 "Darvon"
                       409 "Tylenol with Codeine, Tylenol 3, Tylenol"
                       420 "OTHER Analgesic, NOT SPECIFIED" 440 "Soma"
                       502 "Spray paints"
                       601 "LSD (acid, white lightning) [see als"
                       603 "Mescaline" 605 "PCP (angel dust, phencyclidine)"
                       606 "sic" 702 "Heroin"
                       801 "OTHER Drugs, NOT SPECIFIED" 803 "sic"
                       805 "Cocaine, coke" 806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champ"
                       808 "All of the ones Ive tried" 812 "Cigars"
                       813 "Cigarettes, smoking (subst spec), tobacc"
                       816 "Smokeless tobacco, snuff, chewing tobacc"
                       818 "Nicotine" 824 "Steroids"
                       900 "Non-drug reason given for drug problem"
                       989 "LEGITIMATE SKIP Logically assigned"
                       994 "DONT KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define ARGDRG2A  120 "Downers; OTHER Sedative, NOT SPECIFIED"
                       201 "Valium" 221 "OTHER Tranquilizer, NOT SPECIFIED"
                       322 "Methamphetamine (speed or ice or cr"
                       324 "Uppers; OTHER Stimulant, NOT SPECIFIED"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       355 "Crystal meth" 501 "Gasoline or lighter fluids"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       601 "LSD (acid, white lightning) [see als"
                       605 "PCP (angel dust, phencyclidine)"
                       701 "OTHER Opiates, NOT SPECIFIED" 702 "Heroin"
                       802 "THC, cannabinol" 803 "sic" 805 "Cocaine, coke"
                       806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champ"
                       813 "Cigarettes, smoking (subst spec), tobacc"
                       815 "Coffee"
                       816 "Smokeless tobacco, snuff, chewing tobacc"
                       845 "sic" 900 "Non-drug reason given for drug problem"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define ARGDRG3A  221 "OTHER Tranquilizer, NOT SPECIFIED"
                       322 "Methamphetamine (speed or ice or cr"
                       420 "OTHER Analgesic, NOT SPECIFIED"
                       601 "LSD (acid, white lightning) [see als" 803 "sic"
                       805 "Cocaine, coke"
                       807 "Alcohol, beer, ethanol, EtOH, pink champ"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define ARGDRG4A  322 "Methamphetamine (speed or ice or cr"
                       324 "Uppers; OTHER Stimulant, NOT SPECIFIED"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 803 "sic"
                       807 "Alcohol, beer, ethanol, EtOH, pink champ"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define ARGDRG5A  703 "Opium" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define DRALONE   1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define ALNDRG1A  120 "Downers; OTHER Sedative, NOT SPECIFIED"
                       201 "Valium" 221 "OTHER Tranquilizer, NOT SPECIFIED"
                       301 "Dexedrine" 318 "Ritalin, Methylphenidate"
                       322 "Methamphetamine (speed or ice or cr"
                       324 "Uppers; OTHER Stimulant, NOT SPECIFIED"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       355 "Crystal meth" 401 "Darvon"
                       420 "OTHER Analgesic, NOT SPECIFIED"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       601 "LSD (acid, white lightning) [see als"
                       605 "PCP (angel dust, phencyclidine)" 606 "sic"
                       607 "OTHER Hallucinogen, NOT SPECIFIED"
                       701 "OTHER Opiates, NOT SPECIFIED" 702 "Heroin"
                       801 "OTHER Drugs, NOT SPECIFIED" 803 "sic"
                       805 "Cocaine, coke" 806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champ"
                       808 "All of the ones Ive tried"
                       813 "Cigarettes, smoking (subst spec), tobacc"
                       816 "Smokeless tobacco, snuff, chewing tobacc"
                       824 "Steroids" 860 "sic"
                       900 "Non-drug reason given for drug problem"
                       989 "LEGITIMATE SKIP Logically assigned"
                       994 "DONT KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define ALNDRG2A  120 "Downers; OTHER Sedative, NOT SPECIFIED"
                       209 "Xanax" 221 "OTHER Tranquilizer, NOT SPECIFIED"
                       339 "Amphetamines (speed generically)"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       601 "LSD (acid, white lightning) [see als"
                       605 "PCP (angel dust, phencyclidine)" 702 "Heroin"
                       803 "sic" 805 "Cocaine, coke" 806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champ"
                       813 "Cigarettes, smoking (subst spec), tobacc"
                       815 "Coffee"
                       816 "Smokeless tobacco, snuff, chewing tobacc"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define ALNDRG3A  120 "Downers; OTHER Sedative, NOT SPECIFIED"
                       221 "OTHER Tranquilizer, NOT SPECIFIED"
                       322 "Methamphetamine (speed or ice or cr"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 803 "sic"
                       805 "Cocaine, coke"
                       807 "Alcohol, beer, ethanol, EtOH, pink champ"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define ALNDRG4A  322 "Methamphetamine (speed or ice or cr"
                       324 "Uppers; OTHER Stimulant, NOT SPECIFIED"
                       510 "OTHER Inhalant, NOT SPECIFIED" 803 "sic"
                       807 "Alcohol, beer, ethanol, EtOH, pink champ"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define ALNDRG5A  703 "Opium" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define DRANX     1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define ANXDRG1A  120 "Downers; OTHER Sedative, NOT SPECIFIED"
                       209 "Xanax" 221 "OTHER Tranquilizer, NOT SPECIFIED"
                       241 "Prozac" 311 "Preludin" 313 "Fastin, Phentermine"
                       318 "Ritalin, Methylphenidate"
                       322 "Methamphetamine (speed or ice or cr"
                       324 "Uppers; OTHER Stimulant, NOT SPECIFIED"
                       326 "White cross" 332 "see also 346" 336 "Diet pills"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       353 "No-Doz" 355 "Crystal meth"
                       364 "Sinutab, Sudafed {OTC}"
                       409 "Tylenol with Codeine, Tylenol 3, Tylenol"
                       415 "Codeine" 418 "Methadone"
                       420 "OTHER Analgesic, NOT SPECIFIED"
                       505 "Lacquer thinner or other paint solvents"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       601 "LSD (acid, white lightning) [see als"
                       605 "PCP (angel dust, phencyclidine)" 606 "sic"
                       607 "OTHER Hallucinogen, NOT SPECIFIED"
                       618 "Acid paper, blotter (acid) [see also 601"
                       701 "OTHER Opiates, NOT SPECIFIED" 702 "Heroin"
                       801 "OTHER Drugs, NOT SPECIFIED" 803 "sic"
                       805 "Cocaine, coke" 806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champ"
                       808 "All of the ones Ive tried" 812 "Cigars"
                       813 "Cigarettes, smoking (subst spec), tobacc"
                       814 "Caffeine" 815 "Coffee"
                       816 "Smokeless tobacco, snuff, chewing tobacc"
                       818 "Nicotine" 824 "Steroids"
                       900 "Non-drug reason given for drug problem"
                       989 "LEGITIMATE SKIP Logically assigned"
                       994 "DONT KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define ANXDRG2A  102 "Buticaps"
                       120 "Downers; OTHER Sedative, NOT SPECIFIED"
                       221 "OTHER Tranquilizer, NOT SPECIFIED" 312 "Ionamin"
                       322 "Methamphetamine (speed or ice or cr"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       401 "Darvon" 468 "Excedrin"
                       601 "LSD (acid, white lightning) [see als" 606 "sic"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 702 "Heroin"
                       803 "sic" 805 "Cocaine, coke" 806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champ"
                       813 "Cigarettes, smoking (subst spec), tobacc"
                       815 "Coffee"
                       900 "Non-drug reason given for drug problem"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define ANXDRG3A  221 "OTHER Tranquilizer, NOT SPECIFIED"
                       322 "Methamphetamine (speed or ice or cr"
                       324 "Uppers; OTHER Stimulant, NOT SPECIFIED"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 803 "sic"
                       805 "Cocaine, coke" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define ANXDRG4A  322 "Methamphetamine (speed or ice or cr"
                       324 "Uppers; OTHER Stimulant, NOT SPECIFIED"
                       510 "OTHER Inhalant, NOT SPECIFIED" 803 "sic"
                       807 "Alcohol, beer, ethanol, EtOH, pink champ"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define ANXDRG5A  703 "Opium" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define DRHEALTH  1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define HLTDRG1A  120 "Downers; OTHER Sedative, NOT SPECIFIED"
                       146 "Bentyl, Dicyclomine"
                       259 "Desipramine, Norpramin, Pertofrane"
                       313 "Fastin, Phentermine"
                       318 "Ritalin, Methylphenidate"
                       322 "Methamphetamine (speed or ice or cr"
                       336 "Diet pills"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       355 "Crystal meth" 364 "Sinutab, Sudafed {OTC}"
                       409 "Tylenol with Codeine, Tylenol 3, Tylenol"
                       418 "Methadone" 420 "OTHER Analgesic, NOT SPECIFIED"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       530 "Asthma inhaler, asthma med., bronchial d"
                       605 "PCP (angel dust, phencyclidine)" 702 "Heroin"
                       801 "OTHER Drugs, NOT SPECIFIED" 803 "sic"
                       805 "Cocaine, coke" 806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champ"
                       808 "All of the ones Ive tried" 812 "Cigars"
                       813 "Cigarettes, smoking (subst spec), tobacc"
                       814 "Caffeine" 815 "Coffee"
                       816 "Smokeless tobacco, snuff, chewing tobacc"
                       818 "Nicotine"
                       900 "Non-drug reason given for drug problem"
                       989 "LEGITIMATE SKIP Logically assigned"
                       994 "DONT KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define HLTDRG2A  201 "Valium" 221 "OTHER Tranquilizer, NOT SPECIFIED"
                       312 "Ionamin"
                       322 "Methamphetamine (speed or ice or cr"
                       324 "Uppers; OTHER Stimulant, NOT SPECIFIED"
                       420 "OTHER Analgesic, NOT SPECIFIED"
                       601 "LSD (acid, white lightning) [see als"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 702 "Heroin"
                       803 "sic" 805 "Cocaine, coke" 806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champ"
                       812 "Cigars"
                       813 "Cigarettes, smoking (subst spec), tobacc"
                       814 "Caffeine" 815 "Coffee"
                       816 "Smokeless tobacco, snuff, chewing tobacc"
                       818 "Nicotine"
                       900 "Non-drug reason given for drug problem"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define HLTDRG3A  221 "OTHER Tranquilizer, NOT SPECIFIED"
                       322 "Methamphetamine (speed or ice or cr"
                       326 "White cross" 415 "Codeine" 803 "sic"
                       804 "Hashish" 805 "Cocaine, coke"
                       807 "Alcohol, beer, ethanol, EtOH, pink champ"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define HLTDRG4A  322 "Methamphetamine (speed or ice or cr" 803 "sic"
                       807 "Alcohol, beer, ethanol, EtOH, pink champ"
                       813 "Cigarettes, smoking (subst spec), tobacc"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define HLTDRG5A  703 "Opium" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define DRNTHINK  1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define NTKDRG1A  120 "Downers; OTHER Sedative, NOT SPECIFIED"
                       209 "Xanax" 211 "Buspar" 241 "Prozac"
                       313 "Fastin, Phentermine"
                       318 "Ritalin, Methylphenidate"
                       322 "Methamphetamine (speed or ice or cr"
                       324 "Uppers; OTHER Stimulant, NOT SPECIFIED"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       355 "Crystal meth" 364 "Sinutab, Sudafed {OTC}"
                       401 "Darvon"
                       409 "Tylenol with Codeine, Tylenol 3, Tylenol"
                       418 "Methadone" 420 "OTHER Analgesic, NOT SPECIFIED"
                       435 "Tylenol, Tylenol Extrastrength" 440 "Soma"
                       502 "Spray paints"
                       505 "Lacquer thinner or other paint solvents"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       601 "LSD (acid, white lightning) [see als"
                       604 "Psilocybin (mushrooms)"
                       605 "PCP (angel dust, phencyclidine)" 606 "sic"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 702 "Heroin"
                       704 "Dope" 801 "OTHER Drugs, NOT SPECIFIED"
                       802 "THC, cannabinol" 803 "sic" 804 "Hashish"
                       805 "Cocaine, coke" 806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champ"
                       808 "All of the ones Ive tried" 809 "Pills"
                       813 "Cigarettes, smoking (subst spec), tobacc"
                       814 "Caffeine"
                       816 "Smokeless tobacco, snuff, chewing tobacc"
                       844 "Blood pressure medication" 855 "sic"
                       858 "Antibiotic"
                       900 "Non-drug reason given for drug problem"
                       989 "LEGITIMATE SKIP Logically assigned"
                       994 "DONT KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define NTKDRG2A  102 "Buticaps"
                       120 "Downers; OTHER Sedative, NOT SPECIFIED"
                       201 "Valium" 221 "OTHER Tranquilizer, NOT SPECIFIED"
                       312 "Ionamin"
                       322 "Methamphetamine (speed or ice or cr"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       420 "OTHER Analgesic, NOT SPECIFIED"
                       501 "Gasoline or lighter fluids"
                       504 "Shoeshine liq, glue,toluene,Super Glue,r"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       601 "LSD (acid, white lightning) [see als"
                       605 "PCP (angel dust, phencyclidine)" 606 "sic"
                       701 "OTHER Opiates, NOT SPECIFIED" 702 "Heroin"
                       802 "THC, cannabinol" 803 "sic" 804 "Hashish"
                       805 "Cocaine, coke" 806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champ"
                       813 "Cigarettes, smoking (subst spec), tobacc"
                       815 "Coffee"
                       900 "Non-drug reason given for drug problem"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define NTKDRG3A  201 "Valium" 221 "OTHER Tranquilizer, NOT SPECIFIED"
                       322 "Methamphetamine (speed or ice or cr"
                       415 "Codeine" 420 "OTHER Analgesic, NOT SPECIFIED"
                       501 "Gasoline or lighter fluids"
                       601 "LSD (acid, white lightning) [see als"
                       702 "Heroin" 803 "sic" 804 "Hashish"
                       805 "Cocaine, coke"
                       807 "Alcohol, beer, ethanol, EtOH, pink champ"
                       813 "Cigarettes, smoking (subst spec), tobacc"
                       845 "sic" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define NTKDRG4A  322 "Methamphetamine (speed or ice or cr"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 803 "sic"
                       805 "Cocaine, coke"
                       807 "Alcohol, beer, ethanol, EtOH, pink champ"
                       813 "Cigarettes, smoking (subst spec), tobacc"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define NTKDRG5A  601 "LSD (acid, white lightning) [see als" 703 "Opium"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define DRUPSET   1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define UPSDRG1A  120 "Downers; OTHER Sedative, NOT SPECIFIED"
                       201 "Valium" 209 "Xanax" 241 "Prozac"
                       313 "Fastin, Phentermine"
                       318 "Ritalin, Methylphenidate"
                       322 "Methamphetamine (speed or ice or cr"
                       324 "Uppers; OTHER Stimulant, NOT SPECIFIED"
                       332 "see also 346" 336 "Diet pills"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       353 "No-Doz" 355 "Crystal meth"
                       364 "Sinutab, Sudafed {OTC}"
                       409 "Tylenol with Codeine, Tylenol 3, Tylenol"
                       418 "Methadone" 420 "OTHER Analgesic, NOT SPECIFIED"
                       438 "Anaprox, Naprosyn" 502 "Spray paints"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       601 "LSD (acid, white lightning) [see als"
                       605 "PCP (angel dust, phencyclidine)"
                       701 "OTHER Opiates, NOT SPECIFIED" 702 "Heroin"
                       801 "OTHER Drugs, NOT SPECIFIED" 803 "sic"
                       805 "Cocaine, coke" 806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champ"
                       808 "All of the ones Ive tried" 809 "Pills"
                       812 "Cigars"
                       813 "Cigarettes, smoking (subst spec), tobacc"
                       814 "Caffeine" 815 "Coffee"
                       816 "Smokeless tobacco, snuff, chewing tobacc"
                       818 "Nicotine" 824 "Steroids"
                       900 "Non-drug reason given for drug problem"
                       989 "LEGITIMATE SKIP Logically assigned"
                       994 "DONT KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define UPSDRG2A  120 "Downers; OTHER Sedative, NOT SPECIFIED"
                       201 "Valium" 209 "Xanax"
                       221 "OTHER Tranquilizer, NOT SPECIFIED" 312 "Ionamin"
                       322 "Methamphetamine (speed or ice or cr"
                       324 "Uppers; OTHER Stimulant, NOT SPECIFIED"
                       328 "Pink hearts"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       420 "OTHER Analgesic, NOT SPECIFIED"
                       501 "Gasoline or lighter fluids"
                       601 "LSD (acid, white lightning) [see als"
                       605 "PCP (angel dust, phencyclidine)" 702 "Heroin"
                       803 "sic" 804 "Hashish" 805 "Cocaine, coke"
                       806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champ"
                       813 "Cigarettes, smoking (subst spec), tobacc"
                       815 "Coffee"
                       900 "Non-drug reason given for drug problem"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define UPSDRG3A  322 "Methamphetamine (speed or ice or cr"
                       601 "LSD (acid, white lightning) [see als"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 803 "sic"
                       805 "Cocaine, coke"
                       807 "Alcohol, beer, ethanol, EtOH, pink champ"
                       813 "Cigarettes, smoking (subst spec), tobacc"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define UPSDRG4A  322 "Methamphetamine (speed or ice or cr"
                       510 "OTHER Inhalant, NOT SPECIFIED" 803 "sic"
                       807 "Alcohol, beer, ethanol, EtOH, pink champ"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define UPSDRG5A  703 "Opium" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define DRLSWORK  1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define LSWDRG1A  120 "Downers; OTHER Sedative, NOT SPECIFIED"
                       146 "Bentyl, Dicyclomine" 206 "Tranxene" 209 "Xanax"
                       313 "Fastin, Phentermine"
                       322 "Methamphetamine (speed or ice or cr"
                       324 "Uppers; OTHER Stimulant, NOT SPECIFIED"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       355 "Crystal meth" 364 "Sinutab, Sudafed {OTC}"
                       409 "Tylenol with Codeine, Tylenol 3, Tylenol"
                       440 "Soma" 502 "Spray paints"
                       510 "OTHER Inhalant, NOT SPECIFIED" 524 "see also 509"
                       601 "LSD (acid, white lightning) [see als"
                       605 "PCP (angel dust, phencyclidine)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED"
                       701 "OTHER Opiates, NOT SPECIFIED" 702 "Heroin"
                       801 "OTHER Drugs, NOT SPECIFIED" 803 "sic"
                       805 "Cocaine, coke" 806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champ"
                       808 "All of the ones Ive tried"
                       813 "Cigarettes, smoking (subst spec), tobacc"
                       816 "Smokeless tobacco, snuff, chewing tobacc"
                       900 "Non-drug reason given for drug problem"
                       989 "LEGITIMATE SKIP Logically assigned"
                       994 "DONT KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define LSWDRG2A  120 "Downers; OTHER Sedative, NOT SPECIFIED"
                       201 "Valium" 208 "Centrax"
                       221 "OTHER Tranquilizer, NOT SPECIFIED"
                       322 "Methamphetamine (speed or ice or cr"
                       324 "Uppers; OTHER Stimulant, NOT SPECIFIED"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       501 "Gasoline or lighter fluids"
                       601 "LSD (acid, white lightning) [see als"
                       605 "PCP (angel dust, phencyclidine)" 803 "sic"
                       805 "Cocaine, coke" 806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champ"
                       813 "Cigarettes, smoking (subst spec), tobacc"
                       815 "Coffee"
                       900 "Non-drug reason given for drug problem"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define LSWDRG3A  322 "Methamphetamine (speed or ice or cr"
                       339 "Amphetamines (speed generically)"
                       501 "Gasoline or lighter fluids"
                       601 "LSD (acid, white lightning) [see als"
                       605 "PCP (angel dust, phencyclidine)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 803 "sic"
                       805 "Cocaine, coke"
                       807 "Alcohol, beer, ethanol, EtOH, pink champ"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define LSWDRG4A  322 "Methamphetamine (speed or ice or cr"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 803 "sic"
                       807 "Alcohol, beer, ethanol, EtOH, pink champ"
                       813 "Cigarettes, smoking (subst spec), tobacc"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define LSWDRG5A  703 "Opium" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define DRSUSPIC  1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define SSPDRG1A  120 "Downers; OTHER Sedative, NOT SPECIFIED"
                       201 "Valium" 209 "Xanax" 312 "Ionamin"
                       318 "Ritalin, Methylphenidate"
                       322 "Methamphetamine (speed or ice or cr"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       355 "Crystal meth"
                       420 "OTHER Analgesic, NOT SPECIFIED"
                       505 "Lacquer thinner or other paint solvents"
                       601 "LSD (acid, white lightning) [see als"
                       604 "Psilocybin (mushrooms)"
                       605 "PCP (angel dust, phencyclidine)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED"
                       701 "OTHER Opiates, NOT SPECIFIED" 702 "Heroin"
                       801 "OTHER Drugs, NOT SPECIFIED" 803 "sic"
                       805 "Cocaine, coke" 806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champ"
                       808 "All of the ones Ive tried"
                       813 "Cigarettes, smoking (subst spec), tobacc"
                       815 "Coffee"
                       900 "Non-drug reason given for drug problem"
                       989 "LEGITIMATE SKIP Logically assigned"
                       994 "DONT KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define SSPDRG2A  120 "Downers; OTHER Sedative, NOT SPECIFIED"
                       209 "Xanax" 221 "OTHER Tranquilizer, NOT SPECIFIED"
                       324 "Uppers; OTHER Stimulant, NOT SPECIFIED"
                       339 "Amphetamines (speed generically)"
                       601 "LSD (acid, white lightning) [see als"
                       702 "Heroin" 803 "sic" 805 "Cocaine, coke"
                       806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champ"
                       813 "Cigarettes, smoking (subst spec), tobacc"
                       815 "Coffee" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define SSPDRG3A  322 "Methamphetamine (speed or ice or cr"
                       601 "LSD (acid, white lightning) [see als"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 803 "sic"
                       805 "Cocaine, coke" 806 "Crack, rock" 997 "REFUSED"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define SSPDRG4A  322 "Methamphetamine (speed or ice or cr"
                       510 "OTHER Inhalant, NOT SPECIFIED" 803 "sic"
                       807 "Alcohol, beer, ethanol, EtOH, pink champ"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define SSPDRG5A  703 "Opium" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define DRCOPE    1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define CPEDRG1A  120 "Downers; OTHER Sedative, NOT SPECIFIED"
                       201 "Valium" 221 "OTHER Tranquilizer, NOT SPECIFIED"
                       312 "Ionamin" 318 "Ritalin, Methylphenidate"
                       322 "Methamphetamine (speed or ice or cr"
                       324 "Uppers; OTHER Stimulant, NOT SPECIFIED"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       355 "Crystal meth"
                       601 "LSD (acid, white lightning) [see als"
                       605 "PCP (angel dust, phencyclidine)"
                       701 "OTHER Opiates, NOT SPECIFIED" 702 "Heroin"
                       801 "OTHER Drugs, NOT SPECIFIED" 803 "sic"
                       805 "Cocaine, coke" 806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champ"
                       808 "All of the ones Ive tried"
                       813 "Cigarettes, smoking (subst spec), tobacc"
                       816 "Smokeless tobacco, snuff, chewing tobacc"
                       900 "Non-drug reason given for drug problem"
                       989 "LEGITIMATE SKIP Logically assigned"
                       994 "DONT KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define CPEDRG2A  120 "Downers; OTHER Sedative, NOT SPECIFIED"
                       209 "Xanax" 221 "OTHER Tranquilizer, NOT SPECIFIED"
                       322 "Methamphetamine (speed or ice or cr"
                       324 "Uppers; OTHER Stimulant, NOT SPECIFIED"
                       339 "Amphetamines (speed generically)"
                       601 "LSD (acid, white lightning) [see als"
                       604 "Psilocybin (mushrooms)" 702 "Heroin" 803 "sic"
                       804 "Hashish" 805 "Cocaine, coke" 806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champ"
                       813 "Cigarettes, smoking (subst spec), tobacc"
                       815 "Coffee"
                       900 "Non-drug reason given for drug problem"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define CPEDRG3A  322 "Methamphetamine (speed or ice or cr"
                       601 "LSD (acid, white lightning) [see als"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 803 "sic"
                       805 "Cocaine, coke" 806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champ"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define CPEDRG4A  322 "Methamphetamine (speed or ice or cr"
                       510 "OTHER Inhalant, NOT SPECIFIED" 803 "sic"
                       807 "Alcohol, beer, ethanol, EtOH, pink champ"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define CPEDRG5A  703 "Opium" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define DREMGMED  1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define EMDRG1A   120 "Downers; OTHER Sedative, NOT SPECIFIED"
                       201 "Valium" 318 "Ritalin, Methylphenidate"
                       322 "Methamphetamine (speed or ice or cr"
                       336 "Diet pills" 348 "Crystal" 355 "Crystal meth"
                       435 "Tylenol, Tylenol Extrastrength" 440 "Soma"
                       605 "PCP (angel dust, phencyclidine)" 702 "Heroin"
                       801 "OTHER Drugs, NOT SPECIFIED" 803 "sic"
                       805 "Cocaine, coke" 806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champ"
                       813 "Cigarettes, smoking (subst spec), tobacc"
                       814 "Caffeine"
                       900 "Non-drug reason given for drug problem"
                       989 "LEGITIMATE SKIP Logically assigned"
                       994 "DONT KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define EMDRG2A   109 "Seconal"
                       120 "Downers; OTHER Sedative, NOT SPECIFIED"
                       209 "Xanax" 221 "OTHER Tranquilizer, NOT SPECIFIED"
                       420 "OTHER Analgesic, NOT SPECIFIED"
                       601 "LSD (acid, white lightning) [see als"
                       702 "Heroin" 803 "sic" 805 "Cocaine, coke"
                       806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champ"
                       900 "Non-drug reason given for drug problem"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define EMDRG3A   322 "Methamphetamine (speed or ice or cr"
                       601 "LSD (acid, white lightning) [see als"
                       805 "Cocaine, coke"
                       813 "Cigarettes, smoking (subst spec), tobacc"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define EMDRG4A   322 "Methamphetamine (speed or ice or cr" 803 "sic"
                       807 "Alcohol, beer, ethanol, EtOH, pink champ"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define EMDRG5A   703 "Opium" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define DRTRMT    1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TMTDRG1A  120 "Downers; OTHER Sedative, NOT SPECIFIED"
                       241 "Prozac" 322 "Methamphetamine (speed or ice or cr"
                       324 "Uppers; OTHER Stimulant, NOT SPECIFIED"
                       336 "Diet pills"
                       339 "Amphetamines (speed generically)"
                       355 "Crystal meth"
                       420 "OTHER Analgesic, NOT SPECIFIED" 440 "Soma"
                       502 "Spray paints"
                       601 "LSD (acid, white lightning) [see als"
                       605 "PCP (angel dust, phencyclidine)" 702 "Heroin"
                       801 "OTHER Drugs, NOT SPECIFIED" 803 "sic"
                       805 "Cocaine, coke" 806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champ"
                       808 "All of the ones Ive tried"
                       813 "Cigarettes, smoking (subst spec), tobacc"
                       818 "Nicotine"
                       900 "Non-drug reason given for drug problem"
                       994 "DONT KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define TMTDRG2A  120 "Downers; OTHER Sedative, NOT SPECIFIED"
                       209 "Xanax" 221 "OTHER Tranquilizer, NOT SPECIFIED"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       501 "Gasoline or lighter fluids"
                       601 "LSD (acid, white lightning) [see als"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 702 "Heroin"
                       803 "sic" 805 "Cocaine, coke" 806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champ"
                       813 "Cigarettes, smoking (subst spec), tobacc"
                       900 "Non-drug reason given for drug problem"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define TMTDRG3A  322 "Methamphetamine (speed or ice or cr"
                       601 "LSD (acid, white lightning) [see als" 803 "sic"
                       805 "Cocaine, coke"
                       807 "Alcohol, beer, ethanol, EtOH, pink champ"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define TMTDRG4A  322 "Methamphetamine (speed or ice or cr"
                       807 "Alcohol, beer, ethanol, EtOH, pink champ"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define TMTDRG5A  997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define DRDRVUN   1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define DRVDRG1A  116 "Methaqualone, Quaalude, Sopor"
                       120 "Downers; OTHER Sedative, NOT SPECIFIED"
                       322 "Methamphetamine (speed or ice or cr"
                       355 "Crystal meth"
                       435 "Tylenol, Tylenol Extrastrength" 440 "Soma"
                       601 "LSD (acid, white lightning) [see als"
                       605 "PCP (angel dust, phencyclidine)" 606 "sic"
                       702 "Heroin" 801 "OTHER Drugs, NOT SPECIFIED"
                       803 "sic" 804 "Hashish" 805 "Cocaine, coke"
                       806 "Crack, rock"
                       807 "Alcohol, beer, ethanol, EtOH, pink champ"
                       808 "All of the ones Ive tried"
                       813 "Cigarettes, smoking (subst spec), tobacc"
                       900 "Non-drug reason given for drug problem"
                       989 "LEGITIMATE SKIP Logically assigned"
                       994 "DONT KNOW" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define DRVDRG2A  120 "Downers; OTHER Sedative, NOT SPECIFIED"
                       221 "OTHER Tranquilizer, NOT SPECIFIED"
                       322 "Methamphetamine (speed or ice or cr"
                       601 "LSD (acid, white lightning) [see als"
                       605 "PCP (angel dust, phencyclidine)" 803 "sic"
                       805 "Cocaine, coke"
                       807 "Alcohol, beer, ethanol, EtOH, pink champ"
                       813 "Cigarettes, smoking (subst spec), tobacc"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define DRVDRG3A  607 "OTHER Hallucinogen, NOT SPECIFIED" 703 "Opium"
                       803 "sic" 805 "Cocaine, coke"
                       807 "Alcohol, beer, ethanol, EtOH, pink champ"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define DRVDRG4A  322 "Methamphetamine (speed or ice or cr"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define DRVDRG5A  997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define TMTREAD   1 "Wants interviewer to continue reading"
                       2 "Wants to do it himself/herself"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define EMPDRUG   1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RSKPKCIG  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RSKTRYMJ  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RSKMJOCC  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RSKMJREG  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RKTRYPCP  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RKPCPREG  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RKTRYHER  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RKHERREG  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RKTRYCOC  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RKCOCOCC  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RKCOCREG  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RKCRKOCC  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RKANSOCC  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RKANSREG  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RK2DRINK  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RK5DRINK  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RSKBINGE  1 "No risk" 2 "Slight risk" 3 "Moderate risk"
                       4 "Great risk" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RSKDIFMJ  1 "Probably impossible" 2 "Very difficult"
                       3 "Fairly difficult" 4 "Fairly easy" 5 "Very easy"
                       94 "DONT KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RKDIFLSD  1 "Probably impossible" 2 "Very difficult"
                       3 "Fairly difficult" 4 "Fairly easy" 5 "Very easy"
                       94 "DONT KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RKDIFPCP  1 "Probably impossible" 2 "Very difficult"
                       3 "Fairly difficult" 4 "Fairly easy" 5 "Very easy"
                       94 "DONT KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RKDIFCOC  1 "Probably impossible" 2 "Very difficult"
                       3 "Fairly difficult" 4 "Fairly easy" 5 "Very easy"
                       94 "DONT KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RKDIFHER  1 "Probably impossible" 2 "Very difficult"
                       3 "Fairly difficult" 4 "Fairly easy" 5 "Very easy"
                       94 "DONT KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RSKSELL   1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RKNEIDRN  1 "Often" 2 "Occasionally" 3 "Rarely" 4 "Never"
                       94 "DONT KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define RKNEISEL  1 "Often" 2 "Occasionally" 3 "Rarely" 4 "Never"
                       94 "DONT KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define WALKPAIN  1 "Yes" 2 "No" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define TIMEPAIN  1 "Yes" 2 "No" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define UPSHOR    1 "Yes" 2 "No" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define ASTHMA    1 "Yes" 2 "No" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define TRPSYCH   1 "Yes" 2 "No" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define HEART     1 "Yes" 2 "No" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define FLU       1 "Yes" 2 "No" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ALLERG    1 "Yes" 2 "No" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HOSPYR    1 "Yes" 2 "No" 12 "months?" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define SOREYR    1 "Yes" 2 "No" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define RUNNYYR   1 "Yes" 2 "No" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define COUGHYR   1 "Yes" 2 "No" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define PHLEGMYR  1 "Yes" 2 "No" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HEALTHYR  1 "Excellent" 2 "Very good" 3 "Good" 4 "Fair" 5 "Poor"
                       94 "DONT KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define FLTEAT    1 "Rarely or none of the time (less than a"
                       2 "Some or a little of the time (1-2 days)"
                       3 "Occasion. or a moderate amount of time ("
                       4 "Most or all of the time (5-7 days)" 94 "DONT KNOW"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define FLTMIND   1 "Rarely or none of the time (less than a"
                       2 "Some or a little of the time (1-2 days)"
                       3 "Occasion. or a moderate amount of time ("
                       4 "Most or all of the time (5-7 days)" 94 "DONT KNOW"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define FLTDEPRS  1 "Rarely or none of the time (less than a"
                       2 "Some or a little of the time (1-2 days)"
                       3 "Occasion. or a moderate amount of time ("
                       4 "Most or all of the time (5-7 days)" 94 "DONT KNOW"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define FLTEFFRT  1 "Rarely or none of the time (less than a"
                       2 "Some or a little of the time (1-2 days)"
                       3 "Occasion. or a moderate amount of time ("
                       4 "Most or all of the time (5-7 days)" 94 "DONT KNOW"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define FLTSLEEP  1 "Rarely or none of the time (less than a"
                       2 "Some or a little of the time (1-2 days)"
                       3 "Occasion. or a moderate amount of time ("
                       4 "Most or all of the time (5-7 days)" 94 "DONT KNOW"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define FLTSAD    1 "Rarely or none of the time (less than a"
                       2 "Some or a little of the time (1-2 days)"
                       3 "Occasion. or a moderate amount of time ("
                       4 "Most or all of the time (5-7 days)" 94 "DONT KNOW"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define FLTGOING  1 "Rarely or none of the time (less than a"
                       2 "Some or a little of the time (1-2 days)"
                       3 "Occasion. or a moderate amount of time ("
                       4 "Most or all of the time (5-7 days)" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define MARITAL   1 "Married" 2 "Widowed" 3 "Divorced or separated"
                       4 "Has never married" 85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define PAYMO     89 "LEGITIMATE SKIP Logically assigned"
                       91 "NEVER WORKED FOR PAY" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define PAYYR     985 "BAD DATA Logically assigned"
                       989 "LEGITIMATE SKIP Logically assigned"
                       991 "NEVER WORKED FOR PAY" 994 "DONT KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define NO5JOB    89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define WORKDAYS  89 "LEGITIMATE SKIP Logically assigned" 95 "BAD DATA"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define WORKBLAH  85 "BAD DATA Logically assigned"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define CWE       1 "Respondent" 2 "Someone else (Specified in CWESC)"
                       3 "Income contributed equally (Specified in"
                       4 "No one" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define FULLPART  1 "Full-time" 2 "Part-time"
                       3 "Chief source of income does not work"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define EDUC      0 "No schooling" 1 "First Grade" 2 "Second grade"
                       3 "Third grade" 4 "Fourth grade" 5 "Fifth grade"
                       6 "Sixth grade" 7 "Seventh Grade" 8 "Eighth grade"
                       9 "Ninth grade" 10 "Tenth grade" 11 "Eleventh grade"
                       12 "Twelfth grade" 13 "One year college"
                       14 "2 years college" 15 "3 years college"
                       16 "4 years college" 17 "Graduate/professional school"
                       85 "BAD DATA Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define GRADHS    1 "Yes" 2 "No" 4 "No LOGICALLY IMPUTED (frm DIPLOMA)"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define DIPLOMA   1 "High school diploma" 2 "GED certificate"
                       3 "Neither of the above"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ENROLLD   1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       4 "No LOGICALLY IMPUTED" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define SCHPLANS  1 "Has plans to enroll in a school in futur"
                       2 "Has completed all schooling"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define STUDENT   1 "A full-time student" 2 "A part-time student"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define SCHDAYS   89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SKIPPED   89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define MILES     989 "LEGITIMATE SKIP Logically assigned"
                       991 "HAS NEVER DRIVEN A MOTOR VEHICLE" 994 "DONT KNOW"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define ACCID     1 "Yes" 2 "No" 3 "Did not drive in past 12 months"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define NOCHILD   0 "None" 1 "One" 2 "Two" 3 "Three" 4 "Four" 5 "Five"
                       6 "Six or more"
                       89 "LEGITIMATE SKIP Logically assigned" 95 "BAD DATA"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define TOTPEOP   97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define MOTHER    0 "No" 1 "Yes" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define FATHER    0 "No" 1 "Yes" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define STEPMOM   0 "No" 1 "Yes" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define STEPDAD   0 "No" 1 "Yes" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define SPOUSE    0 "No" 1 "Yes" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define INLAW     0 "None" 93 "RELATIONSHIP SPECIFIED, NO COUNT RECORDE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define OWNCHILD  0 "None" 93 "RELATIONSHIP SPECIFIED, NO COUNT RECORDE"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define STEPCHLD  0 "None" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define BROSIS    0 "None" 93 "RELATIONSHIP SPECIFIED, NO COUNT RECORDE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define OTHREL    0 "None" 93 "RELATIONSHIP SPECIFIED, NO COUNT RECORDE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define FRIENDS   0 "None" 93 "RELATIONSHIP SPECIFIED, NO COUNT RECORDE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define OTHERNON  0 "None" 35 "Are there any of your family members"
                       93 "RELATIONSHIP SPECIFIED, NO COUNT RECORDE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define MOVDAWAY  1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       4 "No LOGICALLY IMPUTED" 94 "DONT KNOW"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define DORM      94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (MOVDAWAY=2)" ;
label define MILBASE   94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (MOVDAWAY=2)" ;
label define HOSP      94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (MOVDAWAY=2)" ;
label define OTHGPH    85 "BAD DATA Logically assigned" 94 "DONT KNOW"
                       95 "BAD DATA" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (MOVDAWAY=2)" ;
label define OTHGPHSP  1 "Own home" 2 "Married"
                       3 "(Moved to) another dwelling, ownership n"
                       4 "(Moved to) apartment, ownership not spec"
                       6 "Trailer = Code 01" 7 "Foster home"
                       8 "Nursing home/home for handicapped/retire" 9 "Died"
                       10 "Lives out of state/city/county"
                       11 "Staying/living with a friend" 12 "Job Corp"
                       13 "Townhouse" 14 "Overseas/out of country"
                       15 "Lives with mother/father/relatives"
                       17 "With other children in school group hous"
                       18 "Group housing in college"
                       21 "Group home/halfway house/shelter/tx or r"
                       85 "BAD DATA Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define SERVICE   1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define MILSTAT   2 "In a Reserves component"
                       3 "Separated/retired from Reserves or activ"
                       89 "LEGITIMATE SKIP Logically assigned" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define TELNO     97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define MOVES     94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define PROXABLE  1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define PROXYREL  1 "Respondents spouse/live-in partner = Co"
                       2 "Respondents father = Code 15"
                       3 "Respondents mother = Code 14"
                       4 "Respondents brother = Code 19"
                       5 "Respondents sister = Code 18"
                       6 "Other family member, relation not specif"
                       12 "Spouse" 14 "Mother" 15 "Father" 16 "Daughter"
                       17 "Son" 20 "Grandmother" 21 "Grandfather"
                       22 "Other female blood relative"
                       23 "Other male blood relative" 25 "Father-in-law"
                       26 "Other female in-laws" 27 "Other male in-laws"
                       28 "Female friend, girlfriend"
                       29 "Male friend, boyfriend"
                       30 "Other female acquaintance, roommate"
                       31 "Other male acquaintance, roommate"
                       32 "Step-mother" 33 "Step-father"
                       40 "Friend (sex unspecified), boarder" 41 "Parents"
                       43 "Guardian (sex unspecified)"
                       44 "Foster mother, female guardian"
                       50 "Multiple people listed"
                       51 "Relative, sex not specified"
                       52 "Roommate, sex not specified" 63 "Visitor"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define PROXHOME  1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define PROXJOIN  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DONT KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define MEDICARE  1 "Yes" 2 "No" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define MEDICAID  1 "Yes" 2 "No" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CHAMPUS   1 "Yes" 2 "No" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define PRVHLTIN  1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define OWNHLTIN  1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define GRPHLTIN  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DONT KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define HLTINALC  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define HLTINDRG  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define HLTINMNT  1 "Yes" 2 "No" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define WHOANSHI  1 "Sample member"
                       2 "Proxy, relationship to sample member not"
                       12 "Spouse" 13 "Live-in partner, fiancee" 14 "Mother"
                       15 "Father" 16 "Daughter" 17 "Son" 18 "Sister"
                       19 "Brother" 20 "Grandmother" 21 "Grandfather"
                       22 "Other female blood relative"
                       23 "Other male blood relative"
                       26 "Other female in-laws" 27 "Other male in-laws"
                       28 "Close female friend" 29 "Close male friend"
                       30 "Other female acquaintance, roommate"
                       31 "Other male acquaintance, roommate"
                       32 "Step-mother" 33 "Step-father"
                       40 "Friend (sex unspecified), boarder" 41 "Parents"
                       43 "Guardian (sex unspecified)"
                       44 "Foster mother, female guardian"
                       45 "Foster father, male guardian"
                       50 "Multiple people listed"
                       51 "Relative, sex not specified"
                       52 "Roommate, sex not specified" 61 "Siblings"
                       62 "Co-worker" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define JOB       1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       4 "No LOGICALLY IMPUTED" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define HOURS     985 "BAD DATA Logically assigned" 994 "DONT KNOW"
                       995 "BAD DATA" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define WORK      1 "Worked only for an employer"
                       2 "Was self-employed only"
                       3 "Self-employed and working for an employe"
                       4 "Did not work during the month"
                       5 "Did work during the month LOGICALLY IMPU"
                       6 "Did not work during the month LOGICALLY"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define WAG1      1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define AWAG1     999985 "BAD DATA Logically assigned"
                       999994 "DONT KNOW" 999997 "REFUSED"
                       999998 "BLANK (NO ANSWER)" 999999 "LEGITIMATE SKIP" ;
label define WEEKS     94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define SOC1      1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ASOC1     999985 "BAD DATA Logically assigned"
                       999994 "DONT KNOW" 999997 "REFUSED"
                       999998 "BLANK (NO ANSWER)" 999999 "LEGITIMATE SKIP" ;
label define SSI1      1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define ASSI1     999985 "BAD DATA Logically assigned"
                       999994 "DONT KNOW" 999997 "REFUSED"
                       999998 "BLANK (NO ANSWER)" 999999 "LEGITIMATE SKIP" ;
label define PUB1      1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       94 "DONT KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define AFDC1     1 "Income from AFDC/ADC" 2 "Income from other"
                       3 "Income from both" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define WEL1      1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define AWEL1     999985 "BAD DATA Logically assigned"
                       999994 "DONT KNOW" 999997 "REFUSED"
                       999998 "BLANK (NO ANSWER)" 999999 "LEGITIMATE SKIP" ;
label define INT1      1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       4 "No LOGICALLY IMPUTED" 94 "DONT KNOW"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define AINT1     999985 "BAD DATA Logically assigned"
                       999994 "DONT KNOW" 999997 "REFUSED"
                       999998 "BLANK (NO ANSWER)" 999999 "LEGITIMATE SKIP" ;
label define CHD1      1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       4 "No LOGICALLY IMPUTED" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define ACHD1     999985 "BAD DATA Logically assigned"
                       999994 "DONT KNOW" 999997 "REFUSED"
                       999998 "BLANK (NO ANSWER)" 999999 "LEGITIMATE SKIP" ;
label define OTH1      1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       4 "No LOGICALLY IMPUTED" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define AOTH1     999985 "BAD DATA Logically assigned"
                       999989 "LEGITIMATE SKIP Logically assigned"
                       999994 "DONT KNOW" 999997 "REFUSED"
                       999998 "BLANK (NO ANSWER)" 999999 "LEGITIMATE SKIP" ;
label define FAMLYRES  1 "Yes" 2 "No" 94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define WAG2      1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       4 "No LOGICALLY IMPUTED"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define AWAG2     999985 "BAD DATA Logically assigned"
                       999989 "LEGITIMATE SKIP Logically assigned"
                       999994 "DONT KNOW" 999997 "REFUSED"
                       999998 "BLANK (NO ANSWER)" 999999 "LEGITIMATE SKIP" ;
label define SOC2      1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       4 "No LOGICALLY IMPUTED"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ASOC2     999985 "BAD DATA Logically assigned"
                       999989 "LEGITIMATE SKIP Logically assigned"
                       999994 "DONT KNOW" 999997 "REFUSED"
                       999998 "BLANK (NO ANSWER)" 999999 "LEGITIMATE SKIP" ;
label define SSI2      1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       4 "No LOGICALLY IMPUTED"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ASSI2     999985 "BAD DATA Logically assigned"
                       999989 "LEGITIMATE SKIP Logically assigned"
                       999994 "DONT KNOW" 999997 "REFUSED"
                       999998 "BLANK (NO ANSWER)" 999999 "LEGITIMATE SKIP" ;
label define PUB2      1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define AFDC2     1 "Income from AFDC/ADC" 2 "Income from other"
                       3 "Income from both"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define WEL2      1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define AWEL2     999985 "BAD DATA Logically assigned"
                       999989 "LEGITIMATE SKIP Logically assigned"
                       999994 "DONT KNOW" 999997 "REFUSED"
                       999998 "BLANK (NO ANSWER)" 999999 "LEGITIMATE SKIP" ;
label define INT2      1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       4 "No LOGICALLY IMPUTED"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define AINT2     999985 "BAD DATA Logically assigned"
                       999989 "LEGITIMATE SKIP Logically assigned"
                       999994 "DONT KNOW" 999997 "REFUSED"
                       999998 "BLANK (NO ANSWER)" 999999 "LEGITIMATE SKIP" ;
label define CHD2      1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       4 "No LOGICALLY IMPUTED"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define ACHD2     999985 "BAD DATA Logically assigned"
                       999989 "LEGITIMATE SKIP Logically assigned"
                       999994 "DONT KNOW" 999997 "REFUSED"
                       999998 "BLANK (NO ANSWER)" 999999 "LEGITIMATE SKIP" ;
label define OTH2      1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       4 "No LOGICALLY IMPUTED"
                       89 "LEGITIMATE SKIP Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define AOTH2     999985 "BAD DATA Logically assigned"
                       999989 "LEGITIMATE SKIP Logically assigned"
                       999994 "DONT KNOW" 999997 "REFUSED"
                       999998 "BLANK (NO ANSWER)" 999999 "LEGITIMATE SKIP" ;
label define WHOANSIN  1 "Sample member"
                       2 "Proxy, relationship to sample member not"
                       12 "Spouse" 13 "Live-in partner, fiancee" 14 "Mother"
                       15 "Father" 16 "Daughter" 17 "Son" 18 "Sister"
                       19 "Brother" 20 "Grandmother" 21 "Grandfather"
                       22 "Other female blood relative"
                       23 "Other male blood relative" 25 "Father-in-law"
                       26 "Other female in-laws" 27 "Other male in-laws"
                       28 "Close female friend"
                       29 "Other male acquaintance, roommate"
                       30 "Other female acquaintance, roommate"
                       31 "Other male acquaintance, roommate"
                       32 "Step-mother" 33 "Step-father"
                       40 "Friend (sex unspecified), boarder" 41 "Parents"
                       42 "Grandparents" 43 "Guardian (sex unspecified)"
                       44 "Foster mother, female guardian"
                       50 "Multiple people listed"
                       51 "Relative, sex not specified" 56 "Unspecified"
                       61 "Siblings" 89 "LEGITIMATE SKIP Logically assigned"
                       94 "DONT KNOW" 96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" 99 "LEGITIMATE SKIP" ;
label define FSTAMP    1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       4 "No LOGICALLY IMPUTED" 94 "DONT KNOW"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define PEOPFD    85 "BAD DATA Logically assigned" 94 "DONT KNOW"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP" ;
label define FOOD      1 "Yes" 2 "No" 3 "Yes LOGICALLY IMPUTED"
                       4 "No LOGICALLY IMPUTED" 94 "DONT KNOW" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define AFOOD     999985 "BAD DATA Logically assigned"
                       999994 "DONT KNOW" 999997 "REFUSED"
                       999998 "BLANK (NO ANSWER)" 999999 "LEGITIMATE SKIP" ;
label define BAP       1 "AM" 2 "PM" 98 "BLANK (NO ANSWER)" ;
label define EAP       1 "AM" 2 "PM" 96 "MULTIPLE RESPONSE"
                       98 "BLANK (NO ANSWER)" ;
label define LANGVER   1 "English" 2 "Spanish" 98 "BLANK (NO ANSWER)" ;
label define UNDINT    1 "No difficulty-no language or reading pro"
                       2 "Just a little difficulty-almost no lang/"
                       3 "Fair amount of difficulty-some lang/read"
                       4 "A lot of difficulty-considerable lang/re"
                       94 "DONT KNOW" 96 "MULTIPLE RESPONSE"
                       98 "BLANK (NO ANSWER)" ;
label define COOPINT   1 "Very cooperative" 2 "Fairly cooperative"
                       3 "Not very cooperative" 4 "Openly hostile"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define PRIVACY   1 "Completely private-no one present/able t"
                       3 "Minor distractions"
                       5 "Person(s) in room or listening 1/3 of th"
                       7 "Serious interruptions more than half the"
                       9 "Constant presence of other person(s)"
                       85 "BAD DATA Logically assigned"
                       98 "BLANK (NO ANSWER)" ;
label define PPRES     1 "Response circled" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (PRIVACY=1)" ;
label define SPRES     2 "Response circled" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (PRIVACY=1)" ;
label define PARPRES   3 "Response circled" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (PRIVACY=1)" ;
label define OARPRES   4 "Response circled" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (PRIVACY=1)" ;
label define OAPRES    5 "Response circled" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (PRIVACY=1)" ;
label define CPRES     6 "Response circled" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (PRIVACY=1)" ;
label define OPRESNSP  7 "Response circled" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (PRIVACY=1)" ;
label define OPRESSPA  11 "Head of household, employer"
                       12 "Spouse, ex-husband supports"
                       13 "Live-in partner,fiancee" 14 "Mother" 15 "Father"
                       16 "Daughter" 17 "Son" 18 "Sister" 19 "Brother"
                       20 "Grandmother" 21 "Grandfather"
                       22 "Other female blood relative"
                       23 "Other male blood relative" 25 "Father-in-law"
                       27 "Other male in-laws" 28 "Close female friend"
                       29 "Close male friend"
                       30 "Other female acquaintance,roommate"
                       31 "Other male acquaintance, roommate"
                       32 "Step-mother" 33 "Step-father" 34 "Step-son"
                       35 "Step-daughter" 38 "Other step relative, female"
                       40 "Friend (sex unspecified), boarder" 41 "Parents"
                       42 "Grandparents" 43 "Guardian(sex unspecified)"
                       44 "Foster mother, female guardian"
                       46 "Governess, nanny or live-in babysitter"
                       47 "Home care worker or health care aide"
                       48 "Housekeeper or maid" 50 "Multiple people listed"
                       51 "Relative, sex not specified"
                       52 "Roommate, sex not specified"
                       53 "Neighbor, sex not specified" 55 "Escort"
                       56 "Unspecified relationship"
                       59 "Adult children/children" 61 "Siblings"
                       62 "Co-worker" 63 "Visitor"
                       66 "Child (specified or not specified) = Cod"
                       72 "Customers" 98 "BLANK (NO ANSWER)"
                       99 "LEGITIMATE SKIP (PRIVACY=1)" ;
label define WHOMARKD  1 "Respondent marked ALL the Answer Sheet r"
                       2 "Interviewer marked All the Answer Sheet"
                       3 "Combination of respondent and F.I"
                       96 "MULTIPLE RESPONSE" 98 "BLANK (NO ANSWER)" ;
label define QUARTER   1 "Quarter 1" 2 "Quarter 2" 3 "Quarter 3"
                       4 "Quarter 4" ;
label define FAMSKIP   0 "Respondent has other family members in h"
                       1 "Respondent didnt have other family in h"
                       98 "BLANK (NO ANSWER)" ;
label define GQTYPE    1 "Halfway House" 2 "Boarding House" 3 "College Dorm"
                       4 "Shelter" 5 "Other" 9 "Not Group Quarters" ;
label define PDEN      1 "Segment in an MSA with 1 million or more"
                       2 "Segment in an MSA with fewer than 1 mill"
                       3 "Segment not in an MSA" ;
label define PDEN2     1 "Segment in an MSA with 1 million or more"
                       2 "Segm. in an MSA from 250000 to 999999 pe"
                       3 "Segment in an MSA with fewer than 250000"
                       4 "Segment not in an MSA and not in a rural"
                       5 "Segment not in an MSA and in a rural are" ;
label define DC        1 "Low SES - DC" 2 "Not Low SES - DC" 9 "NOT IN DC" ;
label define CHICAGO   1 "Low SES - CHICAGO" 2 "Not Low SES - CHICAGO"
                       9 "Not in CHICAGO" ;
label define DENVER    1 "Low SES - DENVER" 2 "Not Low SES - DENVER"
                       9 "Not in DENVER" ;
label define LA        1 "Low SES - LA" 2 "Not Low SES - LA" 9 "Not in LA" ;
label define MIAMI     1 "Low SES - MIAMI" 2 "Not Low SES - MIAMI"
                       9 "Not in MIAMI" ;
label define NEWYORK   1 "Low SES - NEW YORK" 2 "Not Low SES - NEW YORK"
                       9 "Not in NEW YORK" ;
label define REGION    1 "Northeast" 2 "North Central" 3 "South" 4 "West" ;
label define DIVISION  1 "New England" 2 "Middle Atlantic"
                       3 "East North Central" 4 "West North Central"
                       5 "South Atlantic" 6 "East South Central"
                       7 "West South Central" 8 "Mountain" 9 "Pacific" ;
label define URBARE    1 "Yes" 2 "No"
                       3 "Not in any of the 6 Metropolitan areas"
                       9 "Data suppressed for reasons of confident" ;
label define METRO     1 "Chicago Metropolitan area"
                       2 "Denver Metropolitan area"
                       3 "Los Angeles Metropolitan area"
                       4 "Miami Metropolitan area"
                       5 "New York Metropolitan area"
                       6 "Washington, D.C. Metropolitan area"
                       9 "Not in any of the 6 Metropolitan areas" ;
label define IIAGE     1 "Age from birthdate"
                       2 "Age from cover of questionnaire"
                       3 "Age from roster"
                       4 "Age statistically imputed using age gr f" ;
label define IRSEX     1 "Male" 2 "Female" ;
label define IISEX     1 "Sex from questionnaire" 2 "Sex from roster" ;
label define IRRACE    1 "American indian or Alaskan native"
                       2 "Asian or Pacific islander" 3 "Black" 4 "White" ;
label define IIRACE    1 "Race from questionnaire"
                       2 "Race from interviewer observation"
                       3 "Race from roster"
                       4 "Race statis imputed using race - Other"
                       5 "Race statistically imputed, no infor. fr" ;
label define IRHOIND   1 "Hispanic" 2 "Nonhispanic" ;
label define IIHOIND   1 "Hispanicity derived from questionnaire"
                       2 "Hispanicity derived from roster" ;
label define IRHOGRP   1 "Puerto Rican" 2 "Mexican" 3 "Cuban" 4 "Other"
                       99 "LEGITIMATE SKIP" ;
label define IRHOGRP2  1 "Puerto Rican" 2 "Mexican" 3 "Cuban" 4 "Other"
                       5 "Central American" 6 "South American" 7 "Caribbean"
                       99 "LEGITIMATE SKIP Respondent is not hispan" ;
label define IIHOGRP2  1 "Hispanic-Origin Group taken from questio"
                       3 "Statistically imputed data"
                       9 "LEGITIMATE SKIP Respondent is not hispan" ;
label define IRMARIT   1 "Married" 2 "Widowed" 3 "Divorced or Separated"
                       4 "Never Married" 99 "LEGITIMATE SKIP" ;
label define IIMARIT   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IREDUC    0 "No schooling" 1 "First grade" 2 "Second grade"
                       3 "Third grade" 4 "Fourth grade" 5 "Fifth grade"
                       6 "Sixth grade" 7 "Seventh grade" 8 "Eighth grade"
                       9 "Ninth grade" 10 "Tenth grade" 11 "Eleventh grade"
                       12 "Twelfth grade" 13 "One year of college"
                       14 "Two years of college" 15 "Three years of college"
                       16 "Four years of college"
                       17 "Graduate/professional school" ;
label define IIEDUC    1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRHSGRAD  1 "Yes, graduated from high school"
                       2 "No, did not graduate from high school" ;
label define IIHSGRAD  1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define IRPINSUR  1 "Yes, respondent does have private health"
                       2 "No, respondent does not have private hea" ;
label define IIPINSUR  1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define IRINSUR   1 "Yes, respondent does have health insuran"
                       2 "No, respondent does not have health insu" ;
label define IIINSUR   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define IRWAG1    1 "Yes" 2 "No" ;
label define IIWAG1    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define IRAWAG1   0 "Zero income received" ;
label define IIAWAG1   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IRSOC1    1 "Yes" 2 "No" ;
label define IISOC1    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define IRASOC1   0 "Zero income received" ;
label define IIASOC1   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IRSSI1    1 "Yes" 2 "No" ;
label define IISSI1    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define IRASSI1   0 "Zero income received" ;
label define IIASSI1   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IRWEL1    1 "Yes" 2 "No" ;
label define IIWEL1    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define IRAWEL1   0 "Zero income received" ;
label define IIAWEL1   1 "Questionnaire data" 3 "Statistically imputed data"
                       9 "LEGITIMATE SKIP" ;
label define IRINT1    1 "Yes" 2 "No" ;
label define IIINT1    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define IRAINT1   0 "Zero income received" ;
label define IIAINT1   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IRCHD1    1 "Yes" 2 "No" ;
label define IICHD1    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define IRACHD1   0 "Zero income received" ;
label define IIACHD1   1 "Questionnaire data" 3 "Statistically imputed data"
                       9 "LEGITIMATE SKIP" ;
label define IROTH1    1 "Yes" 2 "No" ;
label define IIOTH1    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define IRAOTH1   0 "Zero income received" ;
label define IIAOTH1   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IRWAG2    1 "Yes" 2 "No" ;
label define IIWAG2    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IRAWAG2   0 "Zero income received" ;
label define IIAWAG2   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IRSOC2    1 "Yes" 2 "No" ;
label define IISOC2    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IRASOC2   0 "Zero income received" ;
label define IIASOC2   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IRSSI2    1 "Yes" 2 "No" ;
label define IISSI2    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IRASSI2   0 "Zero income received" ;
label define IIASSI2   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IRWEL2    1 "Yes" 2 "No" ;
label define IIWEL2    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IRAWEL2   0 "Zero income received" ;
label define IIAWEL2   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IRINT2    1 "Yes" 2 "No" ;
label define IIINT2    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IRAINT2   0 "Zero income received" ;
label define IIAINT2   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IRCHD2    1 "Yes" 2 "No" ;
label define IICHD2    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IRACHD2   0 "Zero income received" ;
label define IIACHD2   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IROTH2    1 "Yes" 2 "No" ;
label define IIOTH2    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IRAOTH2   0 "Zero income received" ;
label define IIAOTH2   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IRFOOD    1 "Yes" 2 "No" ;
label define IIFOOD    1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" ;
label define IRAFOOD   0 "Zero income received" ;
label define IIAFOOD   1 "Questionnaire data" 2 "Logically imputed data"
                       3 "Statistically imputed data" 9 "LEGITIMATE SKIP" ;
label define IRALCRC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago" 9 "Never used alcohol" ;
label define IIALCRC   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRMJRC    1 "Within the past week (7 days)"
                       2 "More than 1 week ago but less than 1 mon"
                       3 "1 or more months ago but less than 6 mon"
                       4 "6 or more months ago but less than 1 yea"
                       5 "1 or more years ago but less than 3 year"
                       6 "3 or more years ago" 9 "Never used marijuana" ;
label define IIMJRC    1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRCOCRC   1 "Within the past week (7 days)"
                       2 "More than 1 week ago but less than 1 mon"
                       3 "1 or more months ago but less than 6 mon"
                       4 "6 or more months ago but less than 1 yea"
                       5 "1 or more years ago but less than 3 year"
                       6 "3 or more years ago" 9 "Never used cocaine" ;
label define IICOCRC   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRSEDRC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago" 9 "Never used sedatives" ;
label define IISEDRC   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRTRNRC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago" 9 "Never used tranquilizers" ;
label define IITRNRC   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRSTMRC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago" 9 "Never used stimulants" ;
label define IISTMRC   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRANLRC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago" 9 "Never used analgesics" ;
label define IIANLRC   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRCIGRC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago" 9 "Never smoked cigarettes" ;
label define IICIGRC   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IROTBRC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago"
                       9 "Never used smokeless tobacco" ;
label define IIOTBRC   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRINHRC   1 "Within the past week (7 days)"
                       2 "More than 1 week ago but less than 1 mon"
                       3 "1 or more months ago but less than 6 mon"
                       4 "6 or more months ago but less than 1 yea"
                       5 "1 or more years ago but less than 3 year"
                       6 "3 or more years ago" 9 "Never used inhalants" ;
label define IIINHRC   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRCRKRC   1 "Within the past week (7 days)"
                       2 "More than 1 week ago but less than 1 mon"
                       3 "1 or more months ago but less than 6 mon"
                       4 "6 or more months ago but less than 1 yea"
                       5 "1 or more years ago but less than 3 year"
                       6 "3 or more years ago" 9 "Never used CRACK" ;
label define IICRKRC   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRHALRC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago" 9 "Never used hallucinogens" ;
label define IIHALRC   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRHERRC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago" 9 "Never used heroin" ;
label define IIHERRC   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRPCPRC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago" 9 "Never used PCP" ;
label define IIPCPRC   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRICERC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago but less than 10 yea"
                       6 "10 or more years ago" 9 "Never used ice" ;
label define IIICERC   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRSTRRC   1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago"
                       9 "Never used anabolic steroids" ;
label define IISTRRC   1 "Questionnaire data" 3 "Statistically imputed data" ;
label define IRALCFQ   1 "Used daily in past year"
                       2 "Used almost daily in past year"
                       3 "Used 1-2 days per week in past year"
                       4 "Used several times a month in past year"
                       5 "Used 1-2 times per month in past year"
                       6 "Used every other month in past year"
                       7 "Used 3-5 times in past year"
                       8 "Used 1-2 times in past year"
                       9 "Never used or did not use in the past ye" ;
label define IIALCFQ   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRMJFQ    1 "Used several times per day in past year"
                       2 "Used daily in past year"
                       3 "Used almost daily in past year"
                       4 "Used 1-2 days per week in past year"
                       5 "Used several times per month in past yea"
                       6 "Used 1-2 times per month in past year"
                       7 "Used every other month in past year"
                       8 "Used 3-5 times in past year"
                       9 "Used 1-2 times in past year"
                       10 "Never used or did not use in the past ye" ;
label define IIMJFQ    1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRCOCFQ   1 "Used daily in past year"
                       2 "Used almost daily in past year"
                       3 "Used 1-2 days per week in past year"
                       4 "Used several times per month in past yea"
                       5 "Used 1-2 times per month in past year"
                       6 "Used every other month in past year"
                       7 "Used 3-5 times in past year"
                       8 "Used 1-2 times in past year"
                       9 "Never used or did not use in the past ye" ;
label define IICOCFQ   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRSEDFQ   1 "Used daily in past year"
                       2 "Used almost daily in past year"
                       3 "Used 1-2 days per week in past year"
                       4 "Used several times a month in past year"
                       5 "Used 1-2 times per month in past year"
                       6 "Used every other month in past year"
                       7 "Used 3-5 times in past year"
                       8 "Used 1-2 times in past year"
                       9 "Never used or did not use in the past ye" ;
label define IISEDFQ   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRTRNFQ   1 "Used daily in past year"
                       2 "Used almost daily in past year"
                       3 "Used 1-2 days per week in past year"
                       4 "Used several times a month in past year"
                       5 "Used 1-2 times per month in past year"
                       6 "Used every other month in past year"
                       7 "Used 3-5 times in past year"
                       8 "Used 1-2 times in past year"
                       9 "Never used or did not use in the past ye" ;
label define IITRNFQ   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRSTMFQ   1 "Used daily in past year"
                       2 "Used almost daily in past year"
                       3 "Used 1-2 days per week in past year"
                       4 "Used several times a month in past year"
                       5 "Used 1-2 times per month in past year"
                       6 "Used every other month in past year"
                       7 "Used 3-5 times in past year"
                       8 "Used 1-2 times in past year"
                       9 "Never used or did not use in the past ye" ;
label define IISTMFQ   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRANLFQ   1 "Used daily in past year"
                       2 "Used almost daily in past year"
                       3 "Used 1-2 days per week in past year"
                       4 "Used several times a month in past year"
                       5 "Used 1-2 times per month in past year"
                       6 "Used every other month in past year"
                       7 "Used 3-5 times in past year"
                       8 "Used 1-2 times in past year"
                       9 "Never used or did not use in the past ye" ;
label define IIANLFQ   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IROTBFQ   1 "Used daily in past year"
                       2 "Used almost daily in past year"
                       3 "Used 1-2 days per week in past year"
                       4 "Used several times a month in past year"
                       5 "Used 1-2 times per month in past year"
                       6 "Used every other month in past year"
                       7 "Used 3-5 times in past year"
                       8 "Used 1-2 times in past year"
                       9 "Never used or did not use in the past ye" ;
label define IIOTBFQ   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRINHFQ   1 "Use daily in past year"
                       2 "Used almost daily in past year"
                       3 "Used 1-2 days per week in past year"
                       4 "Used several times a month in past year"
                       5 "Used 1-2 times per month in past year"
                       6 "Used every other month in past year"
                       7 "Used 3-5 times in past year"
                       8 "Used 1-2 times in past year"
                       9 "Never used or did not use in the past ye" ;
label define IIINHFQ   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define IRHALFQ   1 "Used daily in past year"
                       2 "Used almost daily in past year"
                       3 "Used 1-2 days per week in past year"
                       4 "Used several times a month in past year"
                       5 "Used 1-2 times per month in past year"
                       6 "Used every other month in past year"
                       7 "Used 3-5 times in past year"
                       8 "Used 1-2 times in past year"
                       9 "Never used or did not use in the past ye" ;
label define IIHALFQ   1 "Questionnaire data" 2 "Imputed data"
                       3 "Statistically imputed data" ;
label define CATAGE    1 "12-17 years (IRAGE = 12-17)"
                       2 "18-25 years (IRAGE = 18-25)"
                       3 "26-34 years (IRAGE = 26-34)"
                       4 "35+ years (IRAGE > 34)" ;
label define CATAG2    1 "12-17 years (CATAGE = 1)"
                       2 "18-25 years (CATAGE = 2)"
                       3 "26+ years (CATAGE = 3-4)" ;
label define CATAG3    1 "12-17 years (IRAGE = 12-17)"
                       2 "18-25 years IRAGE = 18-25)"
                       3 "26-34 years IRAGE = 26-34)"
                       4 "35-49 years IRAGE = 35-49)"
                       5 "50+ years (IRAGE > 49)" ;
label define RACE      1 "White (IRRACE = 4 and IRHOIND = 2)"
                       2 "Black (IRRACE = 3 and IRHOIND = 2)"
                       3 "Hispanic (IRHOIND = 1)"
                       4 "Other (IRRACE = 1-2 and IRHOIND = 2)" ;
label define HISPRACE  1 "HISPANIC" 2 "NONHISPANIC BLACK"
                       3 "NONHISPANIC NONBLACK" ;
label define EDUCCAT2  1 "Less than high school (IREDUC=0-11 and I"
                       2 "High school graduate (IREDUC = 12 and IR"
                       3 "Some college (IREDUC = 13-15 and IRAGE ="
                       4 "College graduate (IREDUC = 16-17 and IRA"
                       5 "12-17 year olds (IRAGE = 12-17)" ;
label define EMPSTAT2  1 "Full=time (IRWORKST =1,3 and IRAGE => 18"
                       2 "Part-time (IRWORKST = 2 and IRAGE => 18)"
                       3 "Unemployed (IRWORKST = 4,5,10 and IRAGE"
                       4 "Other (IRWORKST = 6-9,11 and IRAGE => 18"
                       5 "12-17 year olds (IRAGE = 12-17)" ;
label define IIINDINC  1 "All personal income sources from questio"
                       3 "At least 1 of sources were stat or logic" ;
label define INDCAT    1 "$0" 2 "$1-$4,999" 3 "$5,000-$6,999"
                       4 "$7,000-$8,999" 5 "$9,000-$11,999"
                       6 "$12,000-$14,999" 7 "$15,000-$19,999"
                       8 "$20,000-$24,999" 9 "$25,000-$29,999"
                       10 "$30,000-$39,999" 11 "$40,000-$49,999"
                       12 "$50,000-$74,999" 13 "$75,000+" ;
label define PERINC    1 "$0-$8,999" 2 "$9,000-$19,999" 3 "$20,000-$39,999"
                       4 "$40,000-$74,999" 5 "$75,000+" ;
label define PERINC2   1 "$0-$9,999" 2 "$10,000-$19,999" 3 "$20,000-$29,999"
                       4 "$30,000-$39,999" 5 "$40,000-$49,999"
                       6 "$50,000-$74,999" 7 "$75,000+" ;
label define PERINC3   1 "$0-$9,999" 2 "$10,000-$19,999" 3 "$20,000-$29,999"
                       4 "$30,000-$39,999" 5 "$40,000-$49,999"
                       6 "$50,000-$74,999" 7 "$75,000+" 8 "12-17 Years Old" ;
label define TOTINC    0 "No family income" ;
label define IITOTINC  1 "All income sources from questionnaire"
                       3 "At least 1 of sources were stat or logic" ;
label define TOTCAT    1 "$0" 2 "$1-$4,999" 3 "$5,000-$6,999"
                       4 "$7,000-$8,999" 5 "$9,000-$11,999"
                       6 "$12,000-$14,999" 7 "$15,000-$19,999"
                       8 "$20,000-$24,999" 9 "$25,000-$29,999"
                       10 "$30,000-$39,999" 11 "$40,000-$49,999"
                       12 "$50,000-$74,999" 13 "$75,000+" ;
label define FAMINC    1 "$0-$8,999" 2 "$9,000-$19,999" 3 "$20,000-$39,999"
                       4 "$40,000-$74,999" 5 "$75,000+" ;
label define FAMINC2   1 "$0-$9,999" 2 "$10,000-$19,999" 3 "$20,000-$29,999"
                       4 "$30,000-$39,999" 5 "$40,000-$49,999"
                       6 "$50,000-$74,999" 7 "$75,000+" ;
label define FAMINC3   1 "$0-$9,999" 2 "$10,000-$19,999" 3 "$20,000-$29,999"
                       4 "$30,000-$39,999" 5 "$40,000-$49,999"
                       6 "$50,000-$74,999" 7 "$75,000+" 8 "12-17 Years Old" ;
label define WELFARE   1 "Yes, respondent or another fam member on"
                       2 "No, there was no one in the family on we" ;
label define HALFLAG   0 "Never used (IRHALRC = 9)"
                       1 "Ever used (IRHALRC = 1-5)" ;
label define HALYR     0 "Did not use in the past year (IRHALRC ="
                       1 "Used within the past year (IRHALRC = 1-3" ;
label define HALMON    0 "Did not use in the past month (IRHALRC ="
                       1 "Used within the past month (IRHALRC = 1)" ;
label define PCPFLAG   0 "Never used (IRPCPRC = 9)"
                       1 "Ever used (IRPCPRC = 1,5)" ;
label define PCPYR     0 "Did not use in the past year (IRPCPRC ="
                       1 "Used within the past year (IRPCPRC = 1-3" ;
label define PCPMON    0 "Did not use in the past month (IRPCPRC ="
                       1 "Used within the past month (IRPCPRC = 1)" ;
label define STMFLAG   0 "Never used (IRSTMRC = 9)"
                       1 "Ever used (IRSTMRC = 1-5)" ;
label define STMYR     0 "Did not use in the past year (IRSTMRC ="
                       1 "Used within the past year (IRSTMRC = 1-3" ;
label define STMMON    0 "Did not use in the past month (IRSTMRC ="
                       1 "Used within the past month (IRSTMRC = 1)" ;
label define SEDFLAG   0 "Never used (IRSEDRC = 9)"
                       1 "Ever used (IRSEDRC = 1-5)" ;
label define SEDYR     0 "Did not use in the past year (IRSEDRC ="
                       1 "Used within the past year (IRSEDRC = 1-3" ;
label define SEDMON    0 "Did not use in the past month (IRSEDRC ="
                       1 "Used within the past month (IRSEDRC = 1)" ;
label define TRQFLAG   0 "Never used (IRTRNRC = 9)"
                       1 "Ever used (IRTRNRC = 1-5)" ;
label define TRQYR     0 "Did not use in the past year (IRTRNRC ="
                       1 "Used within the past year (IRTRNRC = 1-3" ;
label define TRQMON    0 "Did not use in the past month (IRTRNRC ="
                       1 "Used within the past month (IRTRNRC = 1)" ;
label define ANLFLAG   0 "Never used (IRANLRC = 9)"
                       1 "Ever used (IRANLRC = 1-5)" ;
label define ANLYR     0 "Did not use in the past year (IRANLRC ="
                       1 "Used within the past year (IRANLRC = 1-3" ;
label define ANLMON    0 "Did not use in the past month (IRANLRC ="
                       1 "Used within the past month (IRANLRC = 1)" ;
label define ALCFLAG   0 "Never used (IRALCRC = 9)"
                       1 "Ever used (IRALCRC = 1-5)" ;
label define ALCYR     0 "Did not use in the past year (IRALCRC ="
                       1 "Used within the past year (IRALCRC = 1-3" ;
label define ALCMON    0 "Did not use in the past month (IRALCRC ="
                       1 "Used within the past month (IRALCRC = 1)" ;
label define CIGFLAG   0 "Never used (IRCIGRC = 9)"
                       1 "Ever used (IRCIGRC = 1-5)" ;
label define CIGYR     0 "Did not use in the past year (IRCIGRC ="
                       1 "Used within the past year (IRCIGRC = 1-3" ;
label define CIGMON    0 "Did not use in the past month (IRCIGRC ="
                       1 "Used within the past month (IRCIGRC = 1)" ;
label define SMKFLAG   0 "Never used (IROTBRC = 9)"
                       1 "Ever used (IROTBRC = 1-5)" ;
label define SMKYR     0 "Did not use in the past year (IROTBRC ="
                       1 "Used within the past year (IROTBRC = 1-3" ;
label define SMKMON    0 "Did not use in the past month (IROTBRC ="
                       1 "Used within the past month (IROTBRC = 1)" ;
label define HERFLAG   0 "Never used (IRHERRC = 9)"
                       1 "Ever used (IRHERRC = 1-5)" ;
label define HERYR     0 "Did not use in the past year (IRHERRC ="
                       1 "Used within the past year (IRHERRC = 1-3" ;
label define HERMON    0 "Did not use in the past month (IRHERRC ="
                       1 "Used within the past month (IRHERRC = 1)" ;
label define STRFLAG   0 "Never used (IRSTRRC = 9)"
                       1 "Ever used (IRSTRRC = 1-5)" ;
label define STRYR     0 "Did not use in the past year (IRSTRRC ="
                       1 "Used within the past year (IRSTRRC = 1-3" ;
label define STRMON    0 "Did not use in the past month (IRSTRRC ="
                       1 "Used within the past month (IRSTRRC = 1)" ;
label define MRJFLAG   0 "Never used (IRMJRC = 9)"
                       1 "Ever used (IRMJRC = 1-6)" ;
label define MRJYR     0 "Did not use in the past year (IRMJRC = 5"
                       1 "Used within the past year (IRMJRC = 1-4)" ;
label define MRJMON    0 "Did not use in the past month (IRMJRC ="
                       1 "Used within the past month (IRMJRC = 1-2" ;
label define COCFLAG   0 "Never used (IRCOCRC = 9)"
                       1 "Ever used (IRCOCRC = 1-6)" ;
label define COCYR     0 "Did not use in the past year (IRCOCRC ="
                       1 "Used within the past year (IRCOCRC = 1-4" ;
label define COCMON    0 "Did not use in the past month (IRCOCRC ="
                       1 "Used within the past month (IRCOCRC = 1-" ;
label define CRKFLAG   0 "Never used (IRCRKRC = 9)"
                       1 "Ever used (IRCRKRC = 1-6)" ;
label define CRKYR     0 "Did not use in the past year (IRCRKRC= 5"
                       1 "Used within the past year (IRCRKRC = 1-4" ;
label define CRKMON    0 "Did not use in the past month (IRCRKRC ="
                       1 "Used within the past month (IRCRKRC = 1-" ;
label define INHFLAG   0 "Never used (IRINHRC = 9)"
                       1 "Ever used (IRINHRC = 1-6)" ;
label define INHYR     0 "Did not use in the past year (IRINHRC ="
                       1 "Used within the past year (IRINHRC = 1-4" ;
label define INHMON    0 "Did not use in the past month (IRINHRC ="
                       1 "Used within the past month (IRINHRC = 1-" ;
label define ICEFLAG   0 "Never used (IRICERC = 9)"
                       1 "Ever used (IRICERC = 1-6)" ;
label define NEEDLREC  1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago but less than 10 yea"
                       6 "10 or more years ago"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       91 "NEVER USED A NEEDLE TO INJECT ANY DRUG"
                       98 "NEEDLE USE NOT INDICATED BUT 1+ SOURCE V" ;
label define NDL90REC  1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago but less than 10 yea"
                       6 "10 or more years ago"
                       8 "Use in past year LOGICALLY IMPUTED"
                       9 "Use in lifetime LOGICALLY IMPUTED"
                       91 "NEVER USED A NEEDLE TO INJECT ANY DRUG"
                       98 "NEEDLE USE NOT INDICATED BUT 1+ SOURCE V" ;
label define NEDFLAG3  0 "Never used (NDL90REC=91,98)"
                       1 "Ever used (NDL90REC=1-9)" ;
label define NEDYR3    0 "Never used (NDL90REC=4-6,9,91,98)"
                       1 "Ever used (NDL90REC=1-3,8)" ;
label define HALYRF    0 "Never used or did not use in past year ("
                       1 "Any use within the past year (IRHALFQ=1-" ;
label define HALMONF   0 "Did not use monthly/more past year (IRHA"
                       1 "Used monthly or more often past year (IR" ;
label define HALWKF    0 "Did not use weekly or more past year (IR"
                       1 "Used weekly or more often past year (IRH" ;
label define HALOCCF   0 "Used monthly/more or none in pst yr(IRHA"
                       1 "Used past year but less than monthly (IR" ;
label define HALDLYF   0 "Did not use daily/almost daily pst yr(IR"
                       1 "Used daily/almost daily in past year (IR" ;
label define STMYRF    0 "Never used or did not use in past year ("
                       1 "Any use within the past year (IRSTMFQ=1-" ;
label define STMMONF   0 "Did not use monthly/more past year (IRST"
                       1 "Used monthly or more often past year (IR" ;
label define STMWKF    0 "Did not use weekly or more past year (IR"
                       1 "Used weekly or more often past year (IRS" ;
label define STMOCCF   0 "Used monthly/more or none in pst yr(IRST"
                       1 "Used past year but less than monthly (IR" ;
label define STMDLYF   0 "Did not use daily/almost daily pst yr(IR"
                       1 "Used daily/almost daily in past year (IR" ;
label define SEDYRF    0 "Never used or did not use in past year ("
                       1 "Any use within the past year (IRSEDFQ=1-" ;
label define SEDMONF   0 "Did not use monthly/more past year (IRSE"
                       1 "Used monthly or more often past year (IR" ;
label define SEDWKF    0 "Did not use weekly or more past year (IR"
                       1 "Used weekly or more often past year (IRS" ;
label define SEDOCCF   0 "Used monthly/more or none in pst yr(IRSE"
                       1 "Used past year but less than monthly (IR" ;
label define SEDDLYF   0 "Did not use daily/almost daily pst yr(IR"
                       1 "Used daily/almost daily in past year (IR" ;
label define TRQYRF    0 "Never used or did not use in past year ("
                       1 "Any use within the past year (IRTRNFQ=1-" ;
label define TRQMONF   0 "Did not use monthly/more past year (IRTR"
                       1 "Used monthly or more often past year (IR" ;
label define TRQWKF    0 "Did not use weekly or more past year (IR"
                       1 "Used weekly or more often past year (IRT" ;
label define TRQOCCF   0 "Used monthly/more or none in pst yr(IRTR"
                       1 "Used past year but less than monthly (IR" ;
label define TRQDLYF   0 "Did not use daily/almost daily pst yr(IR"
                       1 "Used daily/almost daily in past year (IR" ;
label define ANLYRF    0 "Never used or did not use in past year ("
                       1 "Any use within the past year (IRANLFQ=1-" ;
label define ANLMONF   0 "Did not use monthly/more past year (IRAN"
                       1 "Used monthly or more often past year (IR" ;
label define ANLWKF    0 "Did not use weekly or more past year (IR"
                       1 "Used weekly or more often past year (IRA" ;
label define ANLOCCF   0 "Used monthly/more or none in pst yr(IRAN"
                       1 "Used past year but less than monthly (IR" ;
label define ANLDLYF   0 "Did not use daily/almost daily pst yr(IR"
                       1 "Used daily/almost daily in past year (IR" ;
label define ALCYRF    0 "Never used or not used in past year (IRA"
                       1 "Any use within the past year (IRALCFQ=1-" ;
label define ALCMONF   0 "Did not use monthly/more past year (IRAL"
                       1 "Used monthly or more often past year (IR" ;
label define ALCWKF    0 "Did not use weekly or more past year (IR"
                       1 "Used weekly or more in past year (IRALCF" ;
label define ALCOCCF   0 "Used monthly/more or none in pst yr(IRAL"
                       1 "Used past year but less than monthly (IR" ;
label define ALCDLYF   0 "Did not use daily/almost daily pst yr(IR"
                       1 "Used daily/almost daily in past year (IR" ;
label define SMKYRF    0 "Never used or did not use in past year ("
                       1 "Any use within the past year (IROTBFQ=1-" ;
label define SMKMONF   0 "Did not use monthly/more past year (IROT"
                       1 "Used monthly or more often past year (IR" ;
label define SMKWKF    0 "Did not use weekly or more past year (IR"
                       1 "Used weekly or more often past year (IRO" ;
label define SMKOCCF   0 "Used monthly/more or none in pst yr(IROT"
                       1 "Used past year but less than monthly (IR" ;
label define SMKDLYF   0 "Did not use daily/almost daily pst yr(IR"
                       1 "Used daily/almost daily in past year (IR" ;
label define MRJYRF    0 "Never used or did not use in past year ("
                       1 "Any use within the past year (IRMJFQ=1-9" ;
label define MRJMONF   0 "Did not use monthly/more past year (IRMJ"
                       1 "Used monthly or more in past year (IRMJF" ;
label define MRJWKF    0 "Did not use weekly/more past year (IRMJF"
                       1 "Used weekly or more in past year (IRMJFQ" ;
label define MRJOCCF   0 "Used monthly/more or none in pst yr(IRMJ"
                       1 "Used past year but less than monthly (IR" ;
label define MRJDLYF   0 "Did not use daily/almost daily pst yr(IR"
                       1 "Used daily/almost daily in past year (IR" ;
label define COCYRF    0 "Never used or did not use in past year ("
                       1 "Any use within the past year (IRCOCFQ =" ;
label define COCMONF   0 "Did not use monthly/more past year (IRCO"
                       1 "Used monthly or more often past year (IR" ;
label define COCWKF    0 "Did not use weekly or more past year (IR"
                       1 "Used weekly or more often past year (IRC" ;
label define COCOCCF   0 "Used monthly/more or none in pst yr(IRCO"
                       1 "Used past year but less than monthly (IR" ;
label define COCDLYF   0 "Did not use daily/almost daily pst yr(IR"
                       1 "Used daily/almost daily in past year (IR" ;
label define INHYRF    0 "Never used or did not use in past year ("
                       1 "Any use within the past year (IRINHFQ=1-" ;
label define INHMONF   0 "Did not use monthly/more past year (IRIN"
                       1 "Used monthly or more often past year (IR" ;
label define INHWKF    0 "Did not use weekly or more past year (IR"
                       1 "Used weekly or more often past year (IRI" ;
label define INHOCCF   0 "Used monthly/more or none in pst yr(IRIN"
                       1 "Used past year but less than monthly (IR" ;
label define INHDLYF   0 "Did not use daily/almost daily pst yr(IR"
                       1 "Used daily/almost daily in past year (IR" ;
label define PSYFLAG2  0 "Never used (ALL SOURCE VARIABLES = 9)"
                       1 "Ever used (ANY SOURCE VARIABLE)" ;
label define PSYYR2    0 "Did not use within past year (ALL SOURCE"
                       1 "Used in past year (ANY SOURCE VARIABLE)" ;
label define PSYMON2   0 "Did not use in past month (ALL SOURCE VA"
                       1 "Used in past month (ANY SOURCE VARIABLE" ;
label define SUMFLAG   0 "Never used (ALL SOURCE VARIABLES = 0)"
                       1 "Ever used (ANY SOURCE VARIABLE = 1)" ;
label define SUMYR     0 "Did not use in past year (ALL SOURCE VAR"
                       1 "Used in past year (ANY SOURCE VARIABLE =" ;
label define SUMMON    0 "Did not use in past month (ALL SOURCE VA"
                       1 "Used in past month (ANY SOURCE VARIABLE" ;
label define MJOFLAG   0 "Never used MJ/has used both MJ & anoth"
                       1 "Marijuana is only (illicit) drug ever us" ;
label define MJOYR2    0 "MJ not used past yr/Used MJ & othr dru"
                       1 "Marijuana is only (illicit) drug in past" ;
label define MJOMON2   0 "MJ not used past mnth/Used MJ & othr d"
                       1 "Marijuana only (illicit) drug in past mo" ;
label define IEMFLAG   0 "Never used drug/used only marijuana"
                       1 "Illicit drug except for marijuana are ev" ;
label define IEMYR     0 "Never used drug/used only marijuana past"
                       1 "Illicit drug except for marijuana used p" ;
label define IEMMON    0 "Never used drug/used only marijuana past"
                       1 "Illicit drug except for marijuana used p" ;
label define AL02      1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago" 91 "NEVER USED ALCOHOL"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define SE04      1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define TR04      1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define ST04      1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define ST07      1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago but less than 10 yea"
                       6 "10 or more years ago"
                       93 "NEVER USED AMPHETAMINES WITH A NEEDLE"
                       98 "BLANK (NO ANSWER)" ;
label define AN04      1 "Within past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago" 98 "BLANK (NO ANSWER)" ;
label define MJ04      1 "Within the past week (7 days)"
                       2 "More than 1 week ago but less than 1 mon"
                       3 "1 or more months ago but less than 6 mon"
                       4 "6 or more months ago but less than 1 yea"
                       5 "1 or more years ago but less than 3 year"
                       6 "3 or more years ago" 91 "NEVER USED MARIJUANA"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define IN04      1 "Within the past week (7 days)"
                       2 "More than 1 week ago but less than 1 mon"
                       3 "1 or more months ago but less than 6 mon"
                       4 "6 or more months ago but less than 1 yea"
                       5 "1 or more years ago but less than 3 year"
                       6 "3 or more years ago" 91 "NEVER USED INHALANTS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define CC04      1 "Within the past week (7 days)"
                       2 "More than 1 week ago but less than 1 mon"
                       3 "1 or more months ago but less than 6 mon"
                       4 "6 or more months ago but less than 1 yea"
                       5 "1 or more years ago but less than 3 year"
                       6 "3 or more years ago" 91 "NEVER USED COCAINE"
                       98 "BLANK (NO ANSWER)" ;
label define CC11      1 "Within past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago but less than 10 yea"
                       6 "10 or more years ago" 91 "NEVER USED COCAINE"
                       93 "NEVER USED COCAINE WITH A NEEDLE"
                       98 "BLANK (NO ANSWER)" ;
label define CK01      1 "Within the past week (7 days)"
                       2 "More than 1 week ago but less than 1 mon"
                       3 "1 or months ago but less than 6 months a"
                       4 "6 or months ago but less than 1 year ago"
                       5 "1 or more years ago but less than 3 year"
                       6 "3 or more years ago"
                       81 "NEVER USED CRACK Logically assigned"
                       91 "NEVER USED CRACK" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define LS05      1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago" 91 "NEVER USED HALLUCINOGENS"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define LS08      1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago" 91 "NEVER USED PCP"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HE04      1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago" 91 "NEVER USED HEROIN"
                       97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define HE07      1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago but less than 10 yea"
                       6 "10 or more years ago" 91 "NEVER USED HEROIN"
                       93 "NEVER USED HEROIN WITH A NEEDLE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define ND02      1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than a yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago but less than 10 yea"
                       6 "10 or more years ago"
                       91 "NEVER USED ANY DRUG FOR NONMEDICAL REASO"
                       93 "NEVER USED A NEEDLE TO TAKE ANY DRUG"
                       96 "MULTIPLE RESPONSE" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define SP04      1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "6 or more months ago but less than 1 yea"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago but less than 10 yea"
                       6 "10 or more years ago" 91 "NEVER USED ICR"
                       94 "DONT KNOW" 97 "REFUSED" 98 "BLANK (NO ANSWER)" ;
label define SP08      1 "Within the past month (30 days)"
                       2 "More than 1 month ago but less than 6 mo"
                       3 "More than 6 months ago but less than 1 y"
                       4 "1 or more years ago but less than 3 year"
                       5 "3 or more years ago"
                       91 "NEVER USED ANABOLIC STEROIDS" 97 "REFUSED"
                       98 "BLANK (NO ANSWER)" ;
label define CWEOCC2   990 "INDUSTRY NOT REPORTED" 994 "DONT KNOW"
                       995 "BAD DATA" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define ROCCUP2   990 "OCCUPATION NOT REPORTED" 995 "BAD DATA"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define BUSINES2  990 "INDUSTRY NOT REPORTED" 995 "BAD DATA"
                       997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define CWEBUS2   990 "INDUSTRY NOT REPORTED" 994 "DONT KNOW"
                       995 "BAD DATA" 997 "REFUSED" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define MJTOT2    1 "Never used marijuana (MJTOT = 81,91)"
                       2 "1-2 times (MJTOT = 1)" 3 "3-10 times (MJTOT = 2,3)"
                       4 "11-99 times (MJTOT = 4,5)"
                       5 "100 or more times (MJTOT = 6,7)"
                       6 "Unknown (MJTOT = 85,94,97,98)" ;
label define COCTOT2   1 "Never used cocaine (COCTOT = 81,91)"
                       2 "1-2 times (COCTOT = 1)"
                       3 "3-10 times (COCTOT = 2,3)"
                       4 "11-99 times (COCTOT = 4,5)"
                       5 "100 or more times (COCTOT = 6,7)"
                       6 "Unknown (COCTOT = 85,97,98)" ;
label define MJTOT3    1 "1-2 times (MJTOT2 = 2)" 2 "3-10 times (MJTOT2 = 3)"
                       3 "11-99 times (MJTOT2 = 4)"
                       4 "100 or more times (MJTOT2 = 5)"
                       5 "Never used marijuana (MJTOT2 = 1)" ;
label define COCTOT3   1 "1-2 times (COCTOT2 = 2)"
                       2 "3-10 times (COCTOT2 = 3)"
                       3 "11-99 times (COCTOT2 = 4)"
                       4 "100 or more times (COCTOT2 = 5)"
                       5 "Never used cocaine (COCTOT2 = 1)" ;
label define MJDY30A2  1 "None/never used marijuana (MJDAY30A = 0,"
                       2 "1-2 days (MJDAY30A = 1-2)"
                       3 "3-4 days (MJDAY30A = 3-4)"
                       4 "5-19 days (MJDAY30A = 5-19)"
                       5 "20-30 days (MJDAY30A = 20-30)"
                       6 "Unknown (MJDAY30A = 85,94,95,98)" ;
label define ALCDAYS2  1 "None or never used alcohol (ALCDAYS = 0,"
                       2 "1-2 days (ALCDAYS = 1-2)"
                       3 "3-4 days (ALCDAYS = 3-4)"
                       4 "5-19 days (ALCDAYS = 5-19)"
                       5 "20-30 days (ALCDAYS = 20-31)" ;
label define MRJMON2   1 "Did not use in past month (MRJMON = 0)"
                       2 "Used within the past month (MRJMON = 1)" ;
label define ALCMON2   1 "Did not use in the past month (ALCMON ="
                       2 "Used within the past month (ALCMON = 1)" ;
label define CIGMON2   1 "Did not use in past month (CIGMON = 0)"
                       2 "Used within past month (CIGMON = 1)" ;
label define LSD2      0 "Never used hallucinogens (LSD = 2,81,91,"
                       1 "Ever used LSD (LSD = 1)" ;
label define PEYOTE2   0 "Never used hallucinogens (PEYOTE = 2,81,"
                       1 "Ever used Peyote (PEYOTE = 1)" ;
label define MESC2     0 "Never used hallucinogens (MESC = 2,81,91"
                       1 "Ever used Mescaline (MESC = 1)" ;
label define PSILCY2   0 "Never used hallucinogens (PSILCY = 2,81,"
                       1 "Ever used Psilocybin (PSILCY = 1)" ;
label define ECSTASY2  0 "Never used hallucinogens (ECSTASY=2,81,9"
                       1 "Ever used Ecstasy (ECSTASY=1)" ;
label define GAS2      0 "Never inhaled (GAS = 2,81,91,98)"
                       1 "Ever inhaled (GAS = 1,3)" ;
label define LGAS2     0 "Never inhaled (LGAS=2,81,91,98)"
                       1 "Ever inhaled (LGAS=1,3)" ;
label define SPPAINT2  0 "Never inhaled (SPPAINT = 2,81,91,98)"
                       1 "Ever inhaled (SPPAINT = 1,3)" ;
label define AEROS2    0 "Never inhaled (AEROS = 2,81,91,98)"
                       1 "Ever inhaled (AEROS = 1,3)" ;
label define GLUE2     0 "Never inhaled (GLUE = 2,81,91,98)"
                       1 "Ever inhaled (GLUE = 1,3)" ;
label define SOLVENT2  0 "Never inhaled (SOLVENT = 2,81,91,98)"
                       1 "Ever inhaled (SOLVENT = 1,3)" ;
label define AMYLNIT2  0 "Never inhaled (AMYLNIT = 2,81,91,98)"
                       1 "Ever inhaled (AMYLNIT = 1,3)" ;
label define ETHER2    0 "Never inhaled (ETHER = 2,81,91,98)"
                       1 "Ever inhaled (ETHER = 1,3)" ;
label define NITOXID2  0 "Never inhaled (NITOXID = 2,81,91,98)"
                       1 "Ever inhaled (NITOXID = 1,3)" ;
label define CLEFLU2   0 "Never inhaled (CLEFLU = 2,81,91,98)"
                       1 "Ever inhaled (CLEFLU = 1,3)" ;
label define COCSNIF2  0 "Never/no use pst 12 mos(COCSNIFF=2,81,83"
                       1 "Sniffed/snorted in past 12 months (COCSN" ;
label define FREEBAS2  0 "Never/no use pst 12 mos(FREEBASE=2,81,83"
                       1 "Freebased in past 12 months (FREEBASE =" ;
label define COCSWAL2  0 "Never/no use pst 12 mos(COCSWAL=2,81,83,"
                       1 "Swallowed/drank in past 12 months (COCSW" ;
label define COCIV2    0 "Never/no use past 12 mos (COCIV=2,81,83,"
                       1 "Injected in the past 12 months (COCIV =" ;
label define MJDY30A3  1 "1-2 days (MJDAY30A2 = 2)"
                       2 "3-4 days (MJDAY30A2 = 3)"
                       3 "5-19 days (MJDAY30A2 = 4)"
                       4 "20-30 days (MJDAY30A2 = 5)"
                       5 "None or never used marijuana (MJDAY30A2" ;
label define ALCDAYS3  1 "None or never used alcohol (ALCDAYS2 = 1"
                       2 "1-4 days (ALCDAYS2 = 2-3)"
                       3 "5-19 days (ALCDAYS2 = 4)"
                       4 "20-30 days (ALCDAYS2 = 5)" ;
label define DRINKER2  0 "Never/no ALC use (ALCMON=0 and DR5DAY=0,"
                       1 "Alcohol use (ALCMON = 1 and DR5DAY = 0-3" ;
label define HVYDRK2   0 "Never/no heavy use (DR5DAY=0-4,81,91,93)"
                       1 "Heavy alcohol use (DR5DAY = 5-30)" ;
label define AVCIG2    1 "None/never smoked cigarettes (AVCIG=81,8"
                       2 "Currently smoke < a pack per day (AVCIG"
                       3 "Currently smoke a pack or more per day (" ;
label define RACESEX   1 "White male (SEX = 1 and RACE = 1)"
                       2 "Black male (SEX = 1 and RACE = 2)"
                       3 "Hispanic male (SEX = 1 and RACE = 3)"
                       4 "White female (SEX = 2 and RACE = 1)"
                       5 "Black female (SEX = 2 and RACE = 2)"
                       6 "Hispanic female (SEX = 2 and RACE = 3)" ;
label define NOTMARJ   0 "No (ALL SOURCE VARIABLES = 0)"
                       1 "Yes (ANY SOURCE VARIABLES = 1)" ;
label define COCWAY2   0 "Never/no use past 12 months (COCWAY=2,81"
                       1 "Used other ways past 12 months (COCWAY=1" ;
label define RACESEX2  1 "White male (SEX=1 and RACE=1)"
                       2 "Black male (SEX=1 and RACE=2)"
                       3 "Hispanic male (SEX=1 and RACE=3)"
                       4 "Other male (SEX=1 and RACE=4)"
                       5 "White female (SEX=2 and RACE=1)"
                       6 "Black female (SEX=2 and RACE=2)"
                       7 "Hispanic female (SEX=2 and RACE=3)"
                       8 "Other female (SEX=2 and RACE=4)" ;
label define ALCONLYL  0 "No" 1 "Yes (ALCFLAG=1 AND SUMFLAG=0)" ;
label define ALCONLYY  0 "No" 1 "Yes (ALCYR=1 AND SUMYR=0)" ;
label define ALCONLYM  0 "No" 1 "Yes (ALCMON=1 AND SUMMON=0)" ;
label define ILLONLYL  0 "No" 1 "Yes (SUMFLAG=1 AND ALCFLAG=0)" ;
label define ILLONLYY  0 "No" 1 "Yes (SUMYR=1 AND ALCYR=0)" ;
label define ILLONLYM  0 "No" 1 "Yes (SUMMON=1 AND ALCMON=0)" ;
label define MRJONLYL  0 "No" 1 "Yes (MJOFLAG=1 AND ALCFLAG=0)" ;
label define MRJONLYY  0 "No" 1 "Yes (MJOYR2=1 AND ALCYR=0)" ;
label define MRJONLYM  0 "No" 1 "Yes (MJOMON2=1 AND ALCMON=0)" ;
label define PSYONLYL  0 "No" 1 "Yes (PSYFLAG2=1 AND ALL OTHER SOURCE VAR" ;
label define PSYONLYY  0 "No" 1 "Yes (PSYYR2=1 AND ALL OTHER SOURCE VARS=" ;
label define PSYONLYM  0 "No" 1 "Yes (PSYMON2=1 AND ALL OTHER SOURCE VARS" ;
label define OTHONLYL  0 "No" 1 "Yes (FIRST 3 SOURCE VAR=0 & ANY OTHR S" ;
label define OTHONLYY  0 "No" 1 "Yes (FIRST 3 SOURCE VAR=0 & ANY OTHR S" ;
label define OTHONLYM  0 "No" 1 "Yes (FIRST 3 SOURCE VAR=0 & ANY OTHR S" ;
label define ALCILLL   0 "No" 1 "Yes (ALCFLAG=1 AND SUMFLAG=1)" ;
label define ALCILLY   0 "No" 1 "Yes (ALCYR=1 AND SUMYR=1)" ;
label define ALCILLM   0 "No" 1 "Yes (ALCMON=1 AND SUMMON=1)" ;
label define ALCMRJL   0 "No" 1 "Yes (ALCFLAG,MRJFLAG=1 AND ALL OTHER SOU" ;
label define ALCMRJY   0 "No" 1 "Yes (ALCYR AND MRJYR=1 AND ALL OTHER SOU" ;
label define ALCMRJM   0 "No" 1 "Yes (ALCMON & MRJMON=1 AND ALL OTHER S" ;
label define ALCPSYL   0 "No" 1 "Yes (ALCFLAG,PSYFLAG2=1 & ALL OTHER SO" ;
label define ALCPSYY   0 "No" 1 "Yes (ALCYR & PSYYR2=1 AND ALL OTHER SO" ;
label define ALCPSYM   0 "No" 1 "Yes (ALCMON & PSYMON2=1 & ALL OTHER" ;
label define ALCOTHL   0 "No" 1 "Yes (ALCFLAG=1 & NEXT 2 VAR=0 & ANY" ;
label define ALCOTHY   0 "No" 1 "Yes (ALCYR=1 & NEXT 2 VAR=0 & ANY OT" ;
label define ALCOTHM   0 "No" 1 "Yes (ALCMON=1 & NEXT 2 VAR=0 & ANY O" ;
label define SUB1LIF   0 "No" 1 "Yes (ONLY ONE OF THE SOURCE VARS=1)" ;
label define SUB2LIF   0 "No" 1 "Yes (ONLY TWO OF THE SOURCE VARS=1)" ;
label define SUB3LIF   0 "No" 1 "Yes (THREE OR MORE OF THE SOURCE VARS=1)" ;
label define SUB1YR    0 "No" 1 "Yes (ONLY ONE OF THE SOURCE VARS=1)" ;
label define SUB2YR    0 "No" 1 "Yes (ONLY TWO OF THE SOURCE VARS=1)" ;
label define SUB3YR    0 "No" 1 "Yes (THREE OR MORE OF THE SOURCE VARS=1)" ;
label define SUB1MON   0 "No" 1 "Yes (ONLY ONE OF THE SOURCE VARS=1)" ;
label define SUB2MON   0 "No" 1 "Yes (ONLY TWO OF THE SOURCE VARS=1)" ;
label define SUB3MON   0 "No" 1 "Yes (THREE OR MORE OF THE SOURCE VARS=1)" ;
label define ANYPROB   0 "No" 1 "Yes" ;
label define TWOPROB   0 "No" 1 "Yes" ;
label define THREPROB  0 "No" 1 "Yes" ;
label define IRALCAGG  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ = 1)" ;
label define IRALCARG  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ = 1)" ;
label define IRALCABS  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ = 1)" ;
label define IRALCHIG  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ = 1)" ;
label define IRALCJOB  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ = 1)" ;
label define IRALCMAT  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ = 1)" ;
label define IRALCREL  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ = 1)" ;
label define IRALCFRD  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ = 1)" ;
label define IRALCTOS  1 "Yes" 2 "No" 3 "Yes, LOGICALLY IMPUTED"
                       99 "LEGITIMATE SKIP (IRNOBOOZ = 1)" ;
label define IRALCHOL  1 "Yes" 2 "No" 3 "Yes, LOGICALLY IMPUTED"
                       99 "LEGITIMATE SKIP (IRNOBOOZ = 1)" ;
label define IRALCDRU  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ = 1)" ;
label define IRALCINT  1 "Yes" 2 "No" 3 "Yes, LOGICALLY IMPUTED"
                       99 "LEGITIMATE SKIP (IRNOBOOZ = 1)" ;
label define IRALCREM  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ = 1)" ;
label define IRALCQUI  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ = 1)" ;
label define IRALCMOR  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ = 1)" ;
label define IRALCSHO  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ = 1)" ;
label define IRALCALO  1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRNOBOOZ = 1)" ;
label define IRALCBRK  1 "Yes" 2 "No" 3 "Yes, LOGICALLY IMPUTED"
                       99 "LEGITIMATE SKIP (IRNOBOOZ = 1)" ;
label define IRNOBOOZ  1 "No use of alcohol in the past year"
                       2 "Used alcohol in the past year" ;
label define ANYALC    0 "No" 1 "Yes" ;
label define THREALC   0 "No" 1 "Yes" ;
label define DRUNKYR2  0 "Unknown (DRUNKYR = 85,96,97,98)"
                       1 "Drunk more than twice a month (DRUNKYR ="
                       2 "Drunk twice a month or less (DRUNKYR = 5"
                       3 "Never drunk in past year (DRUNKYR = 9)" ;
label define IRDEP     1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRAS13 = 1)" ;
label define IRARG     1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRAS13 = 1)" ;
label define IRALN     1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRAS13 = 1)" ;
label define IRANX     1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRAS13 = 1)" ;
label define IRHLT     1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRAS13 = 1)" ;
label define IRNTK     1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRAS13 = 1)" ;
label define IRUPS     1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRAS13 = 1)" ;
label define IRLSW     1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRAS13 = 1)" ;
label define IRSSP     1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRAS13 = 1)" ;
label define IRCPE     1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRAS13 = 1)" ;
label define IREMG     1 "Yes" 2 "No" 99 "LEGITIMATE SKIP (IRAS13 = 1)" ;
label define IRDEP1    120 "OTHER Sedative, NOT SPECIFIED, Downers"
                       201 "Valium" 209 "Xanax"
                       221 "OTHER Tranquilizer, NOT SPECIFIED"
                       301 "Dexedrine" 318 "Methylphenidate"
                       322 "Methamphetamine (speed or ice or cr"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       333 "357 Magnum, Magnum 44"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       355 "Crystal meth" 407 "Demerol"
                       409 "Tylenol with Codeine, Tylenol 3"
                       420 "OTHER Analgesic, NOT SPECIFIED" 423 "Percocet"
                       440 "Soma" 502 "Spray paints"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       601 "LSD (acid, white lightning)"
                       605 "PCP (angel dust, phencyclidine)"
                       606 "Ecstacy (MDMA), X-TC"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 702 "Heroin"
                       801 "OTHER Drugs, NOT SPECIFIED" 802 "Cannabinol"
                       803 "Marijuana" 804 "Hashish" 805 "Cocaine, Coke"
                       806 "CRACK" 807 "Alcohol"
                       808 "All of the ones Ive tried" 812 "Cigars"
                       813 "Cigarettes, tobacco not specified" 814 "Caffeine"
                       816 "Smokeless tobacco, snuff, chewing tobacc"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define IRDEP2    201 "Valium" 221 "OTHER Tranquilizer, NOT SPECIFIED"
                       322 "Methamphetamine (speed or ice or cr"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       501 "Lighter fluids, Gasoline"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       601 "LSD (acid, white lightning)"
                       605 "PCP (angel dust, phencyclidine)"
                       701 "OTHER Opiates, NOT SPECIFIED" 702 "Heroin"
                       803 "Marijuana" 804 "Hashish" 805 "Cocaine, Coke"
                       806 "CRACK" 807 "Alcohol"
                       813 "Cigarettes, tobacco not specified" 815 "Coffee"
                       816 "Chewing tobacco, smokeless tobacco, snuf"
                       818 "Nicotine" 999 "LEGITIMATE SKIP" ;
label define IRDEP3    221 "OTHER Tranquilizer, NOT SPECIFIED"
                       322 "Methamphetamine (speed or ice or cr"
                       601 "LSD (acid, white lightning)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED"
                       803 "Marijuana" 805 "Cocaine, Coke" 807 "Alcohol"
                       999 "LEGITIMATE SKIP" ;
label define IRDEP4    510 "OTHER Inhalant, NOT SPECIFIED"
                       607 "OTHER Hallucinogen, NOT SPECIFIED"
                       803 "Marijuana" 807 "Alcohol" 999 "LEGITIMATE SKIP" ;
label define IRDEP5    703 "Opium" 999 "LEGITIMATE SKIP" ;
label define IRARG1    120 "Downers" 201 "Valium"
                       221 "OTHER Tranquilizer, NOT SPECIFIED" 241 "Prozac"
                       318 "Methylphenidate"
                       322 "Methamphetamine (speed or ice or cr"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       401 "Darvon" 409 "Tylenol with Codeine, Tylenol 3"
                       420 "OTHER Analgesic, NOT SPECIFIED" 440 "Soma"
                       502 "Spray paints" 601 "LSD (acid, white lightning)"
                       603 "Mescaline" 605 "PCP (angel dust, phencyclidine)"
                       606 "X-TC (ecstasy, MDMA)" 702 "Heroin"
                       801 "OTHER Drugs, NOT SPECIFIED" 803 "Marijuana"
                       805 "Cocaine, Coke" 806 "CRACK" 807 "Alcohol"
                       808 "All of the ones Ive tried" 812 "Cigars"
                       813 "Cigarettes, tobacco not specified"
                       816 "Smokeless tobacco, snuff, chewing tobacc"
                       818 "Nicotine" 824 "Steroids" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define IRARG2    120 "OTHER Sedative, NOT SPECIFIED, Downers"
                       201 "Valium" 221 "OTHER Tranquilizer, NOT SPECIFIED"
                       322 "Methamphetamine (speed or ice or cr" 324 "Uppers"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       355 "Crystal meth" 501 "Lighter fluids, gasoline"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       601 "LSD (acid, white lightning)"
                       605 "PCP (angel dust, phencyclidine)"
                       701 "OTHER Opiates, NOT SPECIFIED" 702 "Heroin"
                       802 "Cannabinol" 803 "Marijuana" 805 "Cocaine, Coke"
                       806 "CRACK" 807 "Alcohol"
                       813 "Cigarettes, tobacco not specified" 815 "Coffee"
                       816 "Smokeless tobacco, snuff, chewing tobacc"
                       845 "sic" 999 "LEGITIMATE SKIP" ;
label define IRARG3    221 "OTHER Tranquilizer, NOT SPECIFIED"
                       322 "Methamphetamine (speed or ice or cr"
                       420 "OTHER Analgesic, NOT SPECIFIED"
                       601 "LSD (acid, white lightning)" 803 "Marijuana"
                       805 "Cocaine, Coke" 807 "Alcohol"
                       999 "LEGITIMATE SKIP" ;
label define IRARG4    322 "Methamphetamine (speed or ice or cr"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       607 "OTHER Hallucinogen, NOT SPECIFIED"
                       803 "Marijuana" 807 "Alcohol" 999 "LEGITIMATE SKIP" ;
label define IRARG5    703 "Opium" 999 "LEGITIMATE SKIP" ;
label define IRALN1    120 "OTHER Sedative, NOT SPECIFIED, Downers"
                       201 "Valium" 221 "OTHER Tranquilizer, NOT SPECIFIED"
                       301 "Dexedrine" 318 "Ritalin"
                       322 "Methamphetamine (speed or ice or cr" 324 "Uppers"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       355 "Crystal meth" 401 "Darvon"
                       420 "OTHER Analgesic, NOT SPECIFIED"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       601 "LSD (acid, white lightning)"
                       605 "PCP (angel dust, phencyclidine)"
                       606 "Ecstasy (MDMA), X-TC"
                       607 "OTHER Hallucinogen, NOT SPECIFIED"
                       701 "OTHER Opiates, NOT SPECIFIED" 702 "Heroin"
                       801 "OTHER Drugs, NOT SPECIFIED" 803 "Marijuana"
                       805 "Cocaine, Coke" 806 "CRACK" 807 "Alcohol"
                       808 "All of the ones Ive tried"
                       813 "Cigarettes, tobacco not specified"
                       816 "Smokeless tobacco, snuff, chewing tobacc"
                       824 "Steroids" 860 "sic" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define IRALN2    120 "OTHER Sedative, NOT SPECIFIED, Downers"
                       209 "Xanax" 221 "OTHER Tranquilizer, NOT SPECIFIED"
                       339 "Amphetamines (speed generically)"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       601 "LSD (acid, white lightning)"
                       605 "PCP (angel dust, phencyclidine)" 702 "Heroin"
                       803 "Marijuana" 805 "Cocaine, Coke" 806 "CRACK"
                       807 "Alcohol" 813 "Cigarettes, tobacco not specified"
                       815 "Coffee"
                       816 "Smokeless tobacco, snuff, chewing tobacc"
                       999 "LEGITIMATE SKIP" ;
label define IRALN3    120 "Downers" 221 "OTHER Tranquilizer, NOT SPECIFIED"
                       322 "Methamphetamine (speed or ice or cr"
                       607 "OTHER Hallucinogen, NOT SPECIFIED"
                       803 "Marijuana" 805 "Cocaine, Coke" 807 "Alcohol"
                       999 "LEGITIMATE SKIP" ;
label define IRALN4    322 "Methamphetamine (speed or ice or cr" 324 "Uppers"
                       510 "OTHER Inhalant, NOT SPECIFIED" 803 "Marijuana"
                       807 "Alcohol" 999 "LEGITIMATE SKIP" ;
label define IRALN5    703 "Opium" 999 "LEGITIMATE SKIP" ;
label define IRANX1    120 "OTHER Sedative, NOT SPECIFIED, Downers"
                       209 "Xanax" 221 "OTHER Tranquilizer, NOT SPECIFIED"
                       241 "Prozac" 311 "Preludin" 313 "Fastin, Phentermine"
                       318 "Ritalin"
                       322 "Methamphetamine (speed or ice or cr"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       326 "White cross" 332 "Ephedrine" 336 "Diet pills"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       353 "No-Doz" 355 "Crystal meth" 364 "Sudafed, Sinutab"
                       409 "Tylenol with Codeine, Tylenol 3" 415 "Codeine"
                       418 "Methadone" 420 "OTHER Analgesic, NOT SPECIFIED"
                       505 "Lacquer thinner"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       601 "LSD (acid, white lightning)"
                       605 "Phencyclidine (angel dust, PCP)"
                       606 "Ecstasy (MDMA), X-TC"
                       607 "OTHER Hallucinogen, NOT SPECIFIED"
                       618 "Acid paper" 701 "OTHER Opiates, NOT SPECIFIED"
                       702 "Heroin" 801 "OTHER Drugs, NOT SPECIFIED"
                       803 "Marijuana" 805 "Cocaine, Coke" 806 "CRACK"
                       807 "Alcohol" 808 "All of the ones Ive tried"
                       812 "Cigars" 813 "Cigarettes, tobacco not specified"
                       814 "Caffeine" 815 "Coffee"
                       816 "Smokeless tobacco, snuff, chewing tobacc"
                       818 "Nicotine" 824 "Steroids"
                       998 "Blank (not answered)" 999 "Legitimate skip" ;
label define IRANX2    102 "Buticaps" 120 "Downers"
                       221 "OTHER Tranquilizer, NOT SPECIFIED" 312 "Ionamin"
                       322 "Methamphetamine (speed or ice or cr"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       401 "Darvon" 468 "Excedrin <OTC>"
                       601 "LSD (acid, white lightning)"
                       606 "Ecstasy (MDMA), X-TC"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 702 "Heroin"
                       803 "Marijuana" 805 "Cocaine, Coke" 806 "CRACK"
                       807 "Alcohol" 813 "Cigarettes, tobacco not specified"
                       815 "Coffee" 999 "LEGITIMATE SKIP" ;
label define IRANX3    221 "OTHER Tranquilizer, NOT SPECIFIED"
                       322 "Methamphetamine (speed or ice or cr" 324 "Uppers"
                       607 "OTHER Hallucinogen, NOT SPECIFIED"
                       803 "Marijuana" 805 "Cocaine, Coke"
                       999 "LEGITIMATE SKIP" ;
label define IRANX4    322 "Methamphetamine (speed or ice or cr" 324 "Uppers"
                       510 "OTHER Inhalant, NOT SPECIFIED" 803 "Marijuana"
                       807 "Alcohol" 999 "LEGITIMATE SKIP" ;
label define IRANX5    703 "Opium" 999 "LEGITIMATE SKIP" ;
label define IRHLT1    120 "OTHER Sedative, NOT SPECIFIED, Downers"
                       146 "Bentyl, Dicyclomine"
                       259 "Desipramine, Norpramin, Pertofrane"
                       313 "Fastin, Phentermine"
                       318 "Methylphenidate, Ritalin"
                       322 "Methamphetamine (speed or ice or cr"
                       336 "Diet pills"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       355 "Crystal meth" 364 "Sinutab, Sudafed"
                       409 "Tylenol with Codeine, Tylenol 3" 418 "Methadone"
                       420 "OTHER Analgesic, NOT SPECIFIED"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       530 "Asthma inhaler, bronchial dilators"
                       605 "PCP (angel dust, phencyclidine)" 702 "Heroin"
                       801 "OTHER Drugs, NOT SPECIFIED" 803 "Marijuana"
                       805 "Cocaine, Coke" 806 "CRACK" 807 "Alcohol"
                       808 "All of the ones Ive tried" 812 "Cigars"
                       813 "Cigarettes, tobacco not specified" 814 "Caffeine"
                       815 "Coffee"
                       816 "Smokeless tobacco, snuff, chewing tobacc"
                       818 "Nicotine" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define IRHLT2    201 "Valium" 221 "OTHER Tranquilizer, NOT SPECIFIED"
                       312 "Ionamin"
                       322 "Methamphetamine (speed or ice or cr" 324 "Uppers"
                       420 "OTHER Analgesic, NOT SPECIFIED"
                       601 "LSD (acid, white lightning)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 702 "Heroin"
                       803 "Marijuana" 805 "Cocaine, Coke" 806 "CRACK"
                       807 "Alcohol" 812 "Cigars"
                       813 "Cigarettes, tobacco not specified" 814 "Caffeine"
                       815 "Coffee"
                       816 "Smokeless tobacco, snuff, chewing tobacc"
                       818 "Nicotine" 999 "LEGITIMATE SKIP" ;
label define IRHLT3    221 "OTHER Tranquilizer, NOT SPECIFIED"
                       322 "Methamphetamine (speed or ice or cr"
                       326 "White cross" 415 "Codeine" 803 "Marijuana"
                       804 "Hashish" 805 "Cocaine, Coke" 807 "Alcohol"
                       999 "LEGITIMATE SKIP" ;
label define IRHLT4    322 "Methamphetamine (speed or ice or cr"
                       803 "Marijuana" 807 "Alcohol"
                       813 "Cigarettes, tobacco not specified"
                       999 "LEGITIMATE SKIP" ;
label define IRHLT5    703 "Opium" 999 "LEGITIMATE SKIP" ;
label define IRNTK1    120 "OTHER Sedative, NOT SPECIFIED, Downers"
                       209 "Xanax" 211 "Buspar" 241 "Prozac"
                       313 "Fastin, Phentermine" 318 "Ritalin"
                       322 "Methamphetamine (speed or ice or cr"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       355 "Crystal meth" 364 "Sinutab, Sudafed" 401 "Darvon"
                       409 "Tylenol with Codeine, Tylenol 3" 418 "Methadone"
                       420 "OTHER Analgesic, NOT SPECIFIED" 435 "Tylenol"
                       440 "Soma" 502 "Spray paints" 505 "Lacquer thinner"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       601 "LSD (acid, white lightning)"
                       604 "Psilocybin (mushrooms)"
                       605 "PCP (angel dust, phencyclidine)"
                       606 "Ecstasy (MDMA), X-TC"
                       607 "OTHER Hallucinogen, NOT SPECIFIED" 702 "Heroin"
                       704 "Dope" 801 "OTHER Drugs, NOT SPECIFIED"
                       802 "Cannabinol" 803 "Marijuana" 804 "Hashish"
                       805 "Cocaine, Coke" 806 "CRACK" 807 "Alcohol"
                       808 "All of the ones Ive tried" 809 "Pills"
                       813 "Cigarettes, tobacco not specified" 814 "Caffeine"
                       816 "Smokeless tobacco, snuff, chewing tobacc"
                       844 "Blood pressure medication" 855 "sic"
                       858 "Antibiotic" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define IRNTK2    102 "Buticaps" 120 "Downers" 201 "Valium"
                       221 "OTHER Tranquilizer, NOT SPECIFIED" 312 "Ionamin"
                       322 "Methamphetamine (speed or ice or cr"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       420 "OTHER Analgesic, NOT SPECIFIED"
                       501 "Lighter fluids, gasoline"
                       504 "Rubber cement, glue, super glue, shoeshi"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       601 "LSD (acid, white lightning)"
                       605 "PCP (angel dust, phencyclidine)"
                       606 "Ecstasy (MDMA), X-TC"
                       701 "OTHER Opiates, NOT SPECIFIED" 702 "Heroin"
                       802 "Cannabinol" 803 "Marijuana" 804 "Hashish"
                       805 "Cocaine, Coke" 806 "CRACK" 807 "Alcohol"
                       813 "Cigarettes, tobacco not specified" 815 "Coffee"
                       999 "LEGITIMATE SKIP" ;
label define IRNTK3    201 "Valium" 221 "OTHER Tranquilizer, NOT SPECIFIED"
                       322 "Methamphetamine (speed or ice or cr"
                       415 "Codeine" 420 "OTHER Analgesic, NOT SPECIFIED"
                       501 "Lighter fluids, gasoline"
                       601 "LSD (acid, white lightning)" 702 "Heroin"
                       803 "Marijuana" 804 "Hashish" 805 "Cocaine, Coke"
                       807 "Alcohol" 845 "sic" 999 "LEGITIMATE SKIP" ;
label define IRNTK4    322 "Methamphetamine (speed or ice or cr"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       607 "OTHER Hallucinogen, NOT SPECIFIED"
                       803 "Marijuana" 805 "Cocaine, Coke" 807 "Alcohol"
                       813 "Cigarettes, tobacco not specified"
                       999 "LEGITIMATE SKIP" ;
label define IRNTK5    601 "LSD (acid, white lightning)" 703 "Opium"
                       999 "LEGITIMATE SKIP" ;
label define IRUPS1    120 "Downers" 201 "Valium" 209 "Xanax" 241 "Prozac"
                       313 "Fastin, Phentermine"
                       318 "Methylphenidate, Ritalin"
                       322 "Methamphetamine (speed or ice or cr"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       332 "Ephedrine" 336 "Diet pills"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       353 "No-Doz" 355 "Crystal meth" 364 "Sinutab, Sudafed"
                       409 "Tylenol with Codeine, Tylenol 3" 418 "Methadone"
                       420 "OTHER Analgesic, NOT SPECIFIED"
                       438 "Anaprox, Naprosyn" 502 "Spray paints"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       601 "LSD (acid, white lightning)"
                       605 "PCP (angel dust, phencyclidine)"
                       701 "OTHER Opiates, NOT SPECIFIED" 702 "Heroin"
                       801 "OTHER Drugs, NOT SPECIFIED" 803 "Marijuana"
                       805 "Cocaine, Coke" 806 "CRACK" 807 "Alcohol"
                       808 "All of the ones Ive tried" 809 "Pills"
                       812 "Cigars" 813 "Cigarettes, tobacco not specified"
                       814 "Caffeine" 815 "Coffee"
                       816 "Smokeless tobacco, snuff, chewing tobacc"
                       818 "Nicotine" 824 "Steroids" 998 "BLANK (NO ANSWER)"
                       999 "LEGITIMATE SKIP" ;
label define IRUPS2    120 "Downers" 201 "Valium" 209 "Xanax"
                       221 "OTHER Tranquilizer, NOT SPECIFIED" 312 "Ionamin"
                       322 "Methamphetamine (speed or ice or cr"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       328 "Pink hearts"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       420 "OTHER Analgesic, NOT SPECIFIED"
                       501 "Lighter fluids, gasoline"
                       601 "LSD (acid, white lightning)"
                       605 "PCP (angel dust, phencyclidine)" 702 "Heroin"
                       803 "Marijuana" 804 "Hashish" 805 "Cocaine, Coke"
                       806 "CRACK" 807 "Alcohol"
                       813 "Cigarettes, tobacco not specified" 815 "Coffee"
                       999 "LEGITIMATE SKIP" ;
label define IRUPS3    322 "Methamphetamine (speed or ice or cr"
                       601 "LSD (acid, white lightning)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED"
                       803 "Marijuana" 805 "Cocaine, Coke" 807 "Alcohol"
                       999 "LEGITIMATE SKIP" ;
label define IRUPS4    322 "Methamphetamine (speed or ice or cr"
                       510 "OTHER Inhalant, NOT SPECIFIED" 803 "Marijuana"
                       807 "Alcohol" 999 "LEGITIMATE SKIP" ;
label define IRUPS5    703 "Opium" 999 "LEGITIMATE SKIP" ;
label define IRLSW1    120 "Downers" 146 "Bentyl, Dicyclomine" 206 "Tranxene"
                       209 "Xanax" 313 "Fastin, Phentermine"
                       322 "Methamphetamine (speed or ice or cr" 324 "Uppers"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       355 "Crystal meth" 364 "Sinutab, Sudafed"
                       409 "Tylenol with Codeine, Tylenol 3" 440 "Soma"
                       502 "Spray paints" 510 "OTHER Inhalant, NOT SPECIFIED"
                       524 "White-Out" 601 "LSD (acid, white lightning)"
                       605 "PCP (angel dust, phencyclidine)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED"
                       701 "OTHER Opiates, NOT SPECIFIED" 702 "Heroin"
                       801 "OTHER Drugs, NOT SPECIFIED" 803 "Marijuana"
                       805 "Cocaine, Coke" 806 "CRACK" 807 "Alcohol"
                       808 "All of the ones Ive tried"
                       813 "Cigarettes, tobacco not specified"
                       816 "Smokeless tobacco, snuff, chewing tobacc"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define IRLSW2    120 "Downers" 201 "Valium" 208 "Centrax"
                       221 "OTHER Tranquilizer, NOT SPECIFIED"
                       322 "Methamphetamine (speed or ice or cr" 324 "Uppers"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       501 "Lighter fluids, gasoline"
                       601 "LSD (acid, white lightning)"
                       605 "PCP (angel dust, phencyclidine)" 803 "Marijuana"
                       805 "Cocaine, Coke" 806 "CRACK" 807 "Alcohol"
                       813 "Cigarettes, tobacco not specified" 815 "Coffee"
                       999 "LEGITIMATE SKIP" ;
label define IRLSW3    322 "Methamphetamine (speed or ice or cr"
                       339 "Amphetamines (speed generically)"
                       501 "Lighter fluids, gasoline"
                       601 "LSD (acid, white lightning)"
                       605 "PCP (angel dust, phencyclidine)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED"
                       803 "Marijuana" 805 "Cocaine, Coke" 807 "Alcohol"
                       999 "LEGITIMATE SKIP" ;
label define IRLSW4    322 "Methamphetamine (speed or ice or cr"
                       510 "OTHER Inhalant, NOT SPECIFIED"
                       607 "OTHER Hallucinogen, NOT SPECIFIED"
                       803 "Marijuana" 807 "Alcohol"
                       813 "Cigarettes, tobacco not specified"
                       999 "LEGITIMATE SKIP" ;
label define IRLSW5    703 "Opium" 999 "LEGITIMATE SKIP" ;
label define IRSSP1    120 "OTHER Sedative, NOT SPECIFIED, Downers"
                       201 "Valium" 209 "Xanax" 312 "Ionamin" 318 "Ritalin"
                       322 "Methamphetamine (speed or ice or cr"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       355 "Crystal meth"
                       420 "OTHER Analgesic, NOT SPECIFIED"
                       505 "Lacquer thinner"
                       601 "LSD (acid, white lightning)"
                       604 "Psilocybin (mushrooms)"
                       605 "PCP (angel dust, phencyclidine)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED"
                       701 "OTHER Opiates, NOT SPECIFIED" 702 "Heroin"
                       801 "OTHER Drugs, NOT SPECIFIED" 803 "Marijuana"
                       805 "Cocaine, Coke" 806 "CRACK" 807 "Alcohol"
                       808 "All of the ones Ive tried"
                       813 "Cigarettes, tobacco not specified" 815 "Coffee"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define IRSSP2    120 "Downers" 209 "Xanax"
                       221 "OTHER Tranquilizer, NOT SPECIFIED"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       339 "Amphetamines (speed generically)"
                       601 "LSD (acid, white lightning)" 702 "Heroin"
                       803 "Marijuana" 805 "Cocaine, Coke" 806 "CRACK"
                       807 "Alcohol" 813 "Cigarettes, tobacco not specified"
                       815 "Coffee" 999 "LEGITIMATE SKIP" ;
label define IRSSP3    322 "Methamphetamine (speed or ice or cr"
                       601 "LSD (acid, white lightning)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED"
                       803 "Marijuana" 805 "Cocaine, Coke" 806 "CRACK"
                       999 "LEGITIMATE SKIP" ;
label define IRSSP4    322 "Methamphetamine (speed or ice or cr"
                       510 "OTHER Inhalant, NOT SPECIFIED" 803 "Marijuana"
                       807 "Alcohol" 999 "LEGITIMATE SKIP" ;
label define IRSSP5    703 "Opium" 999 "LEGITIMATE SKIP" ;
label define IRCPE1    120 "Downers" 201 "Valium"
                       221 "OTHER Tranquilizer, NOT SPECIFIED" 312 "Ionamin"
                       318 "Methylphenidate, Ritalin"
                       322 "Methamphetamine (speed or ice or cr" 324 "Uppers"
                       339 "Amphetamines (speed generically)" 348 "Crystal"
                       355 "Crystal meth" 601 "LSD (acid, white lightning)"
                       605 "PCP (angel dust, phencyclidine)"
                       701 "OTHER Opiates, NOT SPECIFIED" 702 "Heroin"
                       801 "OTHER Drugs, NOT SPECIFIED" 803 "Marijuana"
                       805 "Cocaine, Coke" 806 "CRACK" 807 "Alcohol"
                       808 "All of the ones Ive tried"
                       813 "Cigarettes, tobacco not specified"
                       816 "Smokeless tobacco, snuff, chewing tobacc"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define IRCPE2    120 "OTHER Sedative, NOT SPECIFIED, Downers"
                       209 "Xanax" 221 "OTHER Tranquilizer, NOT SPECIFIED"
                       322 "Methamphetamine (speed or ice or cr"
                       324 "OTHER Stimulant, NOT SPECIFIED, Uppers"
                       339 "Amphetamines (speed generically)"
                       601 "LSD (acid, white lightning)"
                       604 "Psilocybin (mushrooms)" 702 "Heroin"
                       803 "Marijuana" 804 "Hashish" 805 "Cocaine, Coke"
                       806 "CRACK" 807 "Alcohol"
                       813 "Cigarettes, tobacco not specified" 815 "Coffee"
                       999 "LEGITIMATE SKIP" ;
label define IRCPE3    322 "Methamphetamine (speed or ice or cr"
                       601 "LSD (acid, white lightning)"
                       607 "OTHER Hallucinogen, NOT SPECIFIED"
                       803 "Marijuana" 805 "Cocaine, Coke" 806 "CRACK"
                       807 "Alcohol" 999 "LEGITIMATE SKIP" ;
label define IRCPE4    322 "Methamphetamine (speed or ice or cr"
                       510 "OTHER Inhalant, NOT SPECIFIED" 803 "Marijuana"
                       807 "Alcohol" 999 "LEGITIMATE SKIP" ;
label define IRCPE5    703 "Opium" 999 "LEGITIMATE SKIP" ;
label define IREMG1    120 "Downers" 201 "Valium" 318 "Ritalin"
                       322 "Methamphetamine (speed or ice or cr"
                       336 "Diet pills" 348 "Crystal" 355 "Crystal meth"
                       435 "Tylenol" 440 "Soma"
                       605 "PCP (angel dust, phencyclidine)" 702 "Heroin"
                       801 "OTHER Drugs, NOT SPECIFIED" 803 "Marijuana"
                       805 "Cocaine, Coke" 806 "CRACK" 807 "Alcohol"
                       813 "Cigarettes, tobacco not specified" 814 "Caffeine"
                       998 "BLANK (NO ANSWER)" 999 "LEGITIMATE SKIP" ;
label define IREMG2    109 "Seconal" 120 "Downers" 209 "Xanax"
                       221 "OTHER Tranquilizer, NOT SPECIFIED"
                       420 "OTHER Analgesic, NOT SPECIFIED"
                       601 "LSD (acid, white lightning)" 702 "Heroin"
                       803 "Marijuana" 805 "Cocaine, Coke" 806 "CRACK"
                       807 "Alcohol" 999 "LEGITIMATE SKIP" ;
label define IREMG3    322 "Methamphetamine (speed or ice or cr"
                       601 "LSD (acid, white lightning)" 805 "Cocaine, Coke"
                       999 "LEGITIMATE SKIP" ;
label define IREMG4    322 "Methamphetamine (speed or ice or cr"
                       803 "Marijuana" 807 "Alcohol" 999 "LEGITIMATE SKIP" ;
label define IREMG5    703 "Opium" 999 "LEGITIMATE SKIP" ;
label define IRAS13    1 "Never used any of the substances listed"
                       2 "Used one or more of the listed substance" ;
label define DEPCIG2   0 "No" 1 "Yes" ;
label define DEPALC2   0 "No" 1 "Yes" ;
label define DEPMRJ2   0 "No" 1 "Yes" ;
label define DEPCOC2   0 "No" 1 "Yes" ;
label define ARGCIG2   0 "No" 1 "Yes" ;
label define ARGALC2   0 "No" 1 "Yes" ;
label define ARGMRJ2   0 "No" 1 "Yes" ;
label define ARGCOC2   0 "No" 1 "Yes" ;
label define ALNCIG2   0 "No" 1 "Yes" ;
label define ALNALC2   0 "No" 1 "Yes" ;
label define ALNMRJ2   0 "No" 1 "Yes" ;
label define ALNCOC2   0 "No" 1 "Yes" ;
label define ANXCIG2   0 "No" 1 "Yes" ;
label define ANXALC2   0 "No" 1 "Yes" ;
label define ANXMRJ2   0 "No" 1 "Yes" ;
label define ANXCOC2   0 "No" 1 "Yes" ;
label define HLTCIG2   0 "No" 1 "Yes" ;
label define HLTALC2   0 "No" 1 "Yes" ;
label define HLTMRJ2   0 "No" 1 "Yes" ;
label define HLTCOC2   0 "No" 1 "Yes" ;
label define NTKCIG2   0 "No" 1 "Yes" ;
label define NTKALC2   0 "No" 1 "Yes" ;
label define NTKMRJ2   0 "No" 1 "Yes" ;
label define NTKCOC2   0 "No" 1 "Yes" ;
label define UPSCIG2   0 "No" 1 "Yes" ;
label define UPSALC2   0 "No" 1 "Yes" ;
label define UPSMRJ2   0 "No" 1 "Yes" ;
label define UPSCOC2   0 "No" 1 "Yes" ;
label define LSWCIG2   0 "No" 1 "Yes" ;
label define LSWALC2   0 "No" 1 "Yes" ;
label define LSWMRJ2   0 "No" 1 "Yes" ;
label define LSWCOC2   0 "No" 1 "Yes" ;
label define SSPCIG2   0 "No" 1 "Yes" ;
label define SSPALC2   0 "No" 1 "Yes" ;
label define SSPMRJ2   0 "No" 1 "Yes" ;
label define SSPCOC2   0 "No" 1 "Yes" ;
label define CPECIG2   0 "No" 1 "Yes" ;
label define CPEALC2   0 "No" 1 "Yes" ;
label define CPEMRJ2   0 "No" 1 "Yes" ;
label define CPECOC2   0 "No" 1 "Yes" ;
label define EMCIG2    0 "No" 1 "Yes" ;
label define EMALC2    0 "No" 1 "Yes" ;
label define EMMRJ2    0 "No" 1 "Yes" ;
label define EMCOC2    0 "No" 1 "Yes" ;
label define PRB1CIG   0 "No" 1 "Yes" ;
label define PRB1ALC   0 "No" 1 "Yes" ;
label define PRB1MRJ   0 "No" 1 "Yes" ;
label define PRB1COC   0 "No" 1 "Yes" ;
label define PRB2CIG   0 "No" 1 "Yes" ;
label define PRB2ALC   0 "No" 1 "Yes" ;
label define PRB2MRJ   0 "No" 1 "Yes" ;
label define PRB2COC   0 "No" 1 "Yes" ;
label define PRB3CIG   0 "No" 1 "Yes" ;
label define PRB3ALC   0 "No" 1 "Yes" ;
label define PRB3MRJ   0 "No" 1 "Yes" ;
label define PRB3COC   0 "No" 1 "Yes" ;
label define IRCDCIG   1 "Yes" 2 "No"
                       3 "Response circled LOGICALLY IMPUTED (from"
                       13 "Did not try to cut down on any drug in p"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       99 "LEGITIMATE SKIP" ;
label define IRCDALC   1 "Yes" 2 "No"
                       3 "Response circled LOGICALLY IMPUTED (from"
                       13 "Did not try to cut down on any drug in p"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       99 "LEGITIMATE SKIP" ;
label define IRCDMJ    1 "Yes" 2 "No"
                       13 "Did not try to cut down on any drug in p"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       99 "LEGITIMATE SKIP" ;
label define IRCDCOC   1 "Yes" 2 "No"
                       13 "Did not try to cut down on any drug in p"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       99 "LEGITIMATE SKIP" ;
label define IREFCIG   1 "Yes" 2 "No"
                       13 "Did not need more of any drug used for s"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       99 "LEGITIMATE SKIP" ;
label define IREFALC   1 "Yes" 2 "No"
                       13 "Did not need more of any drug used for s"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       99 "LEGITIMATE SKIP" ;
label define IREFMJ    1 "Yes" 2 "No"
                       13 "Did not need more of any drug used for s"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       99 "LEGITIMATE SKIP" ;
label define IREFCOC   1 "Yes" 2 "No"
                       13 "Did not need more of any drug used for s"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       99 "LEGITIMATE SKIP" ;
label define IRUDCIG   1 "Yes" 2 "No"
                       13 "Did not use any drug daily in the past y"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       99 "LEGITIMATE SKIP" ;
label define IRUDALC   1 "Yes" 2 "No"
                       13 "Did not use any drug daily in the past y"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       99 "LEGITIMATE SKIP" ;
label define IRUDMJ    1 "Yes" 2 "No"
                       13 "Did not use any drug daily in the past y"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       99 "LEGITIMATE SKIP" ;
label define IRUDCOC   1 "Yes" 2 "No"
                       13 "Did not use any drug daily in the past y"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       99 "LEGITIMATE SKIP" ;
label define IRDPCIG   1 "Yes" 2 "No"
                       13 "Did not feel like had to have any drug u"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       99 "LEGITIMATE SKIP" ;
label define IRDPALC   1 "Yes" 2 "No"
                       13 "Did not feel like had to have any drug u"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       99 "LEGITIMATE SKIP" ;
label define IRDPMJ    1 "Yes" 2 "No"
                       13 "Did not feel like had to have any drug u"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       99 "LEGITIMATE SKIP" ;
label define IRDPCOC   1 "Yes" 2 "No"
                       13 "Did not feel like had to have any drug u"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       99 "LEGITIMATE SKIP" ;
label define IRWSCIG   1 "Yes" 2 "No"
                       13 "Did not have withdrawal symptoms in the"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       99 "LEGITIMATE SKIP" ;
label define IRWSALC   1 "Yes" 2 "No"
                       13 "Did not have withdrawal symptoms in the"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       99 "LEGITIMATE SKIP" ;
label define IRWSMJ    1 "Yes" 2 "No"
                       13 "Did not have withdrawal symptoms in the"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       99 "LEGITIMATE SKIP" ;
label define IRWSCOC   1 "Yes" 2 "No"
                       13 "Did not have withdrawal symptoms in the"
                       81 "NEVER USED ANY DRUGS Logically assigned"
                       99 "LEGITIMATE SKIP" ;
label define AVCIG3    0 "None/never/< pack a day (AVCIG=1-3,81,89"
                       1 "Currently smoke a pack or more per day (" ;
label define ALCPROBS  0 "No" 1 "Yes" ;
label define MJPROBS   0 "No" 1 "Yes" ;
label define COCPROBS  0 "No" 1 "Yes" ;
label define CIGPROBS  0 "No" 1 "Yes" ;
label define CHANCMJ2  0 "Did not have a chance to use marijuana"
                       1 "Had a chance to use marijuana" ;
label define CHANCOC2  0 "Did not have a chance to use cocaine"
                       1 "Had a chance to use cocaine" ;
label define CHANHAL2  0 "Did not have a chance to use hallucinoge"
                       1 "Had a chance to use hallucinogens" ;
label define CHANHER2  0 "Did not have a chance to use heroin"
                       1 "Had a chance to use heroin" ;
label define RURORURB  1 "Rural" 2 "Urban" ;
label define PBLACKHH  1 "Greater than or equal to 50%"
                       2 "10% or more but less than 50%"
                       3 "Less than 10 percent" ;
label define PBLACKP   1 "Greater than or equal to 50%"
                       2 "10% or more but less than 50%"
                       3 "Less than 10 percent" ;
label define OWNEDAVE  1 "0 - $44,777" 2 "$44,778 - $60,832"
                       3 "$60,833 - $85,121" 4 "$85,122 - $142,831"
                       5 "$142,832 or more" ;
label define POWNED    1 "0 - 50.25 percent" 2 "50.26 - 67.58 percent"
                       3 "67.59 - 76.38 percent" 4 "76.39 - 83.96 percent"
                       5 "83.97 percent or more" ;
label define PPOVERTY  1 "0 - 2.65 percent" 2 "2.66 - 5.12 percent"
                       3 "5.13 - 9.02 percent" 4 "9.03 - 16.15 percent"
                       5 "16.16 percent or more" ;
label define PRENTED   1 "0 - 16.04 percent" 2 "16.05 - 23.62 percent"
                       3 "23.63 - 32.42 percent" 4 "32.43 - 49.75 percent"
                       5 "49.75 percent or more" ;
label define RENTAVE   1 "0 - $315.81" 2 "$315.82 - $393.95"
                       3 "$393.96 - $476.96" 4 "$476.97 - $619.72"
                       5 "$619.72 or more" ;
label define TRMTHLP2  0 "No (TRMTHELP=2)" 1 "Yes (TRMTHELP=1)" ;
label define DRNKHLP2  0 "No (DRNKHELP=2)" 1 "Yes (DRNKHELP=1)" ;
label define DRALHELP  0 "No (see note above)"
                       1 "Yes (TRMTHLP2=1 or DRNKHLP2=1)" ;
label define HSPHCONC  1 "Greater than or equaled to 50%"
                       2 "10% or more but less than 50%"
                       3 "Less than 10 percent" ;
label define HSPPCONC  1 "Greater than or equaled 50%"
                       2 "10% or more but less than 50%"
                       3 "Less than 10 percent" ;
label define OWNOCONC  1 "Greater than or equaled 50%"
                       2 "10% or more but less than 50%"
                       3 "Less than 10 percent" ;


#delimit cr


/***************************************************************************

 Section 4: Missing Values

 This section will replace numeric missing values (i.e., -9) with generic
 system missing ".".  By default the code in this section is commented out.
 Users wishing to apply the generic missing values should remove the comment
 at the beginning and end of this section.  Note that Stata allows you to
 specify up to 27 unique missing value codes.\n
****************************************************************/

/*
replace CIG5PK = . if (CIG5PK >= 81 )
replace CIGAGE = . if (CIGAGE >= 981 )
replace CIGYRS = . if (CIGYRS >= 985 )
replace PACKS = . if (PACKS >= 89 )
replace CIGTIME = . if (CIGTIME >= 9981 )
replace NOBOOKYR = . if (NOBOOKYR >= 85 )
replace BKLARCNY = . if (BKLARCNY >= 85 )
replace BKBURGL = . if (BKBURGL >= 85 )
replace BKAGASLT = . if (BKAGASLT >= 85 )
replace BKSMASLT = . if (BKSMASLT >= 85 )
replace BKMVTHFT = . if (BKMVTHFT >= 85 )
replace BKROB = . if (BKROB >= 85 )
replace BKRAPE = . if (BKRAPE >= 85 )
replace BKMURDER = . if (BKMURDER >= 85 )
replace BKARSON = . if (BKARSON >= 85 )
replace BKDRVINF = . if (BKDRVINF >= 85 )
replace BKDRUNK = . if (BKDRUNK >= 85 )
replace BKDRUG = . if (BKDRUG >= 85 )
replace BKPROS = . if (BKPROS >= 85 )
replace BKVANDAL = . if (BKVANDAL >= 85 )
replace BKOTHOFF = . if (BKOTHOFF >= 85 )
replace NOTBKED = . if (NOTBKED >= 85 )
replace DRUNKDRV = . if (DRUNKDRV >= 85 )
replace OTHDOING = . if (OTHDOING >= 85 )
replace OTHDOSP1 = . if (OTHDOSP1 >= 85 )
replace OTHDOSP2 = . if (OTHDOSP2 >= 85 )
replace ALCSED = . if (ALCSED >= 85 )
replace ALCTRAN = . if (ALCTRAN >= 85 )
replace ALCSTM = . if (ALCSTM >= 85 )
replace ALCANAL = . if (ALCANAL >= 85 )
replace ALCMJ = . if (ALCMJ >= 85 )
replace ALCINH = . if (ALCINH >= 85 )
replace ALCCOC = . if (ALCCOC >= 85 )
replace ALCHAL = . if (ALCHAL >= 85 )
replace ALCOPT = . if (ALCOPT >= 85 )
replace ALCNONE = . if (ALCNONE >= 85 )
replace CIGHELP = . if (CIGHELP >= 81 )
replace DRNKHELP = . if (DRNKHELP >= 81 )
replace TRMTHELP = . if (TRMTHELP >= 81 )
replace TRMTEMRG = . if (TRMTEMRG >= 81 )
replace TRMTHOSP = . if (TRMTHOSP >= 81 )
replace TRMTDOC = . if (TRMTDOC >= 81 )
replace TRMTTRMT = . if (TRMTTRMT >= 81 )
replace TRMTMHC = . if (TRMTMHC >= 81 )
replace TRMTSHG = . if (TRMTSHG >= 81 )
replace TRMTSOP = . if (TRMTSOP >= 81 )
replace TRMTSP = . if (TRMTSP >= 81 )
replace TRMTREC = . if (TRMTREC >= 81 )
replace NOTRMT = . if (NOTRMT >= 85 )
replace TXEMRG = . if (TXEMRG >= 89 )
replace TXHOSP = . if (TXHOSP >= 89 )
replace TXDOC = . if (TXDOC >= 89 )
replace TXTRMT = . if (TXTRMT >= 89 )
replace TXMHC = . if (TXMHC >= 89 )
replace TXSHG = . if (TXSHG >= 89 )
replace TXSOP = . if (TXSOP >= 89 )
replace TXSP = . if (TXSP >= 85 )
replace TRMTLIFE = . if (TRMTLIFE >= 89 )
replace TRMTRESP = . if (TRMTRESP >= 89 )
replace TRMTFEAR = . if (TRMTFEAR >= 89 )
replace TRMTCOST = . if (TRMTCOST >= 89 )
replace TRMTEVNT = . if (TRMTEVNT >= 89 )
replace TRMTPR = . if (TRMTPR >= 89 )
replace TRMTHLTH = . if (TRMTHLTH >= 89 )
replace TRMTJOB = . if (TRMTJOB >= 89 )
replace TRMTJAIL = . if (TRMTJAIL >= 89 )
replace TRMTSERV = . if (TRMTSERV >= 89 )
replace TRMTBQD = . if (TRMTBQD >= 89 )
replace TRMTDNA = . if (TRMTDNA >= 89 )
replace TRMTSOR = . if (TRMTSOR >= 89 )
replace TRMTRSP = . if (TRMTRSP >= 85 )
replace TRMTOUTC = . if (TRMTOUTC >= 89 )
replace TMTPHI = . if (TMTPHI >= 89 )
replace TMTPSAVE = . if (TMTPSAVE >= 89 )
replace TMTPFMLY = . if (TMTPFMLY >= 89 )
replace TMTPEMPR = . if (TMTPEMPR >= 89 )
replace TMTPMEDI = . if (TMTPMEDI >= 89 )
replace TMTPFREE = . if (TMTPFREE >= 89 )
replace TMTPOTH = . if (TMTPOTH >= 89 )
replace TMTPASP = . if (TMTPASP >= 85 )
replace HIGHBP = . if (HIGHBP >= 94 )
replace BPMED = . if (BPMED >= 89 )
replace NOMARR = . if (NOMARR >= 85 )
replace WORKSTAT = . if (WORKSTAT >= 85 )
replace BHOUR = . if (BHOUR >= 98 )
replace BMIN = . if (BMIN >= 98 )
replace EHOUR = . if (EHOUR >= 98 )
replace EMIN = . if (EMIN >= 98 )
replace IRWORKST = . if (IRWORKST >= 13 )
replace QC06 = . if (QC06 >= 98 )
replace QC09 = . if (QC09 >= 91 )
replace CIGTRY = . if (CIGTRY >= 985 )
replace CIGREC = . if (CIGREC >= 91 )
replace AVCIG = . if (AVCIG >= 89 )
replace SNUFREC = . if (SNUFREC >= 91 )
replace OTHTOB = . if (OTHTOB >= 81 )
replace ALCTRY = . if (ALCTRY >= 981 )
replace ALCREC = . if (ALCREC >= 81 )
replace ALCAGE = . if (ALCAGE >= 981 )
replace ALCDAYS = . if (ALCDAYS >= 81 )
replace NODR30A = . if (NODR30A >= 81 )
replace DR5DAY = . if (DR5DAY >= 81 )
replace MODR30A = . if (MODR30A >= 81 )
replace MODR30DY = . if (MODR30DY >= 81 )
replace ALCPAT = . if (ALCPAT >= 81 )
replace DRUNKYR = . if (DRUNKYR >= 81 )
replace ALCBEER = . if (ALCBEER >= 81 )
replace ALCWINE = . if (ALCWINE >= 81 )
replace ALCLIQR = . if (ALCLIQR >= 81 )
replace ALCVARY = . if (ALCVARY >= 81 )
replace NOSEDAT = . if (NOSEDAT >= 98 )
replace BUTISOL = . if (BUTISOL >= 91 )
replace BUTICAPS = . if (BUTICAPS >= 91 )
replace AMYTAL = . if (AMYTAL >= 91 )
replace MEBARAL = . if (MEBARAL >= 91 )
replace PLACIDYL = . if (PLACIDYL >= 91 )
replace DORIDEN = . if (DORIDEN >= 91 )
replace NOLUDAR = . if (NOLUDAR >= 91 )
replace NEMBUTAL = . if (NEMBUTAL >= 91 )
replace SECONAL = . if (SECONAL >= 91 )
replace TUINAL = . if (TUINAL >= 91 )
replace DALMANE = . if (DALMANE >= 91 )
replace RESTORIL = . if (RESTORIL >= 91 )
replace HALCION = . if (HALCION >= 91 )
replace AMOBARB = . if (AMOBARB >= 91 )
replace PHENOBAR = . if (PHENOBAR >= 91 )
replace METHAQ = . if (METHAQ >= 91 )
replace CHHYD = . if (CHHYD >= 91 )
replace PENTOB = . if (PENTOB >= 91 )
replace SECOB = . if (SECOB >= 91 )
replace SEDNEWA = . if (SEDNEWA >= 981 )
replace SEDNEWB = . if (SEDNEWB >= 991 )
replace SEDNEWC = . if (SEDNEWC >= 991 )
replace SEDNEWD = . if (SEDNEWD >= 991 )
replace SEDNEWE = . if (SEDNEWE >= 991 )
replace SEDNOSP = . if (SEDNOSP >= 91 )
replace SEDDKNAM = . if (SEDDKNAM >= 91 )
replace SEDAGE = . if (SEDAGE >= 981 )
replace SEDTOT = . if (SEDTOT >= 91 )
replace SEDREC = . if (SEDREC >= 81 )
replace SEDYRFRQ = . if (SEDYRFRQ >= 81 )
replace TRNREAD = . if (TRNREAD >= 98 )
replace NOTRANQ = . if (NOTRANQ >= 98 )
replace VALIUM = . if (VALIUM >= 91 )
replace LIBRIUM = . if (LIBRIUM >= 91 )
replace LIMBTROL = . if (LIMBTROL >= 91 )
replace MENRIUM = . if (MENRIUM >= 91 )
replace SERAX = . if (SERAX >= 91 )
replace TRANXENE = . if (TRANXENE >= 91 )
replace ATIVAN = . if (ATIVAN >= 91 )
replace CENTRAX = . if (CENTRAX >= 91 )
replace XANAX = . if (XANAX >= 91 )
replace PAXIPAM = . if (PAXIPAM >= 91 )
replace BUSPAR = . if (BUSPAR >= 91 )
replace MILTOWN = . if (MILTOWN >= 91 )
replace EQUANIL = . if (EQUANIL >= 91 )
replace DEPROL = . if (DEPROL >= 91 )
replace VISTAR = . if (VISTAR >= 91 )
replace ATARAX = . if (ATARAX >= 91 )
replace DURRAX = . if (DURRAX >= 91 )
replace DIAZEPAM = . if (DIAZEPAM >= 91 )
replace SKLY = . if (SKLY >= 91 )
replace MEPROB = . if (MEPROB >= 91 )
replace TRNEWA = . if (TRNEWA >= 991 )
replace TRNEWB = . if (TRNEWB >= 991 )
replace TRNEWC = . if (TRNEWC >= 991 )
replace TRNEWD = . if (TRNEWD >= 991 )
replace TRNEWE = . if (TRNEWE >= 991 )
replace TRNOSP = . if (TRNOSP >= 91 )
replace TRDKNAM = . if (TRDKNAM >= 91 )
replace TRANAGE = . if (TRANAGE >= 981 )
replace TRANTOT = . if (TRANTOT >= 91 )
replace TRANREC = . if (TRANREC >= 91 )
replace TRNYRFRQ = . if (TRNYRFRQ >= 81 )
replace STMREAD = . if (STMREAD >= 96 )
replace NOSTIMS = . if (NOSTIMS >= 98 )
replace DEXED = . if (DEXED >= 91 )
replace DEXAMYL = . if (DEXAMYL >= 91 )
replace ESKAT = . if (ESKAT >= 91 )
replace BENZ = . if (BENZ >= 91 )
replace BIPHET = . if (BIPHET >= 91 )
replace DESOXYN = . if (DESOXYN >= 91 )
replace TENUATE = . if (TENUATE >= 91 )
replace TEPANIL = . if (TEPANIL >= 91 )
replace DIDREX = . if (DIDREX >= 91 )
replace PLEGINE = . if (PLEGINE >= 91 )
replace PRELUDIN = . if (PRELUDIN >= 91 )
replace IONAMIN = . if (IONAMIN >= 91 )
replace FASTIN = . if (FASTIN >= 91 )
replace PONDIMIN = . if (PONDIMIN >= 91 )
replace VORANIL = . if (VORANIL >= 91 )
replace SANOREX = . if (SANOREX >= 91 )
replace MAZANOR = . if (MAZANOR >= 91 )
replace RITALIN = . if (RITALIN >= 91 )
replace CYLERT = . if (CYLERT >= 91 )
replace DETAMP = . if (DETAMP >= 91 )
replace METHI = . if (METHI >= 91 )
replace METHAMP = . if (METHAMP >= 91 )
replace OBLA = . if (OBLA >= 91 )
replace STIMNEWA = . if (STIMNEWA >= 981 )
replace STIMNEWB = . if (STIMNEWB >= 981 )
replace STIMNEWC = . if (STIMNEWC >= 991 )
replace STIMNEWD = . if (STIMNEWD >= 991 )
replace STIMNEWE = . if (STIMNEWE >= 991 )
replace STIMNOSP = . if (STIMNOSP >= 91 )
replace STMDKNAM = . if (STMDKNAM >= 91 )
replace STIMAGE = . if (STIMAGE >= 981 )
replace STIMTOT = . if (STIMTOT >= 91 )
replace STIMREC = . if (STIMREC >= 91 )
replace STMYRFRQ = . if (STMYRFRQ >= 81 )
replace STNEEDLE = . if (STNEEDLE >= 81 )
replace STNDLREC = . if (STNDLREC >= 81 )
replace ANLREAD = . if (ANLREAD >= 96 )
replace ANALNONE = . if (ANALNONE >= 98 )
replace DARVON = . if (DARVON >= 91 )
replace DOLENE = . if (DOLENE >= 91 )
replace SK65A = . if (SK65A >= 91 )
replace WYGESIC = . if (WYGESIC >= 91 )
replace LEVODRO = . if (LEVODRO >= 91 )
replace PERCODAN = . if (PERCODAN >= 91 )
replace DEMEROL = . if (DEMEROL >= 91 )
replace DILAUD = . if (DILAUD >= 91 )
replace TYLCOD = . if (TYLCOD >= 91 )
replace PHENCOD = . if (PHENCOD >= 91 )
replace TALWIN = . if (TALWIN >= 91 )
replace TALWINNX = . if (TALWINNX >= 91 )
replace TALACEN = . if (TALACEN >= 91 )
replace PROPOXY = . if (PROPOXY >= 91 )
replace CODEINE = . if (CODEINE >= 91 )
replace ANILERID = . if (ANILERID >= 91 )
replace MORPHINE = . if (MORPHINE >= 91 )
replace METHDON = . if (METHDON >= 91 )
replace STADOL = . if (STADOL >= 91 )
replace ANALNEWA = . if (ANALNEWA >= 991 )
replace ANALNEWB = . if (ANALNEWB >= 991 )
replace ANALNEWC = . if (ANALNEWC >= 991 )
replace ANALNEWD = . if (ANALNEWD >= 991 )
replace ANALNEWE = . if (ANALNEWE >= 991 )
replace ANLNOSP = . if (ANLNOSP >= 91 )
replace ANLDKNAM = . if (ANLDKNAM >= 91 )
replace ANALAGE = . if (ANALAGE >= 981 )
replace ANALTOT = . if (ANALTOT >= 91 )
replace ANALREC = . if (ANALREC >= 91 )
replace ANLYRFRQ = . if (ANLYRFRQ >= 81 )
replace MJOPP = . if (MJOPP >= 981 )
replace MJAGE = . if (MJAGE >= 981 )
replace MJTOT = . if (MJTOT >= 81 )
replace MJREC = . if (MJREC >= 81 )
replace MJDAY30A = . if (MJDAY30A >= 81 )
replace MJAV30A = . if (MJAV30A >= 81 )
replace MJAV30B = . if (MJAV30B >= 81 )
replace MJAMT30A = . if (MJAMT30A >= 81 )
replace MJFRIEND = . if (MJFRIEND >= 81 )
replace MJDEALER = . if (MJDEALER >= 81 )
replace MJOTHSHR = . if (MJOTHSHR >= 81 )
replace MJGIVEN = . if (MJGIVEN >= 81 )
replace MJTRGOOD = . if (MJTRGOOD >= 81 )
replace MJTRSERV = . if (MJTRSERV >= 81 )
replace MJSTOLE = . if (MJSTOLE >= 81 )
replace MJTRICK = . if (MJTRICK >= 81 )
replace MJOBTNON = . if (MJOBTNON >= 81 )
replace MJBUCK = . if (MJBUCK >= 9981.0000 )
replace MJYRFREQ = . if (MJYRFREQ >= 81 )
replace MJJOINT = . if (MJJOINT >= 81 )
replace MJPIPE = . if (MJPIPE >= 81 )
replace MJBAKE = . if (MJBAKE >= 81 )
replace MJCHEW = . if (MJCHEW >= 81 )
replace MJWAY = . if (MJWAY >= 81 )
replace MJLFDALY = . if (MJLFDALY >= 81 )
replace INHREAD = . if (INHREAD >= 96 )
replace GAS = . if (GAS >= 81 )
replace LGAS = . if (LGAS >= 81 )
replace SPPAINT = . if (SPPAINT >= 81 )
replace AEROS = . if (AEROS >= 81 )
replace GLUE = . if (GLUE >= 81 )
replace SOLVENT = . if (SOLVENT >= 81 )
replace AMYLNIT = . if (AMYLNIT >= 81 )
replace ETHER = . if (ETHER >= 81 )
replace NITOXID = . if (NITOXID >= 81 )
replace CLEFLU = . if (CLEFLU >= 81 )
replace INHNEWA = . if (INHNEWA >= 981 )
replace INHNEWB = . if (INHNEWB >= 981 )
replace INHNEWC = . if (INHNEWC >= 981 )
replace INHNEWD = . if (INHNEWD >= 981 )
replace INHNEWE = . if (INHNEWE >= 981 )
replace INHNOSP = . if (INHNOSP >= 81 )
replace INHDKNAM = . if (INHDKNAM >= 81 )
replace INHAGE = . if (INHAGE >= 981 )
replace INHTOT = . if (INHTOT >= 81 )
replace INHREC = . if (INHREC >= 81 )
replace GAS30A = . if (GAS30A >= 81 )
replace LGAS30A = . if (LGAS30A >= 81 )
replace SPPAN30A = . if (SPPAN30A >= 81 )
replace AEROS30A = . if (AEROS30A >= 81 )
replace GLUE30A = . if (GLUE30A >= 81 )
replace SOLVN30A = . if (SOLVN30A >= 81 )
replace AMLNT30A = . if (AMLNT30A >= 81 )
replace ETHER30A = . if (ETHER30A >= 81 )
replace NOX30A = . if (NOX30A >= 81 )
replace CLFL30A = . if (CLFL30A >= 81 )
replace INNEW30A = . if (INNEW30A >= 981 )
replace INNEW30B = . if (INNEW30B >= 981 )
replace INNEW30C = . if (INNEW30C >= 981 )
replace INNEW30D = . if (INNEW30D >= 981 )
replace INNEW30E = . if (INNEW30E >= 981 )
replace IN30NOSP = . if (IN30NOSP >= 81 )
replace INH30NO = . if (INH30NO >= 81 )
replace INHDY30A = . if (INHDY30A >= 81 )
replace INHYRFRQ = . if (INHYRFRQ >= 81 )
replace INHPO = . if (INHPO >= 81 )
replace INHQNC1 = . if (INHQNC1 >= 98 )
replace INHQNC2 = . if (INHQNC2 >= 98 )
replace INHQNC3 = . if (INHQNC3 >= 98 )
replace INHQNC4 = . if (INHQNC4 >= 98 )
replace INHQNC5 = . if (INHQNC5 >= 98 )
replace INHQNC6 = . if (INHQNC6 >= 98 )
replace INHQNC7 = . if (INHQNC7 >= 98 )
replace INHQNC8 = . if (INHQNC8 >= 98 )
replace INHQNC10 = . if (INHQNC10 >= 98 )
replace INHANSY = . if (INHANSY >= 96 )
replace COCOPP = . if (COCOPP >= 981 )
replace COCAGE = . if (COCAGE >= 981 )
replace COCTOT = . if (COCTOT >= 81 )
replace COCREC = . if (COCREC >= 81 )
replace COCUS30A = . if (COCUS30A >= 81 )
replace COCAM30A = . if (COCAM30A >= 81 )
replace CCFRIEND = . if (CCFRIEND >= 81 )
replace CCDEALER = . if (CCDEALER >= 81 )
replace CCOTHSHR = . if (CCOTHSHR >= 81 )
replace CCGIVEN = . if (CCGIVEN >= 81 )
replace CCTRGOOD = . if (CCTRGOOD >= 81 )
replace CCTRSERV = . if (CCTRSERV >= 81 )
replace CCSTOLE = . if (CCSTOLE >= 81 )
replace CCTRICK = . if (CCTRICK >= 81 )
replace CCOBTNON = . if (CCOBTNON >= 81 )
replace COCBUCK = . if (COCBUCK >= 9981 )
replace COCYRFRQ = . if (COCYRFRQ >= 81 )
replace COCSNIFF = . if (COCSNIFF >= 81 )
replace COCSWAL = . if (COCSWAL >= 81 )
replace COCIV = . if (COCIV >= 81 )
replace FREEBASE = . if (FREEBASE >= 81 )
replace COCWAY = . if (COCWAY >= 81 )
replace CONDLREC = . if (CONDLREC >= 81 )
replace CCLFDALY = . if (CCLFDALY >= 81 )
replace CRAKREC = . if (CRAKREC >= 81 )
replace CRKAM30A = . if (CRKAM30A >= 981 )
replace CKFRIEND = . if (CKFRIEND >= 81 )
replace CKDEALER = . if (CKDEALER >= 81 )
replace CKOTHSHR = . if (CKOTHSHR >= 81 )
replace CKGIVEN = . if (CKGIVEN >= 81 )
replace CKTRGOOD = . if (CKTRGOOD >= 81 )
replace CKTRSERV = . if (CKTRSERV >= 81 )
replace CKSTOLE = . if (CKSTOLE >= 81 )
replace CKTRICK = . if (CKTRICK >= 81 )
replace CKOBTNON = . if (CKOBTNON >= 81 )
replace CRAKBUCK = . if (CRAKBUCK >= 9981 )
replace CKLFDALY = . if (CKLFDALY >= 81 )
replace HALREAD = . if (HALREAD >= 97 )
replace LSD = . if (LSD >= 81 )
replace PEYOTE = . if (PEYOTE >= 81 )
replace MESC = . if (MESC >= 81 )
replace PSILCY = . if (PSILCY >= 81 )
replace PCP = . if (PCP >= 81 )
replace ECSTASY = . if (ECSTASY >= 81 )
replace HALNEWA = . if (HALNEWA >= 981 )
replace HALNEWB = . if (HALNEWB >= 981 )
replace HALNEWC = . if (HALNEWC >= 981 )
replace HALNEWD = . if (HALNEWD >= 981 )
replace HALNEWE = . if (HALNEWE >= 981 )
replace HALNOSP = . if (HALNOSP >= 81 )
replace HALDKNAM = . if (HALDKNAM >= 81 )
replace HALLOPP = . if (HALLOPP >= 981 )
replace HALLAGE = . if (HALLAGE >= 981 )
replace HALLTOT = . if (HALLTOT >= 81 )
replace HALLREC = . if (HALLREC >= 81 )
replace HAL30USE = . if (HAL30USE >= 81 )
replace HALYRFRQ = . if (HALYRFRQ >= 81 )
replace PCPREC = . if (PCPREC >= 81 )
replace HERREAD = . if (HERREAD >= 96 )
replace HEROPP = . if (HEROPP >= 981 )
replace HERAGE = . if (HERAGE >= 981 )
replace HERTOT = . if (HERTOT >= 81 )
replace HERREC = . if (HERREC >= 81 )
replace HER30USE = . if (HER30USE >= 81 )
replace HERNEEDL = . if (HERNEEDL >= 81 )
replace HRNDLREC = . if (HRNDLREC >= 81 )
replace DRGREAD = . if (DRGREAD >= 96 )
replace CDCIG = . if (CDCIG >= 81 )
replace CDALC = . if (CDALC >= 81 )
replace CDSED = . if (CDSED >= 13 )
replace CDTRAN = . if (CDTRAN >= 13 )
replace CDSTM = . if (CDSTM >= 13 )
replace CDANAL = . if (CDANAL >= 13 )
replace CDMJ = . if (CDMJ >= 13 )
replace CDINH = . if (CDINH >= 13 )
replace CDCOC = . if (CDCOC >= 13 )
replace CDHALL = . if (CDHALL >= 13 )
replace CDHER = . if (CDHER >= 13 )
replace CDOTHOP = . if (CDOTHOP >= 13 )
replace CDNONE = . if (CDNONE >= 81 )
replace UCDCIG = . if (UCDCIG >= 13 )
replace UCDALC = . if (UCDALC >= 13 )
replace UCDSED = . if (UCDSED >= 13 )
replace UCDTRAN = . if (UCDTRAN >= 13 )
replace UCDSTM = . if (UCDSTM >= 13 )
replace UCDANAL = . if (UCDANAL >= 13 )
replace UCDMJ = . if (UCDMJ >= 13 )
replace UCDINH = . if (UCDINH >= 13 )
replace UCDCOC = . if (UCDCOC >= 13 )
replace UCDHALL = . if (UCDHALL >= 13 )
replace UCDHER = . if (UCDHER >= 13 )
replace UCDOTHOP = . if (UCDOTHOP >= 13 )
replace UCDNONE = . if (UCDNONE >= 13 )
replace EFFCIG = . if (EFFCIG >= 13 )
replace EFFALC = . if (EFFALC >= 13 )
replace EFFSED = . if (EFFSED >= 13 )
replace EFFTRAN = . if (EFFTRAN >= 13 )
replace EFFSTM = . if (EFFSTM >= 13 )
replace EFFANAL = . if (EFFANAL >= 13 )
replace EFFMJ = . if (EFFMJ >= 13 )
replace EFFINH = . if (EFFINH >= 13 )
replace EFFCOC = . if (EFFCOC >= 13 )
replace EFFHALL = . if (EFFHALL >= 13 )
replace EFFHER = . if (EFFHER >= 13 )
replace EFFOTHOP = . if (EFFOTHOP >= 13 )
replace EFFNONE = . if (EFFNONE >= 13 )
replace UDAYCIG = . if (UDAYCIG >= 13 )
replace UDAYALC = . if (UDAYALC >= 13 )
replace UDAYSED = . if (UDAYSED >= 13 )
replace UDAYTRAN = . if (UDAYTRAN >= 13 )
replace UDAYSTM = . if (UDAYSTM >= 13 )
replace UDAYANAL = . if (UDAYANAL >= 13 )
replace UDAYMJ = . if (UDAYMJ >= 13 )
replace UDAYINH = . if (UDAYINH >= 13 )
replace UDAYCOC = . if (UDAYCOC >= 13 )
replace UDAYHALL = . if (UDAYHALL >= 13 )
replace UDAYHER = . if (UDAYHER >= 13 )
replace UDAYOTH = . if (UDAYOTH >= 13 )
replace UDAYNONE = . if (UDAYNONE >= 13 )
replace DEPCIG = . if (DEPCIG >= 13 )
replace DEPALC = . if (DEPALC >= 13 )
replace DEPSED = . if (DEPSED >= 13 )
replace DEPTRAN = . if (DEPTRAN >= 13 )
replace DEPSTM = . if (DEPSTM >= 13 )
replace DEPANAL = . if (DEPANAL >= 13 )
replace DEPMJ = . if (DEPMJ >= 13 )
replace DEPINH = . if (DEPINH >= 13 )
replace DEPCOC = . if (DEPCOC >= 13 )
replace DEPHALL = . if (DEPHALL >= 13 )
replace DEPHER = . if (DEPHER >= 13 )
replace DEPOTHOP = . if (DEPOTHOP >= 13 )
replace DEPNONE = . if (DEPNONE >= 13 )
replace WSCIG = . if (WSCIG >= 13 )
replace WSALC = . if (WSALC >= 13 )
replace WSSED = . if (WSSED >= 13 )
replace WSTRAN = . if (WSTRAN >= 13 )
replace WSSTM = . if (WSSTM >= 13 )
replace WSANAL = . if (WSANAL >= 13 )
replace WSMJ = . if (WSMJ >= 13 )
replace WSINH = . if (WSINH >= 13 )
replace WSCOC = . if (WSCOC >= 13 )
replace WSHALL = . if (WSHALL >= 13 )
replace WSHER = . if (WSHER >= 13 )
replace WSOTHOP = . if (WSOTHOP >= 13 )
replace WSNONE = . if (WSNONE >= 13 )
replace NDLREAD = . if (NDLREAD >= 96 )
replace GNNDLLIF = . if (GNNDLLIF >= 81 )
replace GNNDLREC = . if (GNNDLREC >= 81 )
replace GNNDLSED = . if (GNNDLSED >= 81 )
replace GNNDLTRA = . if (GNNDLTRA >= 81 )
replace GNNDLSTM = . if (GNNDLSTM >= 81 )
replace GNNDLANL = . if (GNNDLANL >= 81 )
replace GNNDLINH = . if (GNNDLINH >= 81 )
replace GNNDLCOC = . if (GNNDLCOC >= 81 )
replace GNNDLHAL = . if (GNNDLHAL >= 81 )
replace GNNDLHER = . if (GNNDLHER >= 81 )
replace GNNDLOPT = . if (GNNDLOPT >= 81 )
replace GNNDLSTR = . if (GNNDLSTR >= 81 )
replace GNNDLNON = . if (GNNDLNON >= 81 )
replace GNNDLSH1 = . if (GNNDLSH1 >= 81 )
replace GNNDLSH2 = . if (GNNDLSH2 >= 81 )
replace SPTREAD = . if (SPTREAD >= 98 )
replace DRUGTEST = . if (DRUGTEST >= 85 )
replace TESTPOS = . if (TESTPOS >= 85 )
replace ICELIFE = . if (ICELIFE >= 81 )
replace ICEREC = . if (ICEREC >= 81 )
replace STEROPP = . if (STEROPP >= 981 )
replace STERAGE = . if (STERAGE >= 981 )
replace STERTOT = . if (STERTOT >= 81 )
replace STERREC = . if (STERREC >= 81 )
replace SPNEWA = . if (SPNEWA >= 997 )
replace SPNEWB = . if (SPNEWB >= 997 )
replace SPNEWC = . if (SPNEWC >= 997 )
replace SPNEWD = . if (SPNEWD >= 997 )
replace SPNEWE = . if (SPNEWE >= 997 )
replace BOOKED = . if (BOOKED >= 94 )
replace PROBATON = . if (PROBATON >= 85 )
replace PAROLE = . if (PAROLE >= 85 )
replace STRSTEAL = . if (STRSTEAL >= 85 )
replace OTHSTEAL = . if (OTHSTEAL >= 85 )
replace DAMAGE = . if (DAMAGE >= 85 )
replace CARSTEAL = . if (CARSTEAL >= 85 )
replace FORCEMON = . if (FORCEMON >= 85 )
replace BREAKIN = . if (BREAKIN >= 85 )
replace PHYFIGHT = . if (PHYFIGHT >= 85 )
replace HURTBAD = . if (HURTBAD >= 85 )
replace GUNMONEY = . if (GUNMONEY >= 85 )
replace SOLDDRUG = . if (SOLDDRUG >= 85 )
replace DEXREAD = . if (DEXREAD >= 96 )
replace NOBOOZYR = . if (NOBOOZYR >= 85 )
replace ALCAGGR = . if (ALCAGGR >= 94 )
replace ALCARGUM = . if (ALCARGUM >= 94 )
replace ALCABSNT = . if (ALCABSNT >= 97 )
replace ALCHIGH = . if (ALCHIGH >= 94 )
replace ALCJOB = . if (ALCJOB >= 94 )
replace ALCMATCD = . if (ALCMATCD >= 89 )
replace ALCRELCD = . if (ALCRELCD >= 97 )
replace ALCFRDCD = . if (ALCFRDCD >= 97 )
replace ALCTOSS = . if (ALCTOSS >= 97 )
replace ALCHOLIC = . if (ALCHOLIC >= 89 )
replace ALCDRUNK = . if (ALCDRUNK >= 97 )
replace ALCINTOX = . if (ALCINTOX >= 97 )
replace ALCREM = . if (ALCREM >= 97 )
replace ALCQUICK = . if (ALCQUICK >= 89 )
replace ALCMORN = . if (ALCMORN >= 97 )
replace ALCSHOOK = . if (ALCSHOOK >= 97 )
replace ALCALONE = . if (ALCALONE >= 97 )
replace ALCBRKPM = . if (ALCBRKPM >= 97 )
replace AS13NONE = . if (AS13NONE >= 85 )
replace DRDEPRSS = . if (DRDEPRSS >= 97 )
replace DEPDRG1A = . if (DEPDRG1A >= 989 )
replace DEPDRG2A = . if (DEPDRG2A >= 997 )
replace DEPDRG3A = . if (DEPDRG3A >= 997 )
replace DEPDRG4A = . if (DEPDRG4A >= 997 )
replace DEPDRG5A = . if (DEPDRG5A >= 997 )
replace DRARGUM = . if (DRARGUM >= 89 )
replace ARGDRG1A = . if (ARGDRG1A >= 989 )
replace ARGDRG2A = . if (ARGDRG2A >= 997 )
replace ARGDRG3A = . if (ARGDRG3A >= 997 )
replace ARGDRG4A = . if (ARGDRG4A >= 997 )
replace ARGDRG5A = . if (ARGDRG5A >= 997 )
replace DRALONE = . if (DRALONE >= 97 )
replace ALNDRG1A = . if (ALNDRG1A >= 989 )
replace ALNDRG2A = . if (ALNDRG2A >= 997 )
replace ALNDRG3A = . if (ALNDRG3A >= 997 )
replace ALNDRG4A = . if (ALNDRG4A >= 997 )
replace ALNDRG5A = . if (ALNDRG5A >= 997 )
replace DRANX = . if (DRANX >= 97 )
replace ANXDRG1A = . if (ANXDRG1A >= 989 )
replace ANXDRG2A = . if (ANXDRG2A >= 997 )
replace ANXDRG3A = . if (ANXDRG3A >= 997 )
replace ANXDRG4A = . if (ANXDRG4A >= 997 )
replace ANXDRG5A = . if (ANXDRG5A >= 997 )
replace DRHEALTH = . if (DRHEALTH >= 97 )
replace HLTDRG1A = . if (HLTDRG1A >= 989 )
replace HLTDRG2A = . if (HLTDRG2A >= 997 )
replace HLTDRG3A = . if (HLTDRG3A >= 997 )
replace HLTDRG4A = . if (HLTDRG4A >= 997 )
replace HLTDRG5A = . if (HLTDRG5A >= 997 )
replace DRNTHINK = . if (DRNTHINK >= 97 )
replace NTKDRG1A = . if (NTKDRG1A >= 989 )
replace NTKDRG2A = . if (NTKDRG2A >= 997 )
replace NTKDRG3A = . if (NTKDRG3A >= 997 )
replace NTKDRG4A = . if (NTKDRG4A >= 997 )
replace NTKDRG5A = . if (NTKDRG5A >= 997 )
replace DRUPSET = . if (DRUPSET >= 97 )
replace UPSDRG1A = . if (UPSDRG1A >= 989 )
replace UPSDRG2A = . if (UPSDRG2A >= 997 )
replace UPSDRG3A = . if (UPSDRG3A >= 997 )
replace UPSDRG4A = . if (UPSDRG4A >= 997 )
replace UPSDRG5A = . if (UPSDRG5A >= 997 )
replace DRLSWORK = . if (DRLSWORK >= 89 )
replace LSWDRG1A = . if (LSWDRG1A >= 989 )
replace LSWDRG2A = . if (LSWDRG2A >= 997 )
replace LSWDRG3A = . if (LSWDRG3A >= 997 )
replace LSWDRG4A = . if (LSWDRG4A >= 997 )
replace LSWDRG5A = . if (LSWDRG5A >= 997 )
replace DRSUSPIC = . if (DRSUSPIC >= 89 )
replace SSPDRG1A = . if (SSPDRG1A >= 989 )
replace SSPDRG2A = . if (SSPDRG2A >= 997 )
replace SSPDRG3A = . if (SSPDRG3A >= 997 )
replace SSPDRG4A = . if (SSPDRG4A >= 997 )
replace SSPDRG5A = . if (SSPDRG5A >= 997 )
replace DRCOPE = . if (DRCOPE >= 97 )
replace CPEDRG1A = . if (CPEDRG1A >= 989 )
replace CPEDRG2A = . if (CPEDRG2A >= 997 )
replace CPEDRG3A = . if (CPEDRG3A >= 997 )
replace CPEDRG4A = . if (CPEDRG4A >= 997 )
replace CPEDRG5A = . if (CPEDRG5A >= 997 )
replace DREMGMED = . if (DREMGMED >= 97 )
replace EMDRG1A = . if (EMDRG1A >= 989 )
replace EMDRG2A = . if (EMDRG2A >= 997 )
replace EMDRG3A = . if (EMDRG3A >= 997 )
replace EMDRG4A = . if (EMDRG4A >= 997 )
replace EMDRG5A = . if (EMDRG5A >= 997 )
replace DRTRMT = . if (DRTRMT >= 97 )
replace TMTDRG1A = . if (TMTDRG1A >= 994 )
replace TMTDRG2A = . if (TMTDRG2A >= 997 )
replace TMTDRG3A = . if (TMTDRG3A >= 997 )
replace TMTDRG4A = . if (TMTDRG4A >= 997 )
replace TMTDRG5A = . if (TMTDRG5A >= 997 )
replace DRDRVUN = . if (DRDRVUN >= 97 )
replace DRVDRG1A = . if (DRVDRG1A >= 989 )
replace DRVDRG2A = . if (DRVDRG2A >= 997 )
replace DRVDRG3A = . if (DRVDRG3A >= 997 )
replace DRVDRG4A = . if (DRVDRG4A >= 997 )
replace DRVDRG5A = . if (DRVDRG5A >= 997 )
replace TMTREAD = . if (TMTREAD >= 96 )
replace EMPDRUG = . if (EMPDRUG >= 97 )
replace RSKPKCIG = . if (RSKPKCIG >= 94 )
replace RSKTRYMJ = . if (RSKTRYMJ >= 94 )
replace RSKMJOCC = . if (RSKMJOCC >= 94 )
replace RSKMJREG = . if (RSKMJREG >= 94 )
replace RKTRYPCP = . if (RKTRYPCP >= 94 )
replace RKPCPREG = . if (RKPCPREG >= 94 )
replace RKTRYHER = . if (RKTRYHER >= 94 )
replace RKHERREG = . if (RKHERREG >= 94 )
replace RKTRYCOC = . if (RKTRYCOC >= 94 )
replace RKCOCOCC = . if (RKCOCOCC >= 94 )
replace RKCOCREG = . if (RKCOCREG >= 94 )
replace RKCRKOCC = . if (RKCRKOCC >= 94 )
replace RKANSOCC = . if (RKANSOCC >= 94 )
replace RKANSREG = . if (RKANSREG >= 94 )
replace RK2DRINK = . if (RK2DRINK >= 94 )
replace RK5DRINK = . if (RK5DRINK >= 94 )
replace RSKBINGE = . if (RSKBINGE >= 94 )
replace RSKDIFMJ = . if (RSKDIFMJ >= 94 )
replace RKDIFLSD = . if (RKDIFLSD >= 94 )
replace RKDIFPCP = . if (RKDIFPCP >= 94 )
replace RKDIFCOC = . if (RKDIFCOC >= 94 )
replace RKDIFHER = . if (RKDIFHER >= 94 )
replace RSKSELL = . if (RSKSELL >= 94 )
replace RKNEIDRN = . if (RKNEIDRN >= 94 )
replace RKNEISEL = . if (RKNEISEL >= 94 )
replace WALKPAIN = . if (WALKPAIN >= 94 )
replace TIMEPAIN = . if (TIMEPAIN >= 94 )
replace UPSHOR = . if (UPSHOR >= 94 )
replace ASTHMA = . if (ASTHMA >= 94 )
replace TRPSYCH = . if (TRPSYCH >= 94 )
replace HEART = . if (HEART >= 94 )
replace FLU = . if (FLU >= 94 )
replace ALLERG = . if (ALLERG >= 94 )
replace HOSPYR = . if (HOSPYR >= 96 )
replace SOREYR = . if (SOREYR >= 94 )
replace RUNNYYR = . if (RUNNYYR >= 94 )
replace COUGHYR = . if (COUGHYR >= 94 )
replace PHLEGMYR = . if (PHLEGMYR >= 94 )
replace HEALTHYR = . if (HEALTHYR >= 94 )
replace FLTEAT = . if (FLTEAT >= 94 )
replace FLTMIND = . if (FLTMIND >= 94 )
replace FLTDEPRS = . if (FLTDEPRS >= 94 )
replace FLTEFFRT = . if (FLTEFFRT >= 94 )
replace FLTSLEEP = . if (FLTSLEEP >= 94 )
replace FLTSAD = . if (FLTSAD >= 94 )
replace FLTGOING = . if (FLTGOING >= 94 )
replace MARITAL = . if (MARITAL >= 85 )
replace PAYMO = . if (PAYMO >= 89 )
replace PAYYR = . if (PAYYR >= 985 )
replace NO5JOB = . if (NO5JOB >= 89 )
replace WORKDAYS = . if (WORKDAYS >= 89 )
replace WORKBLAH = . if (WORKBLAH >= 85 )
replace CWE = . if (CWE >= 89 )
replace FULLPART = . if (FULLPART >= 89 )
replace EDUC = . if (EDUC >= 85 )
replace GRADHS = . if (GRADHS >= 89 )
replace DIPLOMA = . if (DIPLOMA >= 89 )
replace ENROLLD = . if (ENROLLD >= 94 )
replace SCHPLANS = . if (SCHPLANS >= 89 )
replace STUDENT = . if (STUDENT >= 89 )
replace SCHDAYS = . if (SCHDAYS >= 89 )
replace SKIPPED = . if (SKIPPED >= 89 )
replace MILES = . if (MILES >= 99989 )
replace ACCID = . if (ACCID >= 89 )
replace NOCHILD = . if (NOCHILD >= 89 )
replace TOTPEOP = . if (TOTPEOP >= 97 )
replace MOTHER = . if (MOTHER >= 97 )
replace FATHER = . if (FATHER >= 97 )
replace STEPMOM = . if (STEPMOM >= 97 )
replace STEPDAD = . if (STEPDAD >= 97 )
replace SPOUSE = . if (SPOUSE >= 97 )
replace INLAW = . if (INLAW >= 93 )
replace OWNCHILD = . if (OWNCHILD >= 93 )
replace STEPCHLD = . if (STEPCHLD >= 97 )
replace BROSIS = . if (BROSIS >= 93 )
replace OTHREL = . if (OTHREL >= 93 )
replace FRIENDS = . if (FRIENDS >= 93 )
replace OTHERNON = . if (OTHERNON >= 93 )
replace MOVDAWAY = . if (MOVDAWAY >= 94 )
replace DORM = . if (DORM >= 94 )
replace MILBASE = . if (MILBASE >= 94 )
replace HOSP = . if (HOSP >= 94 )
replace OTHGPH = . if (OTHGPH >= 85 )
replace OTHGPHSP = . if (OTHGPHSP >= 85 )
replace SERVICE = . if (SERVICE >= 89 )
replace MILSTAT = . if (MILSTAT >= 89 )
replace TELNO = . if (TELNO >= 97 )
replace MOVES = . if (MOVES >= 94 )
replace PROXABLE = . if (PROXABLE >= 89 )
replace PROXYREL = . if (PROXYREL >= 89 )
replace PROXHOME = . if (PROXHOME >= 89 )
replace PROXJOIN = . if (PROXJOIN >= 89 )
replace MEDICARE = . if (MEDICARE >= 94 )
replace MEDICAID = . if (MEDICAID >= 94 )
replace CHAMPUS = . if (CHAMPUS >= 94 )
replace PRVHLTIN = . if (PRVHLTIN >= 94 )
replace OWNHLTIN = . if (OWNHLTIN >= 89 )
replace GRPHLTIN = . if (GRPHLTIN >= 89 )
replace HLTINALC = . if (HLTINALC >= 89 )
replace HLTINDRG = . if (HLTINDRG >= 89 )
replace HLTINMNT = . if (HLTINMNT >= 89 )
replace WHOANSHI = . if (WHOANSHI >= 94 )
replace JOB = . if (JOB >= 94 )
replace HOURS = . if (HOURS >= 985 )
replace WORK = . if (WORK >= 94 )
replace WAG1 = . if (WAG1 >= 94 )
replace AWAG1 = . if (AWAG1 >= 999985 )
replace WEEKS = . if (WEEKS >= 94 )
replace SOC1 = . if (SOC1 >= 94 )
replace ASOC1 = . if (ASOC1 >= 999985 )
replace SSI1 = . if (SSI1 >= 94 )
replace ASSI1 = . if (ASSI1 >= 999985 )
replace PUB1 = . if (PUB1 >= 94 )
replace AFDC1 = . if (AFDC1 >= 94 )
replace WEL1 = . if (WEL1 >= 94 )
replace AWEL1 = . if (AWEL1 >= 999985 )
replace INT1 = . if (INT1 >= 94 )
replace AINT1 = . if (AINT1 >= 999985 )
replace CHD1 = . if (CHD1 >= 94 )
replace ACHD1 = . if (ACHD1 >= 999985 )
replace OTH1 = . if (OTH1 >= 94 )
replace AOTH1 = . if (AOTH1 >= 999985 )
replace FAMLYRES = . if (FAMLYRES >= 94 )
replace WAG2 = . if (WAG2 >= 89 )
replace AWAG2 = . if (AWAG2 >= 999985 )
replace SOC2 = . if (SOC2 >= 89 )
replace ASOC2 = . if (ASOC2 >= 999985 )
replace SSI2 = . if (SSI2 >= 89 )
replace ASSI2 = . if (ASSI2 >= 999985 )
replace PUB2 = . if (PUB2 >= 89 )
replace AFDC2 = . if (AFDC2 >= 89 )
replace WEL2 = . if (WEL2 >= 89 )
replace AWEL2 = . if (AWEL2 >= 999985 )
replace INT2 = . if (INT2 >= 89 )
replace AINT2 = . if (AINT2 >= 999985 )
replace CHD2 = . if (CHD2 >= 89 )
replace ACHD2 = . if (ACHD2 >= 99985 )
replace OTH2 = . if (OTH2 >= 89 )
replace AOTH2 = . if (AOTH2 >= 999985 )
replace WHOANSIN = . if (WHOANSIN >= 89 )
replace FSTAMP = . if (FSTAMP >= 94 )
replace PEOPFD = . if (PEOPFD >= 85 )
replace FOOD = . if (FOOD >= 94 )
replace AFOOD = . if (AFOOD >= 999985 )
replace BAP = . if (BAP >= 98 )
replace EAP = . if (EAP >= 96 )
replace LANGVER = . if (LANGVER >= 98 )
replace UNDINT = . if (UNDINT >= 94 )
replace COOPINT = . if (COOPINT >= 96 )
replace PRIVACY = . if (PRIVACY >= 85 )
replace PPRES = . if (PPRES >= 98 )
replace SPRES = . if (SPRES >= 98 )
replace PARPRES = . if (PARPRES >= 98 )
replace OARPRES = . if (OARPRES >= 98 )
replace OAPRES = . if (OAPRES >= 98 )
replace CPRES = . if (CPRES >= 98 )
replace OPRESNSP = . if (OPRESNSP >= 98 )
replace OPRESSPA = . if (OPRESSPA >= 98 )
replace WHOMARKD = . if (WHOMARKD >= 96 )
replace FAMSKIP = . if (FAMSKIP >= 98 )
replace DC = . if (DC >= 9 )
replace CHICAGO = . if (CHICAGO >= 9 )
replace DENVER = . if (DENVER >= 9 )
replace LA = . if (LA >= 9 )
replace MIAMI = . if (MIAMI >= 9 )
replace NEWYORK = . if (NEWYORK >= 9 )
replace URBARE = . if (URBARE >= 9 )
replace METRO = . if (METRO >= 9 )
replace IRHOGRP = . if (IRHOGRP >= 99 )
replace IRHOGRP2 = . if (IRHOGRP2 >= 99 )
replace IIHOGRP2 = . if (IIHOGRP2 >= 9 )
replace IRMARIT = . if (IRMARIT >= 99 )
replace IIMARIT = . if (IIMARIT >= 9 )
replace IIWAG1 = . if (IIWAG1 >= 9 )
replace IIAWAG1 = . if (IIAWAG1 >= 9 )
replace IIASOC1 = . if (IIASOC1 >= 9 )
replace IIASSI1 = . if (IIASSI1 >= 9 )
replace IIAWEL1 = . if (IIAWEL1 >= 9 )
replace IIAINT1 = . if (IIAINT1 >= 9 )
replace IIACHD1 = . if (IIACHD1 >= 9 )
replace IIAOTH1 = . if (IIAOTH1 >= 9 )
replace IIWAG2 = . if (IIWAG2 >= 9 )
replace IIAWAG2 = . if (IIAWAG2 >= 9 )
replace IISOC2 = . if (IISOC2 >= 9 )
replace IIASOC2 = . if (IIASOC2 >= 9 )
replace IISSI2 = . if (IISSI2 >= 9 )
replace IIASSI2 = . if (IIASSI2 >= 9 )
replace IIWEL2 = . if (IIWEL2 >= 9 )
replace IIAWEL2 = . if (IIAWEL2 >= 9 )
replace IIINT2 = . if (IIINT2 >= 9 )
replace IIAINT2 = . if (IIAINT2 >= 9 )
replace IICHD2 = . if (IICHD2 >= 9 )
replace IIACHD2 = . if (IIACHD2 >= 9 )
replace IIOTH2 = . if (IIOTH2 >= 9 )
replace IIAOTH2 = . if (IIAOTH2 >= 9 )
replace IIAFOOD = . if (IIAFOOD >= 9 )
replace IRALCRC = . if (IRALCRC >= 9 )
replace IRMJRC = . if (IRMJRC >= 9 )
replace IRCOCRC = . if (IRCOCRC >= 9 )
replace IRSEDRC = . if (IRSEDRC >= 9 )
replace IRTRNRC = . if (IRTRNRC >= 9 )
replace IRSTMRC = . if (IRSTMRC >= 9 )
replace IRANLRC = . if (IRANLRC >= 9 )
replace IRCIGRC = . if (IRCIGRC >= 9 )
replace IROTBRC = . if (IROTBRC >= 9 )
replace IRINHRC = . if (IRINHRC >= 9 )
replace IRCRKRC = . if (IRCRKRC >= 9 )
replace IRHALRC = . if (IRHALRC >= 9 )
replace IRHERRC = . if (IRHERRC >= 9 )
replace IRPCPRC = . if (IRPCPRC >= 9 )
replace IRICERC = . if (IRICERC >= 9 )
replace IRSTRRC = . if (IRSTRRC >= 9 )
replace IRALCFQ = . if (IRALCFQ >= 9 )
replace IRMJFQ = . if (IRMJFQ >= 10 )
replace IRCOCFQ = . if (IRCOCFQ >= 9 )
replace IRSEDFQ = . if (IRSEDFQ >= 9 )
replace IRTRNFQ = . if (IRTRNFQ >= 9 )
replace IRSTMFQ = . if (IRSTMFQ >= 9 )
replace IRANLFQ = . if (IRANLFQ >= 9 )
replace IROTBFQ = . if (IROTBFQ >= 9 )
replace IRINHFQ = . if (IRINHFQ >= 9 )
replace IRHALFQ = . if (IRHALFQ >= 9 )
replace NEEDLREC = . if (NEEDLREC >= 91 )
replace NDL90REC = . if (NDL90REC >= 91 )
replace AL02 = . if (AL02 >= 91 )
replace SE04 = . if (SE04 >= 97 )
replace TR04 = . if (TR04 >= 97 )
replace ST04 = . if (ST04 >= 97 )
replace ST07 = . if (ST07 >= 97 )
replace AN04 = . if (AN04 >= 97 )
replace MJ04 = . if (MJ04 >= 91 )
replace IN04 = . if (IN04 >= 91 )
replace CC04 = . if (CC04 >= 91 )
replace CC11 = . if (CC11 >= 91 )
replace CK01 = . if (CK01 >= 81 )
replace LS05 = . if (LS05 >= 91 )
replace LS08 = . if (LS08 >= 91 )
replace HE04 = . if (HE04 >= 91 )
replace HE07 = . if (HE07 >= 91 )
replace ND02 = . if (ND02 >= 91 )
replace SP04 = . if (SP04 >= 91 )
replace SP08 = . if (SP08 >= 91 )
replace CHAGE10 = . if (CHAGE10 >= 13 )
replace CWEOCC2 = . if (CWEOCC2 >= 990 )
replace ROCCUP2 = . if (ROCCUP2 >= 990 )
replace BUSINES2 = . if (BUSINES2 >= 990 )
replace CWEBUS2 = . if (CWEBUS2 >= 990 )
replace INTMONTH = . if (INTMONTH >= 13 )
replace IRALCAGG = . if (IRALCAGG >= 99 )
replace IRALCARG = . if (IRALCARG >= 99 )
replace IRALCABS = . if (IRALCABS >= 99 )
replace IRALCHIG = . if (IRALCHIG >= 99 )
replace IRALCJOB = . if (IRALCJOB >= 99 )
replace IRALCMAT = . if (IRALCMAT >= 99 )
replace IRALCREL = . if (IRALCREL >= 99 )
replace IRALCFRD = . if (IRALCFRD >= 99 )
replace IRALCTOS = . if (IRALCTOS >= 99 )
replace IRALCHOL = . if (IRALCHOL >= 99 )
replace IRALCDRU = . if (IRALCDRU >= 99 )
replace IRALCINT = . if (IRALCINT >= 99 )
replace IRALCREM = . if (IRALCREM >= 99 )
replace IRALCQUI = . if (IRALCQUI >= 99 )
replace IRALCMOR = . if (IRALCMOR >= 99 )
replace IRALCSHO = . if (IRALCSHO >= 99 )
replace IRALCALO = . if (IRALCALO >= 99 )
replace IRALCBRK = . if (IRALCBRK >= 99 )
replace IRDEP = . if (IRDEP >= 99 )
replace IRARG = . if (IRARG >= 99 )
replace IRALN = . if (IRALN >= 99 )
replace IRANX = . if (IRANX >= 99 )
replace IRHLT = . if (IRHLT >= 99 )
replace IRNTK = . if (IRNTK >= 99 )
replace IRUPS = . if (IRUPS >= 99 )
replace IRLSW = . if (IRLSW >= 99 )
replace IRSSP = . if (IRSSP >= 99 )
replace IRCPE = . if (IRCPE >= 99 )
replace IREMG = . if (IREMG >= 99 )
replace IRDEP1 = . if (IRDEP1 >= 998 )
replace IRDEP2 = . if (IRDEP2 >= 999 )
replace IRDEP3 = . if (IRDEP3 >= 999 )
replace IRDEP4 = . if (IRDEP4 >= 999 )
replace IRDEP5 = . if (IRDEP5 >= 999 )
replace IRARG1 = . if (IRARG1 >= 998 )
replace IRARG2 = . if (IRARG2 >= 999 )
replace IRARG3 = . if (IRARG3 >= 999 )
replace IRARG4 = . if (IRARG4 >= 999 )
replace IRARG5 = . if (IRARG5 >= 999 )
replace IRALN1 = . if (IRALN1 >= 998 )
replace IRALN2 = . if (IRALN2 >= 999 )
replace IRALN3 = . if (IRALN3 >= 999 )
replace IRALN4 = . if (IRALN4 >= 999 )
replace IRALN5 = . if (IRALN5 >= 999 )
replace IRANX1 = . if (IRANX1 >= 998 )
replace IRANX2 = . if (IRANX2 >= 999 )
replace IRANX3 = . if (IRANX3 >= 999 )
replace IRANX4 = . if (IRANX4 >= 999 )
replace IRANX5 = . if (IRANX5 >= 999 )
replace IRHLT1 = . if (IRHLT1 >= 998 )
replace IRHLT2 = . if (IRHLT2 >= 999 )
replace IRHLT3 = . if (IRHLT3 >= 999 )
replace IRHLT4 = . if (IRHLT4 >= 999 )
replace IRHLT5 = . if (IRHLT5 >= 999 )
replace IRNTK1 = . if (IRNTK1 >= 998 )
replace IRNTK2 = . if (IRNTK2 >= 999 )
replace IRNTK3 = . if (IRNTK3 >= 999 )
replace IRNTK4 = . if (IRNTK4 >= 999 )
replace IRNTK5 = . if (IRNTK5 >= 999 )
replace IRUPS1 = . if (IRUPS1 >= 998 )
replace IRUPS2 = . if (IRUPS2 >= 999 )
replace IRUPS3 = . if (IRUPS3 >= 999 )
replace IRUPS4 = . if (IRUPS4 >= 999 )
replace IRUPS5 = . if (IRUPS5 >= 999 )
replace IRLSW1 = . if (IRLSW1 >= 998 )
replace IRLSW2 = . if (IRLSW2 >= 999 )
replace IRLSW3 = . if (IRLSW3 >= 999 )
replace IRLSW4 = . if (IRLSW4 >= 999 )
replace IRLSW5 = . if (IRLSW5 >= 999 )
replace IRSSP1 = . if (IRSSP1 >= 998 )
replace IRSSP2 = . if (IRSSP2 >= 999 )
replace IRSSP3 = . if (IRSSP3 >= 999 )
replace IRSSP4 = . if (IRSSP4 >= 999 )
replace IRSSP5 = . if (IRSSP5 >= 999 )
replace IRCPE1 = . if (IRCPE1 >= 998 )
replace IRCPE2 = . if (IRCPE2 >= 999 )
replace IRCPE3 = . if (IRCPE3 >= 999 )
replace IRCPE4 = . if (IRCPE4 >= 999 )
replace IRCPE5 = . if (IRCPE5 >= 999 )
replace IREMG1 = . if (IREMG1 >= 998 )
replace IREMG2 = . if (IREMG2 >= 999 )
replace IREMG3 = . if (IREMG3 >= 999 )
replace IREMG4 = . if (IREMG4 >= 999 )
replace IREMG5 = . if (IREMG5 >= 999 )
replace IRCDCIG = . if (IRCDCIG >= 13 )
replace IRCDALC = . if (IRCDALC >= 13 )
replace IRCDMJ = . if (IRCDMJ >= 13 )
replace IRCDCOC = . if (IRCDCOC >= 13 )
replace IREFCIG = . if (IREFCIG >= 13 )
replace IREFALC = . if (IREFALC >= 13 )
replace IREFMJ = . if (IREFMJ >= 13 )
replace IREFCOC = . if (IREFCOC >= 13 )
replace IRUDCIG = . if (IRUDCIG >= 13 )
replace IRUDALC = . if (IRUDALC >= 13 )
replace IRUDMJ = . if (IRUDMJ >= 13 )
replace IRUDCOC = . if (IRUDCOC >= 13 )
replace IRDPCIG = . if (IRDPCIG >= 13 )
replace IRDPALC = . if (IRDPALC >= 13 )
replace IRDPMJ = . if (IRDPMJ >= 13 )
replace IRDPCOC = . if (IRDPCOC >= 13 )
replace IRWSCIG = . if (IRWSCIG >= 13 )
replace IRWSALC = . if (IRWSALC >= 13 )
replace IRWSMJ = . if (IRWSMJ >= 13 )
replace IRWSCOC = . if (IRWSCOC >= 13 )


*/
/********************************************************************

 Section 5: Save Outfile

  This section saves out a Stata system format file.  There is no reason to
  modify it if the macros in Section 1 were specified correctly.

*********************************************************************/

save `outfile', replace

